@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2000-2004 Joern Thyssen <joern@thyssen.nu>
- * Copyright (C) 2000-2019 the AUTHORS
+ * Copyright (C) 2000-2023 the AUTHORS
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,9 +15,34 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: analysis.c,v 1.260 2022/02/15 21:42:12 plm Exp $
+ * $Id: analysis.c,v 1.262 2023/03/07 22:29:54 plm Exp $
  */
 
+/*
+02/2023: Isaac Keslassy: introduced the "background analysis"
+feature, together with a new button in the main toolbar: "Analyse"
+- button: "Analyse":
+    - This is to analyse the current match.
+    - Define options for what it does (in Settings>Analysis):
+        - "background analysis" checkbox:
+            * unchecked => regular "analyse match" (blocking, like today), vs.
+            * checked => we can browse at the same time and check the analysis
+        - "automatic add-to-database" checkbox:
+            * Unchecked = like today, vs
+            * Checked = automatic add-to-db at end of analysis (and we remove the add-to-db
+                button from the statistics page)
+- 2nd button: "Analyze file": 
+    - This is for a file, e.g. a match that we just played online. 
+    - Can launch either one of 3 options (defined in Settings>Analysis):
+        1) Regular "batch analysis": blocking, like today (+add-to-db)
+        2) "Single-file analysis": analysis of 1 chosen file, can be in 
+            background and/or add-to-db based on defined settings
+        3) "Smart analysis": pick the newest file in the preferred folder that gnubg 
+            recognizes, then can be in background and/or add-to-db based on defined settings
+When analyzing in the background, various menus are disabled so the user does not launch
+    another analysis in the middle.
+*/
+
 #include "config.h"
 
 #include <glib.h>
@@ -696,8 +721,9 @@ AnalyzeMove(moverecord * pmr, matchstate * pms, const listOLD * plParentGame,
                     }
                     MT_Exclusive();
                     CopyMoveList(&pmr->ml, &ml);
-                    if (ml.cMoves)
+                    if (ml.cMoves) {
                         g_free(ml.amMoves);
+                    }
                 }
 
             }
@@ -1161,12 +1187,30 @@ CommandAnalyseGame(char *UNUSED(sz))
     fStore_crawford = ms.fCrawford;
     nMoves = NumberMovesGame(plGame);
 
-    ProgressStartValue(_("Analysing game; move:"), nMoves);
+ /* see explanations in CommandAnalyseMatch()*/
+#if defined(USE_GTK)
+    if (fBackgroundAnalysis && fX) {
+        fAnalysisRunning = TRUE;
+        ProgressStartValue(_("Background analysis. Browsing-only mode: "
+          "feel free to browse and check the early analysis results."), nMoves);
+        ShowBoard(); /* hide unallowd toolbar items*/
+        GTKRegenerateGames(); /* hide unallowed menu items*/
+    } else
+#endif
+        ProgressStartValue(_("Analysing game"), nMoves);
 
     AnalyzeGame(plGame, TRUE);
 
     ProgressEnd();
 
+    if (fBackgroundAnalysis) {
+        fAnalysisRunning = FALSE;
+        ShowBoard(); /* hide unallowd toolbar items*/
+#if defined(USE_GTK)
+        GTKRegenerateGames(); /* hide unallowed menu items*/
+#endif
+    }
+
 #if defined(USE_GTK)
     if (fX)
         ChangeGame(NULL);
@@ -1195,7 +1239,26 @@ CommandAnalyseMatch(char *UNUSED(sz))
     fStore_crawford = ms.fCrawford;
     nMoves = NumberMovesMatch(&lMatch);
 
-    ProgressStartValue(_("Analysing match; move:"), nMoves);
+    /* if we analyze in the background, we turn on a global flag
+       to disable all sorts of buttons during the analysis */
+
+#if defined(USE_GTK)
+    if(fBackgroundAnalysis && fX) {
+        fAnalysisRunning = TRUE;
+        ProgressStartValue(_("Background analysis. Browsing-only mode: "
+        "feel free to browse and check the early analysis results."), nMoves);
+        ShowBoard(); /* hide unallowd toolbar items*/
+        GTKRegenerateGames(); /* hide unallowed menu items*/
+    }
+    else
+#endif
+    {
+        /* this was supposed to show nMoves, but it's not used at the end;
+        on the right side we see "n/nTotal"; so we update the text
+        */
+        // ProgressStartValue(_("Analysing match; move:"), nMoves);
+        ProgressStartValue(_("Analysing match"), nMoves);
+    }
 
     IniStatcontext(&scMatch);
 
@@ -1217,6 +1280,15 @@ CommandAnalyseMatch(char *UNUSED(sz))
 
     ProgressEnd();
 
+#if defined(USE_GTK)
+    if (fBackgroundAnalysis && fX) {
+        fAnalysisRunning = FALSE;
+         // CalculateBoard();
+        ShowBoard(); /* show toolbar items*/
+        GTKRegenerateGames(); /* show menu items*/
+    }
+#endif
+
 #if defined(USE_GTK)
     if (fX)
         ChangeGame(NULL);
@@ -2134,14 +2206,7 @@ cmark_move_set(moverecord * pmr, gchar * sz, CMark cmark)
 
     c = pmr->ml.cMoves;
 
-    /* Mike Petch - This is a hack and is not thread safe under GLIB version < 2.12.5
-     * Was added to allow cygwin to compile */
-
-#if GLIB_CHECK_VERSION(2,12,5)
     while ((n = (int) g_ascii_strtoll(sz, &sz, 10)) != 0) {
-#else
-    while ((n = (int) strtoll(sz, &sz, 10)) != 0) {
-#endif
         if (n > c) {
             outputerrf(_("Only %d legal moves, cannot mark move %d\n"), c, n);
             g_slist_free(list);
