@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1999-2003 Gary Wong <gtw@gnu.org>
- * Copyright (C) 1999-2022 the AUTHORS
+ * Copyright (C) 1999-2023 the AUTHORS
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: backgammon.h,v 1.470 2022/10/16 19:05:38 plm Exp $
+ * $Id: backgammon.h,v 1.477 2023/09/14 19:36:03 plm Exp $
  */
 
 #ifndef BACKGAMMON_H
@@ -253,6 +253,22 @@ typedef struct {
     const evalcontext *pec;
 } scoreData;
 
+/* Defining structures for AnalyzeFileSetting.
+Other defined structures throughout the files: 
+- apwAnalyzeFileSetting (gtkgame.c); 
+- "set analysis filesetting" (gtkgame.c); 
+- CommandSetAnalysisFileSetting (backgammon.h)
+*/
+typedef enum {
+    AnalyzeFileBatch, 
+    AnalyzeFileRegular, 
+    AnalyzeFileSmart, 
+    NUM_AnalyzeFileSettings
+    } analyzeFileSetting;
+extern analyzeFileSetting AnalyzeFileSettingDef;
+extern const char* aszAnalyzeFileSetting[NUM_AnalyzeFileSettings];
+extern const char* aszAnalyzeFileSettingCommands[NUM_AnalyzeFileSettings]; 
+
 typedef void (*AsyncFun) (void *);
 
 void asyncDumpDecision(decisionData * pdd);
@@ -337,6 +353,7 @@ extern int fAnalyseDice;
 extern int fAnalyseMove;
 extern int fAutoBearoff;
 extern int fAutoCrawford;
+extern int fAutoDB;
 extern int fAutoGame;
 extern int fAutoMove;
 extern int fAutoRoll;
@@ -370,6 +387,8 @@ extern int log_rollouts;
 extern int nThreadPriority;
 extern int nToolbarStyle;
 extern int nTutorSkillCurrent;
+extern int fBackgroundAnalysis; /* define whether to analyze in the background */
+extern int fAnalysisRunning; /* when analyzing a match in background */
 #if defined(USE_BOARD3D)
 extern int fSync;
 extern int fResetSync;
@@ -384,8 +403,7 @@ typedef const movefilter (*ConstTmoveFilter)[MAX_FILTER_PLIES];
 
 extern TmoveFilter *GetEvalMoveFilter(void);
 extern player ap[2];
-extern char default_names[2][31];
-extern char player1aliases[256];
+extern char default_names[2][MAX_NAME_LEN];
 extern rolloutcontext rcRollout;
 extern skilltype TutorSkill;
 extern statcontext scMatch;
@@ -491,7 +509,11 @@ extern void PromptForExit(void);
 extern void Prompt(void);
 extern void ResetInterrupt(void);
 extern void SaveRolloutSettings(FILE * pf, const char *sz, rolloutcontext * prc);
+extern int SetBoard(char *szGNUbgID);
+extern int SetCubeValue(int n);
 extern void setDefaultFileName(char *path);
+extern void SetDice(int n0, int n1);
+extern int SetGNUbgID(char *szGNUbgID);
 extern void SetMatchDate(matchinfo * pmi);
 extern void SetMatchID(const char *szMatchID);
 extern void SetMatchInfo(char **ppch, const char *sz, char *szMessage);
@@ -639,6 +661,8 @@ extern void CommandSaveSettings(char *);
 extern void CommandSetAnalysisChequerplay(char *);
 extern void CommandSetAnalysisCube(char *);
 extern void CommandSetAnalysisCubedecision(char *);
+extern void CommandSetAnalysisFileSetting(char*);
+extern void CommandSetAnalysisBackground(char *);
 extern void CommandSetAnalysisLimit(char *);
 extern void CommandSetAnalysisLuckAnalysis(char *);
 extern void CommandSetAnalysisLuck(char *);
@@ -658,6 +682,7 @@ extern void CommandSetAnnotation(char *);
 extern void CommandSetAppearance(char *);
 extern void CommandSetAutoBearoff(char *);
 extern void CommandSetAutoCrawford(char *);
+extern void CommandSetAutoDB(char *);
 extern void CommandSetAutoDoubles(char *);
 extern void CommandSetAutoGame(char *);
 extern void CommandSetAutoMove(char *);
@@ -675,6 +700,7 @@ extern void CommandSetCheatEnable(char *);
 extern void CommandSetCheatPlayer(char *);
 extern void CommandSetCheatPlayerRoll(char *);
 extern void CommandSetClockwise(char *);
+extern void CommandSetUseKeyNames(char *);
 extern void CommandSetCommandWindow(char *);
 extern void CommandSetConfirmDefault(char *);
 extern void CommandSetConfirmNew(char *);
@@ -755,7 +781,7 @@ extern void CommandSetGeometryPosX(char *);
 extern void CommandSetGeometryPosY(char *);
 extern void CommandSetGeometryTheory(char *);
 extern void CommandSetGeometryWidth(char *);
-extern void CommandSetGNUBgID(char *);
+extern void CommandSetGNUbgID(char *);
 extern void CommandSetXGID(char *);
 extern void CommandSetGotoFirstGame(char *);
 extern void CommandSetGUIAnimationBlink(char *);
@@ -873,6 +899,14 @@ extern void CommandSetRolloutTruncationEqualPlayer0(char *);
 extern void CommandSetRolloutTruncationPlies(char *);
 extern void CommandSetRolloutVarRedn(char *);
 extern void CommandSetScore(char *);
+extern void CommandSetScoreMapPly(char*);
+extern void CommandSetScoreMapMatchLength(char*);
+extern void CommandSetScoreMapLabel(char*);
+extern void CommandSetScoreMapJacoby(char*);
+extern void CommandSetScoreMapCubeEquityDisplay(char*);
+extern void CommandSetScoreMapMoveEquityDisplay(char*);
+extern void CommandSetScoreMapColour(char*);
+extern void CommandSetScoreMapLayout(char*);
 extern void CommandSetSeed(char *);
 extern void CommandSetSGFFolder(char *);
 extern void CommandSetSoundEnable(char *);
@@ -914,7 +948,6 @@ extern void CommandSetVariationStandard(char *);
 extern void CommandSetVsync3d(char *);
 extern void CommandSetWarning(char *);
 extern void CommandShow8912(char *);
-extern void CommandShowAliases(char *);
 extern void CommandShowAnalysis(char *);
 extern void CommandShowAutoSave(char *);
 extern void CommandShowAutomatic(char *);
@@ -943,6 +976,7 @@ extern void CommandShowExport(char *);
 extern void CommandShowFullBoard(char *);
 extern void CommandShowGammonValues(char *);
 extern void CommandShowGeometry(char *);
+extern void CommandShowHistory(char *);
 extern void CommandShowJacoby(char *);
 extern void CommandShowKeith(char *);
 extern void CommandShowKleinman(char *);
@@ -986,7 +1020,8 @@ extern void CommandShowWarranty(char *);
 extern void CommandSwapPlayers(char *);
 extern void CommandTake(char *);
 extern void CommandSetDefaultNames(char *sz);
-extern void CommandSetAliases(char *sz);
+extern void CommandSetKeyNames(char *sz);
+extern void UserCommand(const char *szCommand);
 extern void hint_move(char *sz, gboolean show, procrecorddata * procdatarec);
 extern void hint_double(int show, int did_double);
 extern void hint_take(int show, int did_take);
@@ -1020,4 +1055,18 @@ extern int quick_roll(void);
 extern int board_in_list(const movelist * pml, const TanBoard old_board, const TanBoard board, int *an);
 extern int GetManualDice(unsigned int anDice[2]);
 
+/* definitions for SmartSit and keyNames*/
+extern void SmartSit(void); /* function that makes sure that player 1 is a key player, if there is one */
+#define MAX_KEY_NAMES 200 /* number of defined key player names*/
+extern char keyNames[MAX_KEY_NAMES][MAX_NAME_LEN]; /* array with all key player names*/
+extern int keyNamesFirstEmpty; /* the keyNames array should be filled from index 0 until keyNamesFirstEmpty-1 (included)*/
+extern int fUseKeyNames; /* whether to use the keyNames array*/
+extern int fWithinSmartSit; /* whether we are within the SmartSit function: if it requests to permute users, no need to add the
+                                    new player1 to the list of preferred users*/
+extern int AddKeyName(const char sz[]); /* function that adds a key player name to the array*/
+extern int DeleteKeyName(const char sz[]); /* function that deletes a key player name to the array*/
+extern void DisplayKeyNames(void); /* debugging function to display the current key player names in the array*/
+
+extern int fTriggeredByRecordList; /* whether history plot is launched from record list or from menu */
+
 #endif	/* BACKGAMMON_H */
