@@ -1,11 +1,11 @@
 /*
- * bearoff.c
+ * Copyright (C) 2002-2004 Joern Thyssen <jthyssen@dk.ibm.com>
+ * Copyright (C) 2003-2019 the AUTHORS
  *
- * by Joern Thyssen <jthyssen@dk.ibm.com>, 2002
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,11 +13,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: bearoff.c,v 1.104 2018/04/28 22:14:46 plm Exp $
+ * $Id: bearoff.c,v 1.109 2022/07/26 21:16:44 plm Exp $
  */
+
 #include "config.h"
 /*must be first here because of strange warning from mingw */
 #include "multithread.h"
@@ -34,9 +34,7 @@
 #include <glib/gstdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <fcntl.h>
 #include <errno.h>
-#include "glib-ext.h"
 
 #define HEURISTIC_C 15
 #define HEURISTIC_P 6
@@ -106,9 +104,9 @@ AverageRolls(const float arProb[32], float *ar)
     sx = sx2 = 0.0f;
 
     for (i = 1; i < 32; i++) {
-        float p = i * arProb[i];
+        float p = (float) i * arProb[i];
         sx += p;
-        sx2 += i * p;
+        sx2 += (float) i * p;
     }
 
     ar[0] = sx;
@@ -206,12 +204,8 @@ HeuristicBearoff(unsigned int anBoard[6], const unsigned int anRoll[2])
 static void
 GenerateBearoff(unsigned char *p, unsigned int nId)
 {
-    unsigned int anRoll[2], anBoard[6], aProb[32];
+    unsigned int anRoll[2], anBoard[6], aProb[32] = { 0 };
     unsigned int i, iBest;
-    unsigned short us;
-
-    for (i = 0; i < 32; i++)
-        aProb[i] = 0;
 
     for (anRoll[0] = 1; anRoll[0] <= 6; anRoll[0]++)
         for (anRoll[1] = 1; anRoll[1] <= anRoll[0]; anRoll[1]++) {
@@ -230,7 +224,8 @@ GenerateBearoff(unsigned char *p, unsigned int nId)
         }
 
     for (i = 0; i < 32; i++) {
-        us = (unsigned short) ((aProb[i] + 18) / 36);
+        unsigned short us = (unsigned short) ((aProb[i] + 18) / 36);
+
         p[(nId << 6) | (i << 1)] = us & 0xFF;
         p[(nId << 6) | (i << 1) | 1] = us >> 8;
     }
@@ -268,9 +263,9 @@ ReadBearoffFile(const bearoffcontext * pbc, unsigned int offset, unsigned char *
 
     if ((fseek(pbc->pf, (long) offset, SEEK_SET) < 0) || (fread(buf, 1, nBytes, pbc->pf) < nBytes)) {
         if (errno)
-            perror("OS bearoff database");
+            perror(_("bearoff database"));
         else
-            fprintf(stderr, "error reading OS bearoff database");
+            fprintf(stderr, _("Error reading bearoff database"));
 
         memset(buf, 0, nBytes);
         return;
@@ -286,7 +281,6 @@ ReadTwoSidedBearoff(const bearoffcontext * pbc, const unsigned int iPos, float a
     unsigned int i, k = (pbc->fCubeful) ? 4 : 1;
     unsigned char ac[8];
     unsigned char *pc = NULL;
-    unsigned short int us;
 
     if (pbc->p)
         pc = pbc->p + 40 + 2 * iPos * k;
@@ -297,7 +291,8 @@ ReadTwoSidedBearoff(const bearoffcontext * pbc, const unsigned int iPos, float a
     /* add to cache */
 
     for (i = 0; i < k; ++i) {
-        us = pc[2 * i] | (unsigned short) (pc[2 * i + 1] << 8);
+        unsigned short int us = pc[2 * i] | (unsigned short) (pc[2 * i + 1] << 8);
+
         if (aus)
             aus[i] = us;
         if (ar)
@@ -356,13 +351,13 @@ ReadHypergammon(const bearoffcontext * pbc, const unsigned int iPos, float arOut
     if (arOutput)
         for (i = 0; i < NUM_OUTPUTS; ++i) {
             us = pc[3 * i] | (pc[3 * i + 1]) << 8 | (pc[3 * i + 2]) << 16;
-            arOutput[i] = us / 16777215.0f;
+            arOutput[i] = (float) us / 16777215.0f;
         }
 
     if (arEquity)
         for (i = 0; i < 4; ++i) {
             us = pc[15 + 3 * i] | (pc[15 + 3 * i + 1]) << 8 | (pc[15 + 3 * i + 2]) << 16;
-            arEquity[i] = (us / 16777215.0f - 0.5f) * 6.0f;
+            arEquity[i] = ((float) us / 16777215.0f - 0.5f) * 6.0f;
         }
 
     return 0;
@@ -377,7 +372,7 @@ BearoffEvalOneSided(const bearoffcontext * pbc, const TanBoard anBoard, float ar
     float aarProb[2][32];
     float aarGammonProb[2][32];
     float r;
-    unsigned int anOn[2];
+    unsigned int anOn[2] = { 0 };
     unsigned int an[2];
     float ar[2][4];
 
@@ -402,7 +397,7 @@ BearoffEvalOneSided(const bearoffcontext * pbc, const TanBoard anBoard, float ar
     /* calculate gammon chances */
 
     for (i = 0; i < 2; ++i)
-        for (j = 0, anOn[i] = 0; j < 25; ++j)
+        for (j = 0; j < 25; ++j)
             anOn[i] += anBoard[i][j];
 
     if (anOn[0] == 15 || anOn[1] == 15) {
@@ -485,7 +480,8 @@ BearoffEval(const bearoffcontext * pbc, const TanBoard anBoard, float arOutput[]
         return BearoffEvalHypergammon(pbc, anBoard, arOutput);
     case BEAROFF_INVALID:
     default:
-        g_warning("Invalid type in BearoffEval");
+        g_warning(_("Invalid bearoff database type"));
+        g_assert_not_reached();
         return 0;
     }
 }
@@ -551,7 +547,6 @@ BearoffDumpTwoSided(const bearoffcontext * pbc, const TanBoard anBoard, char *sz
     unsigned int n = Combination(pbc->nPoints + pbc->nChequers, pbc->nPoints);
     unsigned int iPos = nUs * n + nThem;
     float ar[4];
-    unsigned int i;
     const char *aszEquity[] = {
         N_("Cubeless equity"),
         N_("Owned cube"),
@@ -564,7 +559,7 @@ BearoffDumpTwoSided(const bearoffcontext * pbc, const TanBoard anBoard, char *sz
     ReadTwoSidedBearoff(pbc, iPos, ar, NULL);
 
     if (pbc->fCubeful)
-        for (i = 0; i < 4; ++i)
+        for (int i = 0; i < 4; ++i)
             sprintf(sz + strlen(sz), "%-30.30s: %+7.4f\n", gettext(aszEquity[i]), ar[i]);
     else
         sprintf(sz + strlen(sz), "%-30.30s: %+7.4f\n", gettext(aszEquity[0]), 2.0f * ar[0] - 1.0f);
@@ -665,7 +660,8 @@ BearoffDumpOneSided(const bearoffcontext * pbc, const TanBoard anBoard, char *sz
     sz += sprintf(sz, "\n%s:\n", _("Effective pip count"));
     sz += sprintf(sz, "\t%s\t%s\n", _("Player"), _("Opponent"));
     sz += sprintf(sz, "%s\t%7.3f\t%7.3f\n%s\t%7.3f\t%7.3f\n\n", _("EPC"),
-                  ar[0][0] * x, ar[1][0] * x, _("Wastage"), ar[0][0] * x - anPips[1], ar[1][0] * x - anPips[0]);
+                  ar[0][0] * x, ar[1][0] * x, _("Wastage"), ar[0][0] * x - (float) anPips[1],
+                  ar[1][0] * x - (float) anPips[0]);
 
     sprintf(sz, "%s = %5.3f * %s\n%s = %s - %s\n\n",
             _("EPC"), x, _("Average rolls"), _("Wastage"), _("EPC"), _("pips"));
@@ -715,7 +711,7 @@ BearoffDump(const bearoffcontext * pbc, const TanBoard anBoard, char *sz)
         return BearoffDumpHyper(pbc, anBoard, sz);
     case BEAROFF_INVALID:
     default:
-        g_warning("Invalid type in BearoffDump");
+        g_warning(_("Invalid bearoff database type"));
         return -1;
     }
 }
@@ -730,11 +726,7 @@ BearoffClose(bearoffcontext * pbc)
         fclose(pbc->pf);
 
     if (pbc->map) {
-#if GLIB_CHECK_VERSION(2,22,0)
         g_mapped_file_unref(pbc->map);
-#else
-        g_mapped_file_free(pbc->map);
-#endif
         pbc->p = NULL;
     }
 
@@ -832,7 +824,7 @@ BearoffInit(const char *szFilename, const unsigned int bo, void (*p) (unsigned i
     }
 
 
-    if ((pbc->pf = gnubg_g_fopen(szFilename, "rb")) == 0) {
+    if ((pbc->pf = g_fopen(szFilename, "rb")) == 0) {
         g_printerr("%s\n", _("Invalid or nonexistent database"));
         InvalidDb(pbc);
         return NULL;
@@ -874,7 +866,8 @@ BearoffInit(const char *szFilename, const unsigned int bo, void (*p) (unsigned i
 
     if (((bo & BO_MUST_BE_ONE_SIDED) && (pbc->bt != BEAROFF_ONESIDED))
         || ((bo & BO_MUST_BE_TWO_SIDED) && (pbc->bt != BEAROFF_TWOSIDED))) {
-        	g_printerr("%s: %s\n (%s: '%2s')\n", szFilename, _("incorrect bearoff database"), _("wrong bearoff type"), sz + 6);
+        g_printerr("%s: %s\n (%s: '%2s')\n", szFilename, _("incorrect bearoff database"), _("wrong bearoff type"),
+                   sz + 6);
         InvalidDb(pbc);
         return NULL;
     }
@@ -936,7 +929,7 @@ BearoffInit(const char *szFilename, const unsigned int bo, void (*p) (unsigned i
         fclose(pbc->pf);
         pbc->pf = NULL;
         if ((ReadIntoMemory(pbc) == NULL))
-            if ((pbc->pf = gnubg_g_fopen(szFilename, "rb")) == 0) {
+            if ((pbc->pf = g_fopen(szFilename, "rb")) == 0) {
                 g_printerr("%s\n", _("Invalid or nonexistent database"));
                 InvalidDb(pbc);
                 return NULL;
@@ -959,7 +952,7 @@ fnd(const float x, const float mu, const float sigma)
 
         float xm = (x - mu) / sigma;
 
-        return 1.0f / (sigma * sqrtf(2.0f * (float) G_PI)) * expf(-xm * xm / 2.0f);
+        return 1.0f / (sigma * sqrtf(2.0f * F_PI)) * expf(-xm * xm / 2.0f);
 
     }
 
@@ -985,7 +978,7 @@ ReadBearoffOneSidedND(const bearoffcontext * pbc,
 
     if (arProb || ausProb)
         for (i = 0; i < 32; ++i) {
-            r = fnd(1.0f * i, arx[0], arx[1]);
+            r = fnd((float) i, arx[0], arx[1]);
             if (arProb)
                 arProb[i] = r;
             if (ausProb)
@@ -996,7 +989,7 @@ ReadBearoffOneSidedND(const bearoffcontext * pbc,
 
     if (arGammonProb || ausGammonProb)
         for (i = 0; i < 32; ++i) {
-            r = fnd(1.0f * i, arx[2], arx[3]);
+            r = fnd((float) i, arx[2], arx[3]);
             if (arGammonProb)
                 arGammonProb[i] = r;
             if (ausGammonProb)
@@ -1018,10 +1011,6 @@ AssignOneSided(float arProb[32], float arGammonProb[32],
                unsigned short int ausGammonProb[32],
                const unsigned short int ausProbx[32], const unsigned short int ausGammonProbx[32])
 {
-
-    int i;
-    float arx[64];
-
     if (ausProb)
         memcpy(ausProb, ausProbx, 32 * sizeof(ausProb[0]));
 
@@ -1029,6 +1018,9 @@ AssignOneSided(float arProb[32], float arGammonProb[32],
         memcpy(ausGammonProb, ausGammonProbx, 32 * sizeof(ausGammonProbx[0]));
 
     if (ar || arProb || arGammonProb) {
+        float arx[64];
+        int i;
+
         for (i = 0; i < 32; ++i)
             arx[i] = ausProbx[i] / 65535.0f;
 
@@ -1098,12 +1090,12 @@ GetDistCompressed(unsigned short int aus[64], const bearoffcontext * pbc, const
     /* Sanity checks */
 
     if ((iOffset > 64 * nPos && 64 * nPos > 0) || nz > 32 || ioff > 32 || nzg > 32 || ioffg > 32) {
+        fprintf(stderr, _("The bearoff file '%s' is likely to be corrupted.\n"), pbc->szFilename);
+#if !defined(G_DISABLE_ASSERT)
         fprintf(stderr,
-                "The bearoff file '%s' is likely to be corrupted.\n"
-                "Please check that the MD5 sum is the same as documented "
-                "in the GNU Backgammon manual.\n"
                 "Offset %lu, dist size %u (offset %u), "
-                "gammon dist size %u (offset %u)\n", pbc->szFilename, (unsigned long) iOffset, nz, ioff, nzg, ioffg);
+                "gammon dist size %u (offset %u)\n", (unsigned long) iOffset, nz, ioff, nzg, ioffg);
+#endif
         g_assert_not_reached();
     }
 
@@ -1177,7 +1169,7 @@ ReadBearoffOneSidedExact(const bearoffcontext * pbc, const unsigned int nPosID,
         pus = GetDistUncompressed(aus, pbc, nPosID);
 
     if (!pus) {
-        printf("argh!\n");
+        printf(_("Error decoding one-sided bearoff database entry; position %u\n"), nPosID);
         return -1;
     }
 
