@@ -1,11 +1,11 @@
 /*
- * makebearoff.c
+ * Copyright (C) 2004 Joern Thyssen <jthyssen@dk.ibm.com>
+ * Copyright (C) 2004-2020 the AUTHORS
  *
- * by Gary Wong <gary@cs.arizona.edu>, 1997-1999.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: bearoffdump.c,v 1.24 2017/01/04 22:55:45 plm Exp $
+ * $Id: bearoffdump.c,v 1.29 2022/01/27 22:14:49 plm Exp $
  */
 
 #include "config.h"
@@ -25,6 +24,8 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
+#include <locale.h>
+
 #include "positionid.h"
 #include "bearoff.h"
 #include "multithread.h"
@@ -49,14 +50,21 @@ main(int argc, char **argv)
 
     GOptionEntry ao[] = {
         {"index", 'n', 0, G_OPTION_ARG_INT, &id,
-         "index", NULL},
+         N_("index"), NULL},
         {"posid", 'p', 0, G_OPTION_ARG_STRING, &szPosID,
-         "Position ID", NULL},
+         N_("Position ID"), NULL},
         {NULL, 0, 0, (GOptionArg) 0, NULL, NULL, NULL}
     };
     GError *error = NULL;
     GOptionContext *context;
 
+    setlocale(LC_ALL, "");
+    bindtextdomain(PACKAGE, LOCALEDIR);
+    textdomain(PACKAGE);
+
+    g_set_print_handler(print_utf8_to_locale);
+    g_set_printerr_handler(print_utf8_to_locale);
+
     context = g_option_context_new("file");
     g_option_context_add_main_entries(context, ao, PACKAGE);
     g_option_context_parse(context, &argc, &argv, &error);
@@ -67,35 +75,35 @@ main(int argc, char **argv)
     }
 
     if ((szPosID && id) || (!szPosID && !id)) {
-        g_printerr("Either Position ID or index is required. Not Both.\n" "For more help try `bearoffdump --help'\n");
+        g_printerr(_("Either Position ID or index is required.\n" "For more help try `bearoffdump --help'\n"));
         exit(EXIT_FAILURE);
     }
 
     if (argc != 2) {
-        g_printerr("A bearoff database file should be given as an argument\n"
-                   "For more help try `bearoffdump --help'\n");
+        g_printerr(_("A bearoff database file should be given as an argument\n"
+                   "For more help try `bearoffdump --help'\n"));
         exit(EXIT_FAILURE);
     }
     filename = argv[1];
 
-    printf("Bearoff database: %s\n", filename);
+    g_print(_("Bearoff database: %s\n"), filename);
     if (!id) {
-        printf("Position ID     : %s\n", szPosID);
+        g_print(_("Position ID     : %s\n"), szPosID);
     } else {
-        printf("Position number : %u\n", id);
+        g_print(_("Position number : %u\n"), id);
     }
 
     /* This is needed since we call ReadBearoffFile() from bearoff.c */
     MT_InitThreads();
 
     if (!(pbc = BearoffInit(filename, BO_NONE, NULL))) {
-        printf("Failed to initialise bearoff database %s\n", filename);
+        g_print(_("Failed to initialise bearoff database %s\n"), filename);
         exit(-1);
     }
 
     /* information about bearoff database */
 
-    printf("\n" "Information about database:\n\n");
+    g_print(_("\n" "Information about database:\n\n"));
 
     *sz = 0;
     BearoffStatus(pbc, sz);
@@ -106,13 +114,13 @@ main(int argc, char **argv)
     memset(anBoard, 0, sizeof anBoard);
 
     if (!id) {
-        printf("\n" "Dump of position ID: %s\n\n", szPosID);
+        g_print(_("\n" "Dump of position ID: %s\n\n"), szPosID);
 
         PositionFromID(anBoard, szPosID);
     } else {
         unsigned int n, nUs, nThem;
 
-        printf("\n" "Dump of position#: %u\n\n", id);
+        g_print(_("\n" "Dump of position#: %u\n\n"), id);
 
         n = Combination(pbc->nPoints + pbc->nChequers, pbc->nPoints);
         nUs = id / n;
@@ -125,9 +133,10 @@ main(int argc, char **argv)
 
     {
         char szOut[2048];
-        char *ap[7] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL };
+        char *apc[7] = { NULL, NULL, NULL, NULL, NULL, NULL, NULL };
+        int nc = pbc->bt == BEAROFF_HYPERGAMMON ? pbc->nChequers : 15;
 
-        puts(DrawBoard(szOut, (ConstTanBoard) anBoard, TRUE, ap, NULL, 15));
+        puts(DrawBoard(szOut, (ConstTanBoard) anBoard, TRUE, apc, NULL, nc));
     }
 
     /* dump req. position */
