@@ -1,13 +1,11 @@
 /*
- * graph.c
- * by Jon Kinsey, 2003
+ * Copyright (C) 2003-2019 Jon Kinsey <jonkinsey@gmail.com>
+ * Copyright (C) 2006-2021 the AUTHORS
  *
- * Simple graph graphics
- *
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -15,24 +13,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: graph.c,v 1.32 2017/05/27 21:34:43 plm Exp $
+ * $Id: graph.c,v 1.46 2022/03/06 22:45:43 plm Exp $
  */
 
-
 #include "config.h"
-#include "inc3d.h"
-
+#include "legacyGLinc.h"
+#include "fun3d.h"
 #include "renderprefs.h"
 #include "gtklocdefs.h"
-
-struct _GraphData {
-    float ***data;
-    unsigned int numGames;
-    float maxY;
-};
+#include <glib/gi18n.h>
+#include "common.h"
+#include "analysis.h"
 
 #define COL_WIDTH 5.f
 #define MID_GAP 1
@@ -45,7 +38,7 @@ struct _GraphData {
 #define NUM_HEIGHT_PER .15f
 
 static float modelWidth, modelHeight;
-static OGLFont *numberFont = NULL, *totalText = NULL;
+static OGLFont numberFont, totalText;
 
 static gboolean
 graph_button_press_event(void)
@@ -53,22 +46,19 @@ graph_button_press_event(void)
     return FALSE;
 }
 
-static gboolean
-configure_event(GtkWidget * widget, GdkEventConfigure * UNUSED(eventDetails), const GraphData * gd)
+static void
+configureCB(GtkWidget * widget, void *data)
 {
+    const GraphData *gd = (const GraphData *) data;
     int width, height;
     float maxY, maxX;
     GtkAllocation allocation;
-    GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable(widget);
-
-    if (!gdk_gl_drawable_gl_begin(gldrawable, gtk_widget_get_gl_context(widget)))
-        return FALSE;
 
     gtk_widget_get_allocation(widget, &allocation);
     width = allocation.width;
     height = allocation.height;
     maxX = (float) gd->numGames * RES_WIDTH + RES_WIDTH + TOTAL_GAP;
-    modelWidth = maxX * (1 + NUM_WIDTH_PER);
+    modelWidth = maxX * (NUM_WIDTH_PER + 1 + NUM_WIDTH_PER);
 
     maxY = gd->maxY * 1.05f + 1;
     modelHeight = maxY * (1 + NUM_HEIGHT_PER);
@@ -79,32 +69,22 @@ configure_event(GtkWidget * widget, GdkEventConfigure * UNUSED(eventDetails), co
     glOrtho(0.0, (double) modelWidth, 0.0, (double) modelHeight, -1.0, 0.0);
     glMatrixMode(GL_MODELVIEW);
     glLoadIdentity();
-
-    gdk_gl_drawable_gl_end(gldrawable);
-
-    return TRUE;
 }
 
 static void
-realize(GtkWidget * widget, const GraphData * UNUSED(gd))
+realizeCB(void *UNUSED(data))
 {
-    GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable(widget);
-
-    if (!gdk_gl_drawable_gl_begin(gldrawable, gtk_widget_get_gl_context(widget)))
-        return;
     /* Deep blue background colour */
     glClearColor(.2f, .2f, .4f, 1.f);
 
     if (!CreateNumberFont(&numberFont, FONT_VERA, FONT_PITCH, FONT_SIZE, FONT_HEIGHT_RATIO))
-        g_print("Error creating font\n");
+        g_print(_("Error creating font\n"));
 
+    /* Translate using only the characters contained in Vera font */
     if (!CreateFontText(&totalText, _("Totals"), FONT_VERA, FONT_PITCH, FONT_SIZE, FONT_HEIGHT_RATIO))
-        g_print("Error creating font\n");
+        g_print(_("Error creating font\n"));
 
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-
-    gdk_gl_drawable_gl_end(gldrawable);
-        /*** OpenGL END ***/
 }
 
 static void
@@ -173,7 +153,7 @@ DrawBars(unsigned int num, float *const *values, int totalBar)
 static void
 PrintBottomNumber(unsigned int num, float width, float height, float x, float y)
 {
-    char numStr[10];
+    char numStr[11];
     sprintf(numStr, "%u", num);
 
     glPushMatrix();
@@ -182,7 +162,7 @@ PrintBottomNumber(unsigned int num, float width, float height, float x, float y)
     glColor3f(1.f, 1.f, 1.f);
     glScalef(width, height, 1.f);
     glLineWidth(.5f);
-    glPrintCube(numberFont, numStr);
+    glPrintCube(&numberFont, numStr, 0);        //TODO No AA at the moment
     glPopMatrix();
 }
 
@@ -197,7 +177,7 @@ PrintSideNumber(int num, float width, float height, float x, float y)
 
     glScalef(width, height, 1.f);
     glLineWidth(.5f);
-    glPrintNumbersRA(numberFont, numStr);
+    glPrintNumbersRA(&numberFont, numStr);
 
     glPopMatrix();
 }
@@ -209,17 +189,18 @@ DrawLeftAxis(const GraphData * pgd)
     int *pScale = scale;
     int i, numPoints, pointInc;
 
-    while (pScale[1] && pgd->maxY > *pScale * 5.f)
+    while (pScale[1] && pgd->maxY > (float) *pScale * 5.f)
         pScale++;
 
     pointInc = *pScale;
-    numPoints = (int) (pgd->maxY / pointInc);
+    numPoints = (int) (pgd->maxY / (float) pointInc);
     if (numPoints == 0)
         numPoints = 1;
 
     for (i = 1; i <= numPoints; i++) {
         float y = NUM_HEIGHT;
-        y += (float) i *pointInc;
+
+        y += (float) (i * pointInc);
         glColor3f(1.f, 1.f, 1.f);
         PrintSideNumber(i * pointInc, NUM_WIDTH * 10, NUM_HEIGHT * 10, NUM_WIDTH - 1, y);
 
@@ -247,7 +228,7 @@ DrawGraph(const GraphData * gd)
     glColor3f(1.f, 1.f, 1.f);
     glLineWidth(.5f);
     glScalef(NUM_WIDTH * 10, NUM_HEIGHT * 10, 1.f);
-    glDrawText(totalText);
+    glDrawText(&totalText);
 
     glPopMatrix();
 
@@ -281,36 +262,19 @@ DrawGraph(const GraphData * gd)
 }
 
 static gboolean
-expose_event(GtkWidget * widget, GdkEventExpose * UNUSED(eventDetails), const GraphData * gd)
+exposeCB(GtkWidget * UNUSED(widget), GdkEventExpose * UNUSED(eventData), void *data)
 {
-    GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable(widget);
-
-    if (!gdk_gl_drawable_gl_begin(gldrawable, gtk_widget_get_gl_context(widget)))
-        return TRUE;
-    CheckOpenglError();
-
+    const GraphData *gd = (const GraphData *) data;
     glClear(GL_COLOR_BUFFER_BIT);
-
     DrawGraph(gd);
-
-    gdk_gl_drawable_swap_buffers(gldrawable);
-
-    gdk_gl_drawable_gl_end(gldrawable);
-
     return TRUE;
 }
 
 static void
 destroy_event(GtkWidget * UNUSED(widget), void *UNUSED(data))
 {
-    if (numberFont != NULL) {
-        FreeNumberFont(numberFont);
-        numberFont = NULL;
-    }
-    if (totalText != NULL) {
-        FreeFontText(totalText);
-        totalText = NULL;
-    }
+    FreeNumberFont(&numberFont);
+    FreeTextFont(&totalText);
 }
 
 GtkWidget *
@@ -319,13 +283,10 @@ StatGraph(GraphData * pgd)
     float f1, f2;
     GtkWidget *pw;
 
-    /* Drawing area for OpenGL */
-    pw = gtk_drawing_area_new();
-    /* Set OpenGL-capability to the widget - no list sharing */
-    if ((pw == NULL) || !gtk_widget_set_gl_capability(pw, getGlConfig(), NULL, TRUE, GDK_GL_RGBA_TYPE)) {
-        g_print("Can't create opengl capable widget\n");
+    /* Drawing widget for OpenGL */
+    pw = GLWidgetCreate(realizeCB, configureCB, exposeCB, pgd);
+    if (pw == NULL)
         return NULL;
-    }
 
     f1 = pgd->data[pgd->numGames][0][0] + pgd->data[pgd->numGames][0][1];
     f2 = pgd->data[pgd->numGames][1][0] + pgd->data[pgd->numGames][1][1];
@@ -335,9 +296,6 @@ StatGraph(GraphData * pgd)
 
     gtk_widget_set_events(pw, GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK);
     g_signal_connect(G_OBJECT(pw), "button_press_event", G_CALLBACK(graph_button_press_event), pgd);
-    g_signal_connect(G_OBJECT(pw), "realize", G_CALLBACK(realize), pgd);
-    g_signal_connect(G_OBJECT(pw), "configure_event", G_CALLBACK(configure_event), pgd);
-    g_signal_connect(G_OBJECT(pw), "expose_event", G_CALLBACK(expose_event), pgd);
     g_signal_connect(G_OBJECT(pw), "destroy", G_CALLBACK(destroy_event), NULL);
 
     return pw;
@@ -353,14 +311,14 @@ SetNumGames(GraphData * pgd, unsigned int numGames)
 extern GraphData *
 CreateGraphData(void)
 {
-    return (GraphData *) malloc(sizeof(GraphData));
+    return (GraphData *) g_malloc(sizeof(GraphData));
 }
 
 void
 TidyGraphData(GraphData * pgd)
 {
     Free3d(pgd->data, pgd->numGames + 1, 2);
-    free(pgd);
+    g_free(pgd);
 }
 
 void
