@@ -1,12 +1,12 @@
 #!/bin/sh
-#
-# credits.sh
-#
-# by Gary Wong <gtw@gnu.org>, 1998, 1999, 2000, 2001, 2002, 2003, 2004
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of version 3 or later of the GNU General Public License as
-# published by the Free Software Foundation.
+
+# Copyright (C) 1998-2004 Gary Wong <gtw@gnu.org>
+# Copyright (C) 2004-2023 the AUTHORS
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,10 +14,10 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
 #
-# $Id: credits.sh,v 1.157 2018/01/15 21:04:21 plm Exp $
+# $Id: credits.sh,v 1.168 2023/10/18 21:33:42 plm Exp $
 # 
 
 authors=/tmp/auth.$$
@@ -46,11 +46,13 @@ Holger Bochnig
 Guido Flohr
 Nis Joergensen
 Petr Kadlec
+Isaac Keslassy
 Kaoru Takahashi
 Stein Kulseth
 Ingo Macherius
 Jeremy Moore
 Rod Roark
+Aaron Tikuisis
 EOF
 
 cat > $support <<EOF
@@ -63,6 +65,7 @@ EOF
 cat > $translations <<EOF
 Petr Kadlec,Czech
 Joern Thyssen,Danish
+Matti Kamppinen,Finnish
 Olivier Baur,French
 Achim Mueller,German
 Vangelis Skarmoutsos,Greek
@@ -71,6 +74,7 @@ Renzo Campagna,Italian
 Yoshito Takeuchi,Japanese
 Mihai Varzaru,Romanian
 Dmitri I Gouliaev,Russian
+Fernando García García,Spanish
 Akif Dinc,Turkish
 EOF
 
@@ -186,6 +190,7 @@ Frank Worrell
 Christopher D. Yep
 Anders Zachrison
 Douglas Zare
+Tilemachos Zoidis
 Louis Zulli
 EOF
 
@@ -203,11 +208,13 @@ EOF
 # generate credits.c
 
 cat > credits.h <<EOF
-/* Do not modify this file!  It is created automatically by credits.sh.
-   Modify credits.sh instead. 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+/* Do not modify this file!  It is created automatically by credits.sh. */
+
+/*
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -215,18 +222,17 @@ cat > credits.h <<EOF
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ */
 
 #include <glib/gi18n.h>
 
-typedef struct _credEntry {
+typedef struct {
 	char* Name;
 	char* Type;
 } credEntry;
 
-typedef struct _credits {
+typedef struct {
 	const char* Title;
 	credEntry *Entry;
 } credits;
@@ -245,11 +251,13 @@ extern const char aszCOPYRIGHT[];
 
 EOF
 cat > credits.c <<EOF
-/* Do not modify this file!  It is created automatically by credits.sh.
-   Modify credits.sh instead. 
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+/* Do not modify this file!  It is created automatically by credits.sh. */
+
+/*
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -257,16 +265,15 @@ cat > credits.c <<EOF
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ */
 
 #include "common.h"
 #include <glib/gi18n.h>
 #include "credits.h"
 
-const char aszCOPYRIGHT[] = N_("Copyright (C) 1999, 2000, 2001, 2002, 2003, 2004 by Gary Wong.\n"
-                               "Copyright (C) 2018 by Gary Wong and the AUTHORS; for details type \`show version'.");
+const char aszCOPYRIGHT[] = N_("Copyright (C) 1999-2004 Gary Wong.\n"
+                               "Copyright (C) 2004-2024 the AUTHORS; for details type \`show version'.");
 
 credEntry ceAuthors[] = {
 EOF
@@ -407,10 +414,10 @@ pr -4 -t < $extra | expand | sed 's/^/    /' >> AUTHORS
 
 cat >> AUTHORS <<'EOF'                            
 
-       
+ 
     The manual for GNU Backgammon includes a chapter describing the rules of
       backgammon, written by Tom Keith for his Backgammon Galore web site
-                             <http://www.bkgm.com/>.
+                             <https://www.bkgm.com/>.
 
 
   Library code from the following authors has been included in GNU Backgammon:
@@ -418,7 +425,7 @@ cat >> AUTHORS <<'EOF'
                Austin Appleby (the MurmurHash3 hashing function)
      Ulrich Drepper (an implementation of the public domain MD5 algorithm)
             Bob Jenkins (the ISAAC pseudo random number generator)
-       Takuji Nishimura and Makoto Matsumoto (the Mersenne Twister PRNG)
+         Mutsuo Saito and Makoto Matsumoto (the Mersenne Twister PRNG)
                    Brian Paul (the TR tile rendering library)
              Claes Tornberg (the mec match equity table generator)
 
