@@ -21,6 +21,9 @@
 #ifndef EXTERNAL_H
 #define EXTERNAL_H
 
+#if HAVE_SYS_SOCKET_H
+#include <sys/socket.h>
+#endif
 #include <glib.h>
 #include <glib-object.h>
 #include "backgammon.h"
@@ -198,12 +201,13 @@ typedef struct scancontext {
 
 #else                           /* #ifndef WIN32 */
 #include <winsock2.h>
+#include <ws2tcpip.h>
 #endif                          /* #ifndef WIN32 */
 
 #define EXTERNAL_INTERFACE_VERSION "2"
 #define RFBF_VERSION_SUPPORTED "0"
 
-extern int ExternalSocket(struct sockaddr **ppsa, int *pcb, char *sz);
+extern int ExternalSocket(struct sockaddr **ppsa, socklen_t *pcb, char *sz);
 extern int ExternalRead(int h, char *pch, size_t cch);
 extern int ExternalWrite(int h, char *pch, size_t cch);
 #ifdef WIN32
