@@ -67,7 +67,7 @@
 
 
 /* First part of user prologue.  */
-#line 1 "external_y.y"
+#line 1 "../gnubg/external_y.y"
 
 /*
  * Copyright (C) 2014-2015 Michael Petch <mpetch@gnubg.org>
@@ -291,9 +291,9 @@ extern int yydebug;
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 union YYSTYPE
 {
-#line 114 "external_y.y"
+#line 114 "../gnubg/external_y.y"
 
-    gboolean bool;
+    gboolean boolean;
     gchar character;
     gfloat floatnum;
     gint intnum;
@@ -387,7 +387,7 @@ typedef enum yysymbol_kind_t yysymbol_kind_t;
 
 
 /* Second part of user prologue.  */
-#line 125 "external_y.y"
+#line 125 "../gnubg/external_y.y"
 
 
 #line 394 "external_y.c"
@@ -1408,127 +1408,127 @@ yydestruct (const char *yymsg,
   switch (yykind)
     {
     case YYSYMBOL_E_STRING: /* E_STRING  */
-#line 166 "external_y.y"
+#line 166 "../gnubg/external_y.y"
             { if (((*yyvaluep).str)) g_string_free(((*yyvaluep).str), TRUE); }
 #line 1414 "external_y.c"
         break;
 
     case YYSYMBOL_setcommand: /* setcommand  */
-#line 167 "external_y.y"
+#line 167 "../gnubg/external_y.y"
             { if (((*yyvaluep).list)) g_list_free(((*yyvaluep).list)); }
 #line 1420 "external_y.c"
         break;
 
     case YYSYMBOL_command: /* command  */
-#line 169 "external_y.y"
+#line 169 "../gnubg/external_y.y"
             { if (((*yyvaluep).cmd)) { g_free(((*yyvaluep).cmd)); }}
 #line 1426 "external_y.c"
         break;
 
     case YYSYMBOL_board_element: /* board_element  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1432 "external_y.c"
         break;
 
     case YYSYMBOL_board_elements: /* board_elements  */
-#line 167 "external_y.y"
+#line 167 "../gnubg/external_y.y"
             { if (((*yyvaluep).list)) g_list_free(((*yyvaluep).list)); }
 #line 1438 "external_y.c"
         break;
 
     case YYSYMBOL_sessionoption: /* sessionoption  */
-#line 167 "external_y.y"
+#line 167 "../gnubg/external_y.y"
             { if (((*yyvaluep).list)) g_list_free(((*yyvaluep).list)); }
 #line 1444 "external_y.c"
         break;
 
     case YYSYMBOL_evaloption: /* evaloption  */
-#line 167 "external_y.y"
+#line 167 "../gnubg/external_y.y"
             { if (((*yyvaluep).list)) g_list_free(((*yyvaluep).list)); }
 #line 1450 "external_y.c"
         break;
 
     case YYSYMBOL_sessionoptions: /* sessionoptions  */
-#line 167 "external_y.y"
+#line 167 "../gnubg/external_y.y"
             { if (((*yyvaluep).list)) g_list_free(((*yyvaluep).list)); }
 #line 1456 "external_y.c"
         break;
 
     case YYSYMBOL_evaloptions: /* evaloptions  */
-#line 167 "external_y.y"
+#line 167 "../gnubg/external_y.y"
             { if (((*yyvaluep).list)) g_list_free(((*yyvaluep).list)); }
 #line 1462 "external_y.c"
         break;
 
     case YYSYMBOL_boardcommand: /* boardcommand  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1468 "external_y.c"
         break;
 
     case YYSYMBOL_evalcommand: /* evalcommand  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1474 "external_y.c"
         break;
 
     case YYSYMBOL_board: /* board  */
-#line 167 "external_y.y"
+#line 167 "../gnubg/external_y.y"
             { if (((*yyvaluep).list)) g_list_free(((*yyvaluep).list)); }
 #line 1480 "external_y.c"
         break;
 
     case YYSYMBOL_float_type: /* float_type  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1486 "external_y.c"
         break;
 
     case YYSYMBOL_string_type: /* string_type  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1492 "external_y.c"
         break;
 
     case YYSYMBOL_integer_type: /* integer_type  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1498 "external_y.c"
         break;
 
     case YYSYMBOL_boolean_type: /* boolean_type  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1504 "external_y.c"
         break;
 
     case YYSYMBOL_list_type: /* list_type  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1510 "external_y.c"
         break;
 
     case YYSYMBOL_basic_types: /* basic_types  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1516 "external_y.c"
         break;
 
     case YYSYMBOL_list: /* list  */
-#line 167 "external_y.y"
+#line 167 "../gnubg/external_y.y"
             { if (((*yyvaluep).list)) g_list_free(((*yyvaluep).list)); }
 #line 1522 "external_y.c"
         break;
 
     case YYSYMBOL_list_element: /* list_element  */
-#line 168 "external_y.y"
+#line 168 "../gnubg/external_y.y"
             { if (((*yyvaluep).gv)) { g_value_unsetfree(((*yyvaluep).gv)); }}
 #line 1528 "external_y.c"
         break;
 
     case YYSYMBOL_list_elements: /* list_elements  */
-#line 167 "external_y.y"
+#line 167 "../gnubg/external_y.y"
             { if (((*yyvaluep).list)) g_list_free(((*yyvaluep).list)); }
 #line 1534 "external_y.c"
         break;
@@ -1807,7 +1807,7 @@ yyreduce:
   switch (yyn)
     {
   case 2: /* commands: EOL  */
-#line 174 "external_y.y"
+#line 174 "../gnubg/external_y.y"
         {
             extcmd->ct = COMMAND_NONE;
             YYACCEPT;
@@ -1816,7 +1816,7 @@ yyreduce:
     break;
 
   case 3: /* commands: SET setcommand EOL  */
-#line 180 "external_y.y"
+#line 180 "../gnubg/external_y.y"
         {
             extcmd->pCmdData = (yyvsp[-1].list);
             extcmd->ct = COMMAND_SET;
@@ -1826,7 +1826,7 @@ yyreduce:
     break;
 
   case 4: /* commands: INTERFACEVERSION EOL  */
-#line 187 "external_y.y"
+#line 187 "../gnubg/external_y.y"
         {
             extcmd->ct = COMMAND_VERSION;
             YYACCEPT;
@@ -1835,7 +1835,7 @@ yyreduce:
     break;
 
   case 5: /* commands: HELP EOL  */
-#line 193 "external_y.y"
+#line 193 "../gnubg/external_y.y"
         {
             extcmd->ct = COMMAND_HELP;
             YYACCEPT;
@@ -1844,7 +1844,7 @@ yyreduce:
     break;
 
   case 6: /* commands: EXIT EOL  */
-#line 199 "external_y.y"
+#line 199 "../gnubg/external_y.y"
         {
             extcmd->ct = COMMAND_EXIT;
             YYACCEPT;
@@ -1853,7 +1853,7 @@ yyreduce:
     break;
 
   case 7: /* commands: command EOL  */
-#line 205 "external_y.y"
+#line 205 "../gnubg/external_y.y"
         {
             if ((yyvsp[-1].cmd)->cmdType == COMMAND_LIST) {
                 g_value_unsetfree((yyvsp[-1].cmd)->pvData);
@@ -1908,7 +1908,7 @@ yyreduce:
     break;
 
   case 8: /* setcommand: DEBUG boolean_type  */
-#line 259 "external_y.y"
+#line 259 "../gnubg/external_y.y"
         {
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_DEBUG, (yyvsp[0].gv));
         }
@@ -1916,7 +1916,7 @@ yyreduce:
     break;
 
   case 9: /* setcommand: E_INTERFACE NEW  */
-#line 264 "external_y.y"
+#line 264 "../gnubg/external_y.y"
         {
             GVALUE_CREATE(G_TYPE_INT, int, 1, gvint); 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_NEWINTERFACE, gvint);
@@ -1925,7 +1925,7 @@ yyreduce:
     break;
 
   case 10: /* setcommand: E_INTERFACE OLD  */
-#line 270 "external_y.y"
+#line 270 "../gnubg/external_y.y"
         {
             GVALUE_CREATE(G_TYPE_INT, int, 0, gvint); 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_NEWINTERFACE, gvint);
@@ -1934,7 +1934,7 @@ yyreduce:
     break;
 
   case 11: /* setcommand: PROMPT string_type  */
-#line 276 "external_y.y"
+#line 276 "../gnubg/external_y.y"
         {
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_PROMPT, (yyvsp[0].gv));
         }
@@ -1942,7 +1942,7 @@ yyreduce:
     break;
 
   case 12: /* command: boardcommand  */
-#line 283 "external_y.y"
+#line 283 "../gnubg/external_y.y"
         {
             commandinfo *cmdInfo = g_malloc0(sizeof(commandinfo));
             cmdInfo->pvData = (yyvsp[0].gv);
@@ -1953,7 +1953,7 @@ yyreduce:
     break;
 
   case 13: /* command: evalcommand  */
-#line 291 "external_y.y"
+#line 291 "../gnubg/external_y.y"
         {
             commandinfo *cmdInfo = g_malloc0(sizeof(commandinfo));
             cmdInfo->pvData = (yyvsp[0].gv);
@@ -1964,7 +1964,7 @@ yyreduce:
     break;
 
   case 14: /* command: DISABLED list  */
-#line 299 "external_y.y"
+#line 299 "../gnubg/external_y.y"
         { 
             GVALUE_CREATE(G_TYPE_BOXED_GLIST_GV, boxed, (yyvsp[0].list), gvptr);
             g_list_free((yyvsp[0].list));
@@ -1977,7 +1977,7 @@ yyreduce:
     break;
 
   case 16: /* board_elements: board_element  */
-#line 315 "external_y.y"
+#line 315 "../gnubg/external_y.y"
         { 
             (yyval.list) = g_list_prepend(NULL, (yyvsp[0].gv)); 
         }
@@ -1985,7 +1985,7 @@ yyreduce:
     break;
 
   case 17: /* board_elements: board_elements ':' board_element  */
-#line 320 "external_y.y"
+#line 320 "../gnubg/external_y.y"
         { 
             (yyval.list) = g_list_prepend((yyvsp[-2].list), (yyvsp[0].gv)); 
         }
@@ -1993,7 +1993,7 @@ yyreduce:
     break;
 
   case 19: /* sessionoption: JACOBYRULE boolean_type  */
-#line 331 "external_y.y"
+#line 331 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_JACOBYRULE, (yyvsp[0].gv)); 
         }
@@ -2001,7 +2001,7 @@ yyreduce:
     break;
 
   case 20: /* sessionoption: CRAWFORDRULE boolean_type  */
-#line 336 "external_y.y"
+#line 336 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_CRAWFORDRULE, (yyvsp[0].gv));
         }
@@ -2009,7 +2009,7 @@ yyreduce:
     break;
 
   case 21: /* sessionoption: RESIGNATION integer_type  */
-#line 341 "external_y.y"
+#line 341 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_RESIGNATION, (yyvsp[0].gv));
         }
@@ -2017,7 +2017,7 @@ yyreduce:
     break;
 
   case 22: /* sessionoption: BEAVERS boolean_type  */
-#line 346 "external_y.y"
+#line 346 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_BEAVERS, (yyvsp[0].gv));
         }
@@ -2025,7 +2025,7 @@ yyreduce:
     break;
 
   case 23: /* evaloption: PLIES integer_type  */
-#line 353 "external_y.y"
+#line 353 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_PLIES, (yyvsp[0].gv)); 
         }
@@ -2033,7 +2033,7 @@ yyreduce:
     break;
 
   case 24: /* evaloption: NOISE float_type  */
-#line 358 "external_y.y"
+#line 358 "../gnubg/external_y.y"
         {
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_NOISE, (yyvsp[0].gv)); 
         }
@@ -2041,7 +2041,7 @@ yyreduce:
     break;
 
   case 25: /* evaloption: NOISE integer_type  */
-#line 363 "external_y.y"
+#line 363 "../gnubg/external_y.y"
         {
             float floatval = (float) g_value_get_int((yyvsp[0].gv)) / 10000.0f;
             GVALUE_CREATE(G_TYPE_FLOAT, float, floatval, gvfloat); 
@@ -2052,7 +2052,7 @@ yyreduce:
     break;
 
   case 26: /* evaloption: PRUNE  */
-#line 371 "external_y.y"
+#line 371 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2int_tuple (KEY_STR_PRUNE, TRUE);
         }
@@ -2060,7 +2060,7 @@ yyreduce:
     break;
 
   case 27: /* evaloption: PRUNE boolean_type  */
-#line 376 "external_y.y"
+#line 376 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_PRUNE, (yyvsp[0].gv));
         }
@@ -2068,7 +2068,7 @@ yyreduce:
     break;
 
   case 28: /* evaloption: DETERMINISTIC  */
-#line 381 "external_y.y"
+#line 381 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2int_tuple (KEY_STR_DETERMINISTIC, TRUE);
         }
@@ -2076,7 +2076,7 @@ yyreduce:
     break;
 
   case 29: /* evaloption: DETERMINISTIC boolean_type  */
-#line 386 "external_y.y"
+#line 386 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_DETERMINISTIC, (yyvsp[0].gv));
         }
@@ -2084,7 +2084,7 @@ yyreduce:
     break;
 
   case 30: /* evaloption: CUBE boolean_type  */
-#line 391 "external_y.y"
+#line 391 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2gvalue_tuple (KEY_STR_CUBEFUL, (yyvsp[0].gv));
         }
@@ -2092,7 +2092,7 @@ yyreduce:
     break;
 
   case 31: /* evaloption: CUBEFUL  */
-#line 396 "external_y.y"
+#line 396 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2int_tuple (KEY_STR_CUBEFUL, TRUE); 
         }
@@ -2100,7 +2100,7 @@ yyreduce:
     break;
 
   case 32: /* evaloption: CUBELESS  */
-#line 401 "external_y.y"
+#line 401 "../gnubg/external_y.y"
         { 
             (yyval.list) = create_str2int_tuple (KEY_STR_CUBEFUL, FALSE); 
         }
@@ -2108,7 +2108,7 @@ yyreduce:
     break;
 
   case 33: /* sessionoptions: %empty  */
-#line 408 "external_y.y"
+#line 408 "../gnubg/external_y.y"
         { 
             /* Setup the defaults */
             STR2GV_MAPENTRY_CREATE(KEY_STR_JACOBYRULE, fJacoby, G_TYPE_INT, 
@@ -2129,7 +2129,7 @@ yyreduce:
     break;
 
   case 34: /* sessionoptions: sessionoptions sessionoption  */
-#line 426 "external_y.y"
+#line 426 "../gnubg/external_y.y"
         { 
             STR2GV_MAP_ADD_ENTRY((yyvsp[-1].list), (yyvsp[0].list), (yyval.list)); 
         }
@@ -2137,7 +2137,7 @@ yyreduce:
     break;
 
   case 35: /* evaloptions: %empty  */
-#line 433 "external_y.y"
+#line 433 "../gnubg/external_y.y"
         { 
             /* Setup the defaults */
             STR2GV_MAPENTRY_CREATE(KEY_STR_JACOBYRULE, fJacoby, G_TYPE_INT, 
@@ -2158,7 +2158,7 @@ yyreduce:
     break;
 
   case 36: /* evaloptions: evaloptions evaloption  */
-#line 451 "external_y.y"
+#line 451 "../gnubg/external_y.y"
         { 
             STR2GV_MAP_ADD_ENTRY((yyvsp[-1].list), (yyvsp[0].list), (yyval.list)); 
         }
@@ -2166,7 +2166,7 @@ yyreduce:
     break;
 
   case 37: /* evaloptions: evaloptions sessionoption  */
-#line 456 "external_y.y"
+#line 456 "../gnubg/external_y.y"
         { 
             STR2GV_MAP_ADD_ENTRY((yyvsp[-1].list), (yyvsp[0].list), (yyval.list)); 
         }
@@ -2174,7 +2174,7 @@ yyreduce:
     break;
 
   case 38: /* boardcommand: board sessionoptions  */
-#line 463 "external_y.y"
+#line 463 "../gnubg/external_y.y"
         {
             GVALUE_CREATE(G_TYPE_BOXED_GLIST_GV, boxed, (yyvsp[-1].list), gvptr1);
             GVALUE_CREATE(G_TYPE_BOXED_MAP_GV, boxed, (yyvsp[0].list), gvptr2);
@@ -2189,7 +2189,7 @@ yyreduce:
     break;
 
   case 39: /* evalcommand: EVALUATION FIBSBOARD board evaloptions  */
-#line 477 "external_y.y"
+#line 477 "../gnubg/external_y.y"
         {
             GVALUE_CREATE(G_TYPE_BOXED_GLIST_GV, boxed, (yyvsp[-1].list), gvptr1);
             GVALUE_CREATE(G_TYPE_BOXED_MAP_GV, boxed, (yyvsp[0].list), gvptr2);
@@ -2205,7 +2205,7 @@ yyreduce:
     break;
 
   case 40: /* board: FIBSBOARD E_STRING ':' E_STRING ':' board_elements endboard  */
-#line 492 "external_y.y"
+#line 492 "../gnubg/external_y.y"
         {
             GVALUE_CREATE(G_TYPE_GSTRING, boxed, (yyvsp[-3].str), gvstr1); 
             GVALUE_CREATE(G_TYPE_GSTRING, boxed, (yyvsp[-5].str), gvstr2); 
@@ -2218,7 +2218,7 @@ yyreduce:
     break;
 
   case 41: /* float_type: E_FLOAT  */
-#line 504 "external_y.y"
+#line 504 "../gnubg/external_y.y"
         { 
             GVALUE_CREATE(G_TYPE_FLOAT, float, (yyvsp[0].floatnum), gvfloat); 
             (yyval.gv) = gvfloat; 
@@ -2227,7 +2227,7 @@ yyreduce:
     break;
 
   case 42: /* string_type: E_STRING  */
-#line 512 "external_y.y"
+#line 512 "../gnubg/external_y.y"
         { 
             GVALUE_CREATE(G_TYPE_GSTRING, boxed, (yyvsp[0].str), gvstr); 
             g_string_free ((yyvsp[0].str), TRUE); 
@@ -2237,7 +2237,7 @@ yyreduce:
     break;
 
   case 43: /* integer_type: E_INTEGER  */
-#line 521 "external_y.y"
+#line 521 "../gnubg/external_y.y"
         { 
             GVALUE_CREATE(G_TYPE_INT, int, (yyvsp[0].intnum), gvint); 
             (yyval.gv) = gvint; 
@@ -2246,16 +2246,16 @@ yyreduce:
     break;
 
   case 44: /* boolean_type: E_BOOLEAN  */
-#line 529 "external_y.y"
+#line 529 "../gnubg/external_y.y"
         { 
-            GVALUE_CREATE(G_TYPE_INT, int, (yyvsp[0].bool), gvint); 
+            GVALUE_CREATE(G_TYPE_INT, int, (yyvsp[0].boolean), gvint); 
             (yyval.gv) = gvint; 
         }
 #line 2255 "external_y.c"
     break;
 
   case 45: /* list_type: list  */
-#line 537 "external_y.y"
+#line 537 "../gnubg/external_y.y"
         { 
             GVALUE_CREATE(G_TYPE_BOXED_GLIST_GV, boxed, (yyvsp[0].list), gvptr);
             g_list_free((yyvsp[0].list));
@@ -2265,7 +2265,7 @@ yyreduce:
     break;
 
   case 50: /* list: '(' list_elements ')'  */
-#line 552 "external_y.y"
+#line 552 "../gnubg/external_y.y"
         { 
             (yyval.list) = g_list_reverse((yyvsp[-1].list));
         }
@@ -2273,7 +2273,7 @@ yyreduce:
     break;
 
   case 53: /* list_elements: %empty  */
-#line 563 "external_y.y"
+#line 563 "../gnubg/external_y.y"
         { 
             (yyval.list) = NULL; 
         }
@@ -2281,7 +2281,7 @@ yyreduce:
     break;
 
   case 54: /* list_elements: list_element  */
-#line 568 "external_y.y"
+#line 568 "../gnubg/external_y.y"
         { 
             (yyval.list) = g_list_prepend(NULL, (yyvsp[0].gv));
         }
@@ -2289,7 +2289,7 @@ yyreduce:
     break;
 
   case 55: /* list_elements: list_elements ',' list_element  */
-#line 573 "external_y.y"
+#line 573 "../gnubg/external_y.y"
         { 
             (yyval.list) = g_list_prepend((yyvsp[-2].list), (yyvsp[0].gv)); 
         }
@@ -2521,7 +2521,7 @@ yyreturnlab:
   return yyresult;
 }
 
-#line 577 "external_y.y"
+#line 577 "../gnubg/external_y.y"
 
 
 #ifdef EXTERNAL_TEST
