@@ -851,8 +851,7 @@ OutputCubeAnalysis(float aarOutput[2][NUM_ROLLOUT_OUTPUTS],
 
     if (pci->nMatchTo)
         sprintf(strchr(sz, 0), " %s %s (%s: %s)\n",
-                (!pci->nMatchTo || !fOutputMWC) ?
-                _("cubeless equity") : _("cubeless MWC"),
+                fOutputMWC ? _("cubeless MWC") : _("cubeless equity"),
                 OutputEquity(aarOutput[0][OUTPUT_EQUITY], pci, TRUE),
                 _("Money"), OutputMoneyEquity(aarOutput[0], TRUE));
     else
