@@ -1,11 +1,11 @@
 /*
- * gtkchequer.h
+ * Copyright (C) 2002-2003 Joern Thyssen <jthyssen@dk.ibm.com>
+ * Copyright (C) 2004-2021 the AUTHORS
  *
- * by Joern Thyssen <jthyssen@dk.ibm.com>, 2002
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: gtkchequer.h,v 1.21 2013/06/16 02:16:14 mdpetch Exp $
+ * $Id: gtkchequer.h,v 1.23 2021/10/05 20:58:46 plm Exp $
  */
 
 #ifndef GTKCHEQUER_H
@@ -24,7 +23,7 @@
 
 #include "backgammon.h"
 
-typedef struct _hintdata {
+typedef struct {
     GtkWidget *pwMoves;         /* the movelist */
     GtkWidget *pwRollout, *pwRolloutSettings;   /* rollout buttons */
     GtkWidget *pwEval, *pwEvalSettings; /* evaluation buttons */
@@ -35,6 +34,7 @@ typedef struct _hintdata {
     GtkWidget *pwShow;          /* button for showing moves */
     GtkWidget *pwTempMap;       /* button for showing temperature map */
     GtkWidget *pwCmark;         /* button for marking */
+    GtkWidget *pwScoreMap;      /* button for showing move score map */
     moverecord *pmr;
     movelist *pml;
     int fButtonsValid;
