@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2002-2003 Joern Thyssen <jthyssen@dk.ibm.com>
  * Copyright (C) 2021 Aaron Tikuisis and Isaac Keslassy (MoneyEval)
- * Copyright (C) 2002-2022 the AUTHORS
+ * Copyright (C) 2002-2023 the AUTHORS
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: gtkcube.c,v 1.104 2022/08/30 18:38:35 plm Exp $
+ * $Id: gtkcube.c,v 1.107 2023/03/07 22:29:54 plm Exp $
  */
 
 #include "config.h"
@@ -658,7 +658,7 @@ TakeAnalysis(cubehintdata * pchd)
     /* Jacoby rule */ 
     if (pchd->ms.nMatchTo && pchd->evalAtMoney) {
 
-        GtkWidget *pwJ = gtk_check_button_new_with_label ("Jacoby"); 
+        GtkWidget *pwJ = gtk_check_button_new_with_label(_("Jacoby"));
 
 #if GTK_CHECK_VERSION(3,0,0)
         gtk_grid_attach(GTK_GRID(pwGrid), pwJ, 0, iRow, 2, 1);
@@ -1112,7 +1112,7 @@ GTK_FILL, GTK_EXPAND | GTK_FILL, 8, 4);
     /* Jacoby option - only appears when using money eval */
     if (pchd->evalAtMoney) {
 
-        GtkWidget *pwJ = gtk_check_button_new_with_label ("Jacoby"); 
+        GtkWidget *pwJ = gtk_check_button_new_with_label(_("Jacoby"));
 
 #if GTK_CHECK_VERSION(3,0,0)
         gtk_grid_attach(GTK_GRID(pwGrid), pwJ, 0, iRow, 2, 1);
@@ -1404,10 +1404,12 @@ CubeAnalysisMWC(GtkWidget * pw, cubehintdata * pchd)
 {
 /* Called by GTK when the MWC button is toggled. Switches output between MWC and equity. Only applicable during match play.
 */
+    int f;
+
     g_assert(pchd->ms.nMatchTo);
     g_assert(!pchd->evalAtMoney);
 
-    int f = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pw));
+    f = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pw));
 
     if (f != fOutputMWC) {
         gchar *sz = g_strdup_printf("set output mwc %s", fOutputMWC ? "off" : "on");
@@ -1440,7 +1442,10 @@ GetContent(cubehintdata * pchd)
     else
         GetMoneyCubeInfo(&ci, &pchd->ms);
     
+    // g_message("move type: %d, player: %d",pchd->pmr->mt, pchd->pmr->fPlayer);
+
     switch (pchd->pmr->mt) {
+    case MOVE_NORMAL:    
     case MOVE_DOUBLE:
         fTake = -1;
         break;
@@ -1450,7 +1455,7 @@ GetContent(cubehintdata * pchd)
     case MOVE_TAKE:
         fTake = 1;
         break;
-    default:
+    default: //IK: problem: we get here with a regular {ND|move} ("MOVE_NORMAL") when we click on the cube tab
         g_assert_not_reached();
         return NULL;
     }
@@ -1511,7 +1516,7 @@ CubeAnalysisScoreMap(GtkWidget * UNUSED(pw), cubehintdata * UNUSED(pchd))
 /* Called by GTK when the score map button is clicked.
 */
 
-    UserCommand("show scoremap"); //cf keyword -> gtkgame.c: CMD_SHOW_SCORE_MAP
+    UserCommand("show scoremap"); //cf keyword -> gtkgame.c: CMD_SHOW_SCORE_MAP_CUBE
 
 }
 
@@ -1539,7 +1544,7 @@ CreateCubeAnalysisTools(cubehintdata * pchd)
     GtkWidget *pwTempMap = gtk_button_new_with_label(_("Temp. Map"));
     GtkWidget *pwCmark = pchd->pwCmark = gtk_toggle_button_new_with_label(_("Cmark"));
     GtkWidget *pwMoneyEval = gtk_toggle_button_new_with_label(_("Money Eval"));   
-    GtkWidget *pwScoreMap = gtk_button_new_with_label(_("Score Map"));     
+    GtkWidget *pwScoreMap = gtk_button_new_with_label(_("ScoreMap"));     
     GtkWidget *pw;
     int i;
 
@@ -1584,10 +1589,12 @@ CreateCubeAnalysisTools(cubehintdata * pchd)
 
     for (i = 0; i < 5; ++i) {
 
-        gchar *sz = g_strdup_printf("%d", i);  
+        gchar *sz;  
         int *pi = g_malloc(sizeof(int));
-        *pi=i;
+
+        sz = g_strdup_printf("%d", i);
         GtkWidget *pwply = gtk_button_new_with_label(sz);
+        g_free(sz);
 
 #if GTK_CHECK_VERSION(3,0,0)
         gtk_style_context_add_class(gtk_widget_get_style_context(pwply), "gnubg-analysis-button");
@@ -1596,6 +1603,7 @@ CreateCubeAnalysisTools(cubehintdata * pchd)
 
         g_signal_connect(G_OBJECT(pwply), "clicked", G_CALLBACK(CubeAnalysisEvalPly), pchd);
 
+        *pi = i;
         g_object_set_data_full(G_OBJECT(pwply), "ply", pi, g_free);
 
         sz = g_strdup_printf(_("Evaluate play on cubeful %d-ply"), i);
@@ -1693,14 +1701,29 @@ CreateCubeAnalysisTools(cubehintdata * pchd)
                      (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 0, 0);
 #endif
 
-// Note: evalAtMoney should always be false here.
+    /* We want to disable some buttons particularly when we are in the middle
+       of running an analysis in the background */
+
+    gtk_widget_set_sensitive(pwRollout, !fAnalysisRunning);
+    gtk_widget_set_sensitive(pwEval, !fAnalysisRunning);
+    gtk_widget_set_sensitive(pwEvalSettings, !fAnalysisRunning);
+    gtk_widget_set_sensitive(pw, !fAnalysisRunning);
+    gtk_widget_set_sensitive(pwRolloutSettings, !fAnalysisRunning);
+    gtk_widget_set_sensitive(pwRolloutPresets, !fAnalysisRunning);
+    gtk_widget_set_sensitive(pwCopy, !fAnalysisRunning);
+    gtk_widget_set_sensitive(pwTempMap, !fAnalysisRunning);
+    gtk_widget_set_sensitive(pwScoreMap, !fAnalysisRunning);
+
+
+    // Note: evalAtMoney should always be false here.
     gtk_widget_set_sensitive(pwMWC, pchd->ms.nMatchTo && !pchd->evalAtMoney); //MWC not available in money play, i.e.
                                                 // either in true money play or in a hypothetical one
-    gtk_widget_set_sensitive(pwMoneyEval, pchd->ms.nMatchTo); //i.e., the Money Eval
+    gtk_widget_set_sensitive(pwMoneyEval, pchd->ms.nMatchTo && !fAnalysisRunning); //i.e., the Money Eval
                                                           // button is not available at money play since it doesn't help there
     //gtk_widget_set_sensitive(pwTempMap, !pchd->evalAtMoney);  
     gtk_widget_set_sensitive(pwCmark, !pchd->evalAtMoney);   
 
+
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pwCmark), pchd->pmr->CubeDecPtr->cmark);
 
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(pwMWC), fOutputMWC);
