@@ -1,14 +1,11 @@
 /*
- * gtkfile.c
+ * Copyright (C) 2005 Ingo Macherius
+ * Copyright (C) 2005-2023 the AUTHORS
  *
- * by Ingo Macherius 2005
- *
- * File dialogs
- *
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,10 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- * $Id: gtkfile.c,v 1.72 2017/09/25 19:05:52 plm Exp $
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -42,36 +36,68 @@
 #include "file.h"
 #include "util.h"
 
+/*for picking the first file in folder...*/
+#include <stdio.h>
+#include <dirent.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#include <time.h>
+#include <sys/types.h>
+
+#define MAX_LEN 1024
 
 static void
 FilterAdd(const char *fn, const char *pt, GtkFileChooser * fc)
 {
     GtkFileFilter *aff = gtk_file_filter_new();
+    gchar *sz;
+
     gtk_file_filter_set_name(aff, fn);
     gtk_file_filter_add_pattern(aff, pt);
-    gtk_file_filter_add_pattern(aff, g_ascii_strup(pt, -1));
+    gtk_file_filter_add_pattern(aff, sz = g_ascii_strup(pt, -1));
+    g_free(sz);
     gtk_file_chooser_add_filter(fc, aff);
 }
 
 static GtkWidget *
 GnuBGFileDialog(const gchar * prompt, const gchar * folder, const gchar * name, GtkFileChooserAction action)
 {
-#ifdef WIN32
-    char *programdir, *pc, *tmp;
+#if defined( WIN32)
+    char *programdir, *pc;
 #endif
     GtkWidget *fc;
     switch (action) {
     case GTK_FILE_CHOOSER_ACTION_OPEN:
         fc = gtk_file_chooser_dialog_new(prompt, NULL,
                                          GTK_FILE_CHOOSER_ACTION_OPEN,
+#if GTK_CHECK_VERSION(3,0,0)
+                                         "_Open",
+#else
                                          GTK_STOCK_OPEN,
-                                         GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+#endif
+                                         GTK_RESPONSE_ACCEPT,
+#if GTK_CHECK_VERSION(3,0,0)
+                                         "_Cancel",
+#else
+                                         GTK_STOCK_CANCEL,
+#endif
+                                         GTK_RESPONSE_CANCEL, NULL);
         break;
     case GTK_FILE_CHOOSER_ACTION_SAVE:
         fc = gtk_file_chooser_dialog_new(prompt, NULL,
                                          GTK_FILE_CHOOSER_ACTION_SAVE,
+#if GTK_CHECK_VERSION(3,0,0)
+                                         "_Save",
+#else
                                          GTK_STOCK_SAVE,
-                                         GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+#endif
+                                         GTK_RESPONSE_ACCEPT,
+#if GTK_CHECK_VERSION(3,0,0)
+                                         "_Cancel",
+#else
+                                         GTK_STOCK_CANCEL,
+#endif
+                                         GTK_RESPONSE_CANCEL, NULL);
         break;
     default:
         return NULL;
@@ -81,12 +107,18 @@ GnuBGFileDialog(const gchar * prompt, const gchar * folder, const gchar * name,
 
     if (folder && *folder && g_file_test(folder, G_FILE_TEST_IS_DIR))
         gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(fc), folder);
-    if (name && *name)
-        gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(fc), name);
+    if (name && *name) {
+        if (action == GTK_FILE_CHOOSER_ACTION_OPEN)
+            gtk_file_chooser_set_filename(GTK_FILE_CHOOSER(fc), name);
+        else
+            gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(fc), name);
+    }
 
-#ifdef WIN32
+#if defined(WIN32)
     programdir = g_strdup(getDataDir());
     if ((pc = strrchr(programdir, G_DIR_SEPARATOR)) != NULL) {
+        char *tmp;
+
         *pc = '\0';
 
         tmp = g_build_filename(programdir, "GridGammon", "SaveGame", NULL);
@@ -118,10 +150,12 @@ extern char *
 GTKFileSelect(const gchar * prompt, const gchar * extension, const gchar * folder,
               const gchar * name, GtkFileChooserAction action)
 {
-    gchar *sz, *filename = NULL;
+    gchar *filename = NULL;
     GtkWidget *fc = GnuBGFileDialog(prompt, folder, name, action);
+
     if (extension && *extension) {
-        sz = g_strdup_printf(_("Supported files (%s)"), extension);
+        gchar *sz = g_strdup_printf(_("Supported files (%s)"), extension);
+
         FilterAdd(sz, extension, GTK_FILE_CHOOSER(fc));
         FilterAdd(_("All Files"), "*", GTK_FILE_CHOOSER(fc));
         g_free(sz);
@@ -129,31 +163,40 @@ GTKFileSelect(const gchar * prompt, const gchar * extension, const gchar * folde
 
     if (gtk_dialog_run(GTK_DIALOG(fc)) == GTK_RESPONSE_ACCEPT)
         filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fc));
+
     gtk_widget_destroy(fc);
+
     return filename;
 }
 
-typedef struct _SaveOptions {
+typedef struct {
     GtkWidget *fc, *description, *mgp, *upext;
 } SaveOptions;
 
 static void
 SaveOptionsCallBack(GtkWidget * UNUSED(pw), SaveOptions * pso)
 {
-    gchar *fn, *fnn, *fnd;
     gint type, mgp;
 
     type = gtk_combo_box_get_active(GTK_COMBO_BOX(pso->description));
     mgp = gtk_combo_box_get_active(GTK_COMBO_BOX(pso->mgp));
+
     gtk_dialog_set_response_sensitive(GTK_DIALOG(pso->fc), GTK_RESPONSE_ACCEPT, export_format[type].exports[mgp]);
+
     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(pso->upext))) {
+        gchar *fn;
+
         if ((fn = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(pso->fc))) != NULL) {
-            DisectPath(fn, export_format[type].extension, &fnn, &fnd);
-            gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(pso->fc), fnd);
-            gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(pso->fc), fnn);
+            gchar *fnname, *fndir;
+
+            DisectPath(fn, export_format[type].extension, &fnname, &fndir);
+            gtk_file_chooser_set_current_folder(GTK_FILE_CHOOSER(pso->fc), fndir);
+            gtk_file_chooser_set_current_name(GTK_FILE_CHOOSER(pso->fc), fnname);
+
+            g_free(fnname);
+            g_free(fndir);
+
             g_free(fn);
-            g_free(fnn);
-            g_free(fnd);
         }
     }
 }
@@ -161,15 +204,15 @@ SaveOptionsCallBack(GtkWidget * UNUSED(pw), SaveOptions * pso)
 static void
 SaveCommon(guint f, gchar * prompt)
 {
-
     GtkWidget *hbox;
-    guint i, j, type;
+    guint i;
+    gint j, type;
     SaveOptions so;
     static ExportType last_export_type = EXPORT_SGF;
-    static guint last_export_mgp = 0;
+    static gint last_export_mgp = 0;
     static gchar *last_save_folder = NULL;
     static gchar *last_export_folder = NULL;
-    gchar *fn = GetFilename(TRUE, (f == 1) ? EXPORT_SGF : last_export_type);
+    gchar *fn = GetFilename(TRUE, (f == 1) ? EXPORT_SGF : last_export_type, TRUE);
     gchar *folder = NULL;
     const gchar *mgp_text[3] = { "match", "game", "position" };
 
@@ -248,10 +291,15 @@ static void
 selection_changed_cb(GtkFileChooser * file_chooser, void *UNUSED(notused))
 {
     const char *label;
-    char *buf;
-    char *filename = gtk_file_chooser_get_filename(file_chooser);
-    FilePreviewData *fpd = ReadFilePreview(filename);
+    gchar *buf;
+    gchar *filename;
+    FilePreviewData *fpd;
     int openable = FALSE;
+
+    filename = gtk_file_chooser_get_filename(file_chooser);
+    fpd = ReadFilePreview(filename);
+    g_free(filename);
+
     if (!fpd) {
         lastOpenType = N_IMPORT_TYPES;
         label = "";
@@ -274,13 +322,14 @@ add_import_filters(GtkFileChooser * fc)
 {
     GtkFileFilter *aff = gtk_file_filter_new();
     gint i;
-    gchar *sg;
+    gchar *sg, *sz;
 
     gtk_file_filter_set_name(aff, _("Supported files"));
     for (i = 0; i < N_IMPORT_TYPES; ++i) {
         sg = g_strdup_printf("*%s", import_format[i].extension);
         gtk_file_filter_add_pattern(aff, sg);
-        gtk_file_filter_add_pattern(aff, g_ascii_strup(sg, -1));
+        gtk_file_filter_add_pattern(aff, sz = g_ascii_strup(sg, -1));
+        g_free(sz);
         g_free(sg);
     }
     gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(fc), aff);
@@ -347,14 +396,14 @@ GTKOpen(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
 {
     GtkWidget *fc;
     GtkWidget *type_combo, *box, *box2;
-    gchar *fn;
     gchar *folder = NULL;
     gint import_type;
     static gchar *last_import_folder = NULL;
+    static gchar *last_import_file = NULL;
 
     folder = last_import_folder ? last_import_folder : default_import_folder;
 
-    fc = GnuBGFileDialog(_("Open backgammon file"), folder, NULL, GTK_FILE_CHOOSER_ACTION_OPEN);
+    fc = GnuBGFileDialog(_("Open backgammon file"), folder, last_import_file, GTK_FILE_CHOOSER_ACTION_OPEN);
 
     type_combo = import_types_combo();
     g_signal_connect(type_combo, "changed", G_CALLBACK(OpenTypeChanged), fc);
@@ -390,10 +439,13 @@ GTKOpen(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
     autoOpen = TRUE;
 
     if (gtk_dialog_run(GTK_DIALOG(fc)) == GTK_RESPONSE_ACCEPT) {
-        fn = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fc));
+        gchar *fn = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fc));
+	
         import_type = gtk_combo_box_get_active(GTK_COMBO_BOX(type_combo));
         if (import_type == 0) { /* Type automatically based on file */
-            do_import_file(lastOpenType, fn);
+            do_import_file((gint)lastOpenType, fn);
+	    g_free(last_import_file);
+	    last_import_file = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fc));
         } else {
             import_type--;      /* Ignore auto option */
             if (import_type == N_IMPORT_TYPES) {        /* Load command file */
@@ -407,6 +459,8 @@ GTKOpen(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
                 g_free(cmd);
             } else {            /* Import as specific type */
                 do_import_file(import_type, fn);
+		g_free(last_import_file);
+		last_import_file = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fc));
             }
         }
 
@@ -456,7 +510,17 @@ batch_create_save(gchar * filename, gchar ** save, char **result)
     gchar *file;
     gchar *folder;
     gchar *dir;
+
     DisectPath(filename, NULL, &file, &folder);
+    
+    if (file == NULL || folder == NULL) {
+	g_free(file);
+	g_free(folder);
+	if (result)
+            *result = _("Incorrect path");
+	return FALSE;
+    }
+ 
     dir = g_build_filename(folder, "analysed", NULL);
     g_free(folder);
 
@@ -464,15 +528,17 @@ batch_create_save(gchar * filename, gchar ** save, char **result)
         g_mkdir(dir, 0700);
 
     if (!g_file_test(dir, G_FILE_TEST_IS_DIR)) {
+        g_free(file);
         g_free(dir);
         if (result)
-            *result = _("Failed to make directory");
+            *result = _("Failed to create directory");
         return FALSE;
     }
 
     *save = g_strconcat(dir, G_DIR_SEPARATOR_S, file, ".sgf", NULL);
     g_free(file);
     g_free(dir);
+
     return TRUE;
 }
 
@@ -489,12 +555,11 @@ batch_analyse(gchar * filename, char **result, gboolean add_to_db, gboolean add_
     printf("save %s\n", save);
 
     if (g_file_test((save), G_FILE_TEST_EXISTS)) {
-        *result = _("Previous");
+        *result = _("Pre-existing");
         g_free(save);
         return TRUE;
     }
 
-
     g_free(szCurrentFileName);
     szCurrentFileName = NULL;
     cmd = g_strdup_printf("import auto \"%s\"", filename);
@@ -549,7 +614,7 @@ batch_do_all(gpointer batch_model, gboolean add_to_db, gboolean add_incdata_to_d
         gchar *filename;
         gint cancelled;
         gtk_tree_model_get(batch_model, &iter, COL_PATH, &filename, -1);
-
+        //outputerrf("filename=%s\n", filename);
         batch_analyse(filename, &result, add_to_db, add_incdata_to_db);
         gtk_list_store_set(batch_model, &iter, COL_RESULT, result, -1);
 
@@ -590,7 +655,6 @@ batch_create_model(GSList * filenames)
     GtkListStore *store;
     GtkTreeIter tree_iter;
     GSList *iter;
-    FilePreviewData *fpd;
 
     store = gtk_list_store_new(NUM_COLS, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
@@ -599,6 +663,7 @@ batch_create_model(GSList * filenames)
         char *folder;
         char *file;
         char *filename = (char *) iter->data;
+        FilePreviewData *fpd;
 
         gtk_list_store_append(store, &tree_iter);
 
@@ -635,9 +700,9 @@ batch_create_view(GSList * filenames)
     gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(view),
                                                 -1, _("Result"), renderer, "text", COL_RESULT, NULL);
 
-    gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(view), -1, _("Type"), renderer, "text", COL_DESC, NULL);
+    gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(view), -1, Q_("fileType|Type"), renderer, "text", COL_DESC, NULL);
 
-    gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(view), -1, ("File"), renderer, "text", COL_FILE, NULL);
+    gtk_tree_view_insert_column_with_attributes(GTK_TREE_VIEW(view), -1, _("File"), renderer, "text", COL_FILE, NULL);
     model = batch_create_model(filenames);
 
     gtk_tree_view_set_model(GTK_TREE_VIEW(view), model);
@@ -754,6 +819,175 @@ batch_create_dialog_and_run(GSList * filenames, gboolean add_to_db)
     gtk_window_set_modal(GTK_WINDOW(dialog), FALSE);
 }
 
+extern void
+GTKAnalyzeCurrent(void)
+{
+    /*analyze match*/
+    UserCommand("analyse match");
+    if (fAutoDB) {
+        /*add match to db*/
+        CommandRelationalAddMatch(NULL);
+    }
+    /*show stats panel*/
+    UserCommand("show statistics match");
+    return;
+}
+
+/* functions to find latest file in folder */
+
+static void recentByModification(const char* path, char* recent){
+    char buffer[MAX_LEN];
+    FilePreviewData *fdp;
+    struct dirent* entry;
+    time_t recenttime = 0;
+    struct stat statbuf;
+    DIR* dir  = opendir(path);
+
+    if (dir) {
+        while (NULL != (entry = readdir(dir))) {
+           // outputerrf(_("`%s' ... looking at file....: %s, time: %lld"), entry->d_name, recent, (long long)recenttime);
+
+            /* we first check that it's a file*/
+            if(strcmp(entry->d_name, ".") == 0 || strcmp(entry->d_name, "..") == 0 || strncmp(entry->d_name, "/", 1) == 0 || strncmp(entry->d_name, "\\", 1) == 0)
+                continue;
+            /* check file type when DIRENT is defined; could use stat if not*/
+#ifdef _DIRENT_HAVE_D_TYPE
+            if (entry->d_type == DT_REG) 
+// #else
+//             DIR* dir2 = opendir(entry);
+//             if(dir2==NULL) {
+#endif 
+            {    
+                /* we then check that it's more recent than what we've seen so far*/
+                sprintf(buffer, "%s/%s", path, entry->d_name);
+                stat(buffer, &statbuf);            
+                if (statbuf.st_mtime > recenttime) {
+                    /* next we check that it's a correct file format*/
+                    fdp = ReadFilePreview(buffer);
+                    if (!fdp) {
+                        //outputerrf(_("`%s' is not a backgammon file (especially %s)... looking at file....: %s, time: %lld"), buffer,entry->d_name, recent, (long long) recenttime);
+                        g_free(fdp);
+                        continue;
+                    } else if (fdp->type == N_IMPORT_TYPES) {
+                        //outputerrf(_("The format of '%s' is not recognized  (especially %s)"), buffer,entry->d_name);
+                        g_free(fdp);
+                        continue;
+                    } else {
+                        /* finally it passed all the checks, we keep it for now in the char * recent */
+                        strncpy(recent, buffer, MAX_LEN);
+                        // strncpy(recent, entry->d_name, MAX_LEN);
+                        recenttime = statbuf.st_mtime;
+                        // g_message("looking at file....: %s, time: %lld\n", recent, (long long) recenttime);
+                        g_free(fdp);
+                    }
+                }
+            }
+        }
+        closedir(dir);
+    } else {
+        outputerrf("Unable to read the directory");
+    }
+}
+
+static void
+AnalyzeSingleFile(void)
+{
+    gchar *folder = NULL;
+    gchar *filename = NULL;
+    GtkWidget *fc;
+    static gchar *last_folder = NULL;
+
+    folder = last_folder ? last_folder : default_import_folder;
+
+    /* now select a file; could also use GTKFileSelect() */
+    fc = GnuBGFileDialog(_("Select file to analyse"), folder, NULL, GTK_FILE_CHOOSER_ACTION_OPEN);
+    gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(fc), FALSE);
+    add_import_filters(GTK_FILE_CHOOSER(fc));
+
+    if (gtk_dialog_run(GTK_DIALOG(fc)) == GTK_RESPONSE_ACCEPT) {
+        filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(fc));
+    }
+    if (filename) {
+        gchar* cmd;
+
+        g_free(last_folder);
+        last_folder = gtk_file_chooser_get_current_folder(GTK_FILE_CHOOSER(fc));
+        gtk_widget_destroy(fc);
+
+        // char buffer[MAX_LEN];
+        // sprintf(buffer, "%s/%s", last_folder, filename);
+        // // if (!get_input_discard())
+        // //     return;
+
+        /*open this file*/
+        cmd = g_strdup_printf("import auto \"%s\"", filename);
+        UserCommand(cmd);
+        g_free(cmd);
+        ////outputerrf("filename=%s\n", filename);
+        //CommandImportAuto(filename);
+        g_free(filename);
+
+        /*analyze match*/
+        UserCommand("analyse match");
+        if(fAutoDB) {
+            /*add match to db*/
+            CommandRelationalAddMatch(NULL);
+        }
+        /*show stats panel*/
+        UserCommand("show statistics match");
+        return;
+
+    } else
+        gtk_widget_destroy(fc);
+}
+
+
+static void
+SmartAnalyze(void)
+{
+    gchar *folder = NULL;
+    gchar *cmd;
+    char recent[MAX_LEN] = "";
+
+    folder = default_import_folder ? default_import_folder : ".";
+    // g_message("folder=%s\n", folder);
+
+    /* find most recent file in the folder and write its name (in char recent[])*/
+    recentByModification(folder, recent);
+
+    /*open this file*/
+    cmd = g_strdup_printf("import auto \"%s\"", recent);
+    UserCommand(cmd);
+    g_free(cmd);
+
+    //outputerrf("recent=%s\n", recent);
+    //CommandImportAuto(recent);
+
+    /*analyze match*/
+    UserCommand("analyse match");
+    if(fAutoDB) {
+        /*add match to db*/
+        CommandRelationalAddMatch(NULL);
+    }
+    /*show stats panel*/
+    UserCommand("show statistics match");
+    return;
+}
+
+extern void
+GTKAnalyzeFile(void)
+{
+    // g_message("GTKAnalyzeFile(): %d\n", AnalyzeFileSettingDef);
+    if (AnalyzeFileSettingDef == AnalyzeFileBatch) {
+        GTKBatchAnalyse(NULL, 0, NULL);
+    } else if (AnalyzeFileSettingDef == AnalyzeFileRegular) {
+        AnalyzeSingleFile();
+    } else { //   AnalyzeFileSmart, 
+        SmartAnalyze();
+    }
+    return;
+}
+
 extern void
 GTKBatchAnalyse(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
 {
@@ -771,7 +1005,7 @@ GTKBatchAnalyse(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
     add_import_filters(GTK_FILE_CHOOSER(fc));
 
     add_to_db = gtk_check_button_new_with_label(_("Add to database"));
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(add_to_db), TRUE);
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(add_to_db), fAutoDB);
 
     gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(fc), add_to_db);
 
@@ -796,5 +1030,4 @@ GTKBatchAnalyse(gpointer UNUSED(p), guint UNUSED(n), GtkWidget * UNUSED(pw))
         fConfirmNew = fConfirmNew_s;
     } else
         gtk_widget_destroy(fc);
-
 }
