@@ -1,11 +1,11 @@
 /*
- * gtkgame.h
+ * Copyright (C) 2000-2003 Gary Wong <gtw@gnu.org>
+ * Copyright (C) 2001-2016 the AUTHORS
  *
- * by Gary Wong <gtw@gnu.org>, 2000, 2002.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: gtkgame.h,v 1.161 2018/06/10 19:13:33 plm Exp $
+ * $Id: gtkgame.h,v 1.165 2023/11/20 21:00:06 plm Exp $
  */
 
 #ifndef GTKGAME_H
@@ -30,7 +29,7 @@
 
 #define TOOLBAR_ACTION_OFFSET 10000
 
-#if defined(USE_GTKUIMANAGER)
+#if !defined(USE_GTKITEMFACTORY)
 extern GtkUIManager *puim;
 #endif
 
@@ -165,15 +164,14 @@ extern void ShowList(char *asz[], const char *szTitle, GtkWidget * parent);
 extern void ShowMove(hintdata * phd, const int f);
 extern void SwapBoardToPanel(int ToPanel, int updateEvents);
 extern void DoHideAllPanels(int updateEvents);
-#if defined(USE_GTKUIMANAGER)
+#if defined(USE_GTKITEMFACTORY)
+extern void ToggleDockPanels(gpointer p, guint n, GtkWidget * pw);
+#else
 extern void ToggleEdit(GtkToggleAction * action, gpointer user_data);
 extern void ToggleClockwise(GtkToggleAction * action, gpointer user_data);
 extern void ToggleDockPanels(GtkToggleAction * action, gpointer user_data);
-#else
-extern void ToggleDockPanels(gpointer p, guint n, GtkWidget * pw);
 #endif
 extern void GTKUndo(void);
-extern void UserCommand(const char *szCommand);
 extern void ShowToolbar(void);
 extern void HideToolbar(void);
 extern void MoveListDestroy(void);
@@ -185,7 +183,9 @@ extern void ProcessInput(char *sz);
 
 #if defined(USE_BOARD3D)
 extern void SetSwitchModeMenuText(void);
-#include "inc3d.h"
 #endif
 
+extern void AddText(GtkWidget* pwBox, char* Text);
+extern void drawArrow (cairo_t *cr, double start_x, double start_y, double end_x, double end_y);
+
 #endif
