@@ -1,7 +1,11 @@
 /*
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * Copyright (C) 2006 Jon Kinsey <jonkinsey@gmail.com>
+ * Copyright (C) 2008 the AUTHORS
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -9,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: gtkpanels.h,v 1.7 2013/06/16 02:16:16 mdpetch Exp $
+ * $Id: gtkpanels.h,v 1.8 2020/02/23 21:00:47 plm Exp $
  */
 
 /* position of windows: main window, game list, and annotation */
@@ -20,7 +23,7 @@
 #ifndef GTKPANELS_H
 #define GTKPANELS_H
 
-typedef enum _gnubgwindow {
+typedef enum {
     WINDOW_MAIN = 0,
     WINDOW_GAME,
     WINDOW_ANALYSIS,
@@ -32,7 +35,7 @@ typedef enum _gnubgwindow {
     NUM_WINDOWS
 } gnubgwindow;
 
-typedef struct _windowgeometry {
+typedef struct {
     int nWidth, nHeight;
     int nPosX, nPosY, max;
 } windowgeometry;
