@@ -1,14 +1,11 @@
 /*
- * gtktempmap.c
+ * Copyright (C) 2002-2003 Joern Thyssen <jth@gnubg.org>
+ * Copyright (C) 2003-2022 the AUTHORS
  *
- * by Joern Thyssen <jth@gnubg.org>, 2003
- *
- * Based on Sho Sengoku's Equity Temperature Map
- * http://www46.pair.com/sengoku/TempMap/English/TempMap.html
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -16,14 +13,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: gtktempmap.c,v 1.58 2018/07/01 20:39:10 plm Exp $
+ * $Id: gtktempmap.c,v 1.65 2022/09/02 13:43:30 plm Exp $
+ */
+
+/*
+ * Based on Sho Sengoku's Equity Temperature Map
+ * https://bkgm.com/articles/Sengoku/TemperatureMap/index.html 
  */
 
 #include "config.h"
-#include "gtklocdefs.h"
 
 #include <gtk/gtk.h>
 
@@ -42,11 +42,12 @@
 #include "renderprefs.h"
 #include "gtkboard.h"
 #include "gtkwindows.h"
+#include "gtkcube.h"
 
 #define SIZE_QUADRANT 52
 
 
-typedef struct _tempmap {
+typedef struct {
 
     matchstate *pms;
     float aarEquity[6][6];
@@ -65,7 +66,7 @@ typedef struct _tempmap {
 } tempmap;
 
 
-typedef struct _tempmapwidget {
+typedef struct {
 
     unsigned char *achDice[2];
     unsigned char *achPips[2];
@@ -87,11 +88,10 @@ static int fShowEquity = FALSE;
 static int fShowBestMove = FALSE;
 
 static int
-TempMapEquities(evalcontext * pec, matchstate * pms,
+TempMapEquities(evalcontext * pec, const matchstate * pms,
                 float aarEquity[6][6], int aaanMove[6][6][8], const gchar * szTitle, const float rFac)
 {
 
-
     int i, j;
     float arOutput[NUM_ROLLOUT_OUTPUTS];
     TanBoard anBoard;
@@ -150,8 +150,6 @@ TempMapEquities(evalcontext * pec, matchstate * pms,
 
         }
 
-
-
     ProgressEnd();
 
     memcpy(aarEquity, aar, sizeof aar);
@@ -212,7 +210,7 @@ SetStyle(GtkWidget * pw, const float rEquity, const float rMin, const float rMax
 
 
 static char *
-GetEquityString(const float rEquity, cubeinfo * pci, const int fInvert)
+GetEquityString(const float rEquity, const cubeinfo * pci, const int fInvert)
 {
 
     float r;
@@ -246,7 +244,7 @@ UpdateTempMapEquities(tempmapwidget * ptmw)
     float rMax, rMin, r;
     cubeinfo ci;
     int m;
-    char szMove[100];
+    char szMove[FORMATEDMOVESIZE];
 
     /* calc. min, max and average */
 
@@ -273,7 +271,6 @@ UpdateTempMapEquities(tempmapwidget * ptmw)
 
     GetMatchStateCubeInfo(&ci, ptmw->atm[0].pms);
 
-
     for (m = 0; m < ptmw->n; ++m) {
         for (i = 0; i < 6; ++i)
             for (j = 0; j < 6; ++j) {
@@ -284,7 +281,6 @@ UpdateTempMapEquities(tempmapwidget * ptmw)
                                             FormatMove(szMove, (ConstTanBoard) ptmw->atm[m].pms->anBoard,
                                                        ptmw->atm[m].aaanMove[i][j]));
 
-
                 SetStyle(ptmw->atm[m].aapwDA[i][j], ptmw->atm[m].aarEquity[i][j], rMin, rMax, ptmw->fInvert);
 
                 gtk_widget_set_tooltip_text(ptmw->atm[m].aapwe[i][j], sz);
@@ -310,11 +306,10 @@ UpdateTempMapEquities(tempmapwidget * ptmw)
 static gboolean
 DrawQuadrant(GtkWidget * pw, cairo_t * cr, tempmapwidget * ptmw)
 {
-    int *pi = (int *) g_object_get_data(G_OBJECT(pw), "user_data");
+    const int *pi = (int *) g_object_get_data(G_OBJECT(pw), "user_data");
     int i = 0;
     int j = 0;
     int m = 0;
-    float r = 0.0f;
     cubeinfo ci;
     PangoLayout *layout;
     PangoFontDescription *description;
@@ -325,19 +320,17 @@ DrawQuadrant(GtkWidget * pw, cairo_t * cr, tempmapwidget * ptmw)
     gtk_widget_get_allocation(pw, &allocation);
 
 #if GTK_CHECK_VERSION(3,0,0)
-    {
-        double *gbval = g_object_get_data(G_OBJECT(pw), "gbval");
-        guint width, height;
+    double *gbval = g_object_get_data(G_OBJECT(pw), "gbval");
+    guint width, height;
 
-        width = gtk_widget_get_allocated_width(pw);
-        height = gtk_widget_get_allocated_height(pw);
+    width = gtk_widget_get_allocated_width(pw);
+    height = gtk_widget_get_allocated_height(pw);
 
-        cairo_rectangle(cr, 0, 0, width, height);
-        cairo_set_source_rgb(cr, 1.0, *gbval, *gbval);
-        cairo_fill(cr);
+    cairo_rectangle(cr, 0, 0, width, height);
+    cairo_set_source_rgb(cr, 1.0, *gbval, *gbval);
+    cairo_fill(cr);
 
-        gtk_render_frame(gtk_widget_get_style_context(pw), cr, 0, 0, width, height);
-    }
+    gtk_render_frame(gtk_widget_get_style_context(pw), cr, 0, 0, width, height);
 #else
     (void) cr;                  /* silence compiler warning */
     gtk_paint_box(gtk_widget_get_style(pw), gtk_widget_get_window(pw), GTK_STATE_NORMAL,
@@ -358,11 +351,13 @@ DrawQuadrant(GtkWidget * pw, cairo_t * cr, tempmapwidget * ptmw)
     str = g_string_new("");
 
     if (ptmw->fShowEquity) {
+        float r = 0.0f;
+
         if (j >= 0)
             r = ptmw->atm[m].aarEquity[i][j];
         else if (j == -1)
             r = ptmw->atm[m].rAverage;
-        GetMatchStateCubeInfo(&ci, ptmw->atm[m].pms);
+        GetMatchStateCubeInfo(&ci, ptmw->atm[0].pms);
         tmp = GetEquityString(r, &ci, ptmw->fInvert);
         while (*tmp == ' ')
             tmp++;
@@ -373,8 +368,9 @@ DrawQuadrant(GtkWidget * pw, cairo_t * cr, tempmapwidget * ptmw)
     /* move */
 
     if (j >= 0 && ptmw->fShowBestMove) {
-        char szMove[100];
-        FormatMovePlain(szMove, ptmw->atm[m].pms->anBoard, ptmw->atm[m].aaanMove[i][j]);
+        char szMove[FORMATEDMOVESIZE];
+
+        FormatMovePlain(szMove, (ConstTanBoard)ptmw->atm[m].pms->anBoard, ptmw->atm[m].aaanMove[i][j]);
         if (ptmw->fShowEquity)
             g_string_append_printf(str, " %s", szMove);
         else
@@ -390,9 +386,9 @@ DrawQuadrant(GtkWidget * pw, cairo_t * cr, tempmapwidget * ptmw)
     if (ptmw->fShowEquity && j >= 0 && ptmw->fShowBestMove)
         y = 2;
     else if (ptmw->fShowEquity)
-        y = (allocation.height - 4) / 2.0f;
+        y = (float)(allocation.height - 4) / 2.0f;
     else
-        y = 2 + (allocation.height - 4) / 10.0f;
+        y = 2 + (float)(allocation.height - 4) / 10.0f;
 
     description = pango_font_description_from_string("sans");
     pango_font_description_set_size(description, allocation.height * PANGO_SCALE / 8);
@@ -403,11 +399,15 @@ DrawQuadrant(GtkWidget * pw, cairo_t * cr, tempmapwidget * ptmw)
         if (tmp)
             *tmp = 0;
         pango_layout_set_text(layout, pch, -1);
-        gtk_locdef_paint_layout(gtk_widget_get_style(pw), gtk_widget_get_window(pw), cr,
+#if GTK_CHECK_VERSION(3,0,0)
+        gtk_render_layout(gtk_widget_get_style_context(pw), cr, 2.0, (double)y, layout);
+#else
+        gtk_paint_layout(gtk_widget_get_style(pw), gtk_widget_get_window(pw),
                                 GTK_STATE_NORMAL, TRUE, NULL, pw, NULL, 2, (int) y, layout);
+#endif
         if (tmp) {
             pch = tmp + 1;
-            y += (allocation.height - 4) / 5.0f;
+            y += (float)(allocation.height - 4) / 5.0f;
         }
     } while (tmp);
 
@@ -430,7 +430,7 @@ ExposeQuadrant(GtkWidget * pw, GdkEventExpose * UNUSED(pev), tempmapwidget * ptm
 static void
 ExposeDieArea(GtkWidget * pw, cairo_t * cr, gint area_x, gint area_y, gint area_width, gint area_height, tempmapwidget * ptmw)
 {
-    int *pi = (int *) g_object_get_data(G_OBJECT(pw), "user_data");
+    const int *pi = (int *) g_object_get_data(G_OBJECT(pw), "user_data");
     int x, y;
     int nSizeDie;
     GtkAllocation allocation;
@@ -495,7 +495,7 @@ ExposeDie(GtkWidget * pw, GdkEventExpose * pev, tempmapwidget * ptmw)
 static void
 TempMapPlyToggled(GtkWidget * pw, tempmapwidget * ptmw)
 {
-    int *pi = (int *) g_object_get_data(G_OBJECT(pw), "user_data");
+    const int *pi = (int *) g_object_get_data(G_OBJECT(pw), "user_data");
 
     evalcontext ec = { TRUE, 0, FALSE, TRUE, 0.0 };
 
@@ -576,19 +576,29 @@ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const in
     int i, j;
 
     GtkWidget *pwDialog;
-    GtkWidget *pwTable = NULL;
     GtkWidget *pwv;
     GtkWidget *pw;
     GtkWidget *pwh;
     GtkWidget *pwx = NULL;
+#if GTK_CHECK_VERSION(3,0,0)
+    GtkWidget *pwOuterGrid;
+    GtkWidget *pwGrid = NULL;
+#else
     GtkWidget *pwOuterTable;
+    GtkWidget *pwTable = NULL;
+#endif
 
     int k, l, km, lm, m;
 
     /* dialog */
-
-    pwDialog = GTKCreateDialog(_("Sho Sengoku Temperature Map - Distribution of rolls"),
+    if (!cubeTempMapAtMoney) {
+        pwDialog = GTKCreateDialog(_("Sho Sengoku Temperature Map - Distribution of Rolls"),
                                DT_INFO, NULL, DIALOG_FLAG_MODAL, NULL, NULL);
+    } else {
+        pwDialog = GTKCreateDialog(_("Temperature Map in Hypothetical Money Play"),
+                               DT_INFO, NULL, DIALOG_FLAG_MODAL, NULL, NULL);
+    }
+                               
 
     ptmw = (tempmapwidget *) g_malloc(sizeof(tempmapwidget));
     ptmw->fShowBestMove = fShowBestMove;
@@ -623,8 +633,15 @@ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const in
 
     for (km = 1; km * lm < n; ++km);
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwOuterGrid = gtk_grid_new();
+    gtk_grid_set_column_homogeneous(GTK_GRID(pwOuterGrid), TRUE);
+    gtk_grid_set_row_homogeneous(GTK_GRID(pwOuterGrid), TRUE);
+    gtk_box_pack_start(GTK_BOX(pwv), pwOuterGrid, TRUE, TRUE, 0);
+#else
     pwOuterTable = gtk_table_new(km, lm, TRUE);
     gtk_box_pack_start(GTK_BOX(pwv), pwOuterTable, TRUE, TRUE, 0);
+#endif
 
     for (k = m = 0; k < km; ++k)
         for (l = 0; l < lm && m < n; ++l, ++m) {
@@ -635,9 +652,19 @@ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const in
 
             pw = gtk_frame_new(ptm->szTitle);
 
+#if GTK_CHECK_VERSION(3,0,0)
+            gtk_grid_attach(GTK_GRID(pwOuterGrid), pw, l, k, 1, 1);
+
+            pwGrid = gtk_grid_new();
+            gtk_grid_set_column_homogeneous(GTK_GRID(pwGrid), TRUE);
+            gtk_grid_set_row_homogeneous(GTK_GRID(pwGrid), TRUE);
+            gtk_container_add(GTK_CONTAINER(pw), pwGrid);
+#else
             gtk_table_attach_defaults(GTK_TABLE(pwOuterTable), pw, l, l + 1, k, k + 1);
 
-            gtk_container_add(GTK_CONTAINER(pw), pwTable = gtk_table_new(7, 7, TRUE));
+            pwTable = gtk_table_new(7, 7, TRUE);
+            gtk_container_add(GTK_CONTAINER(pw), pwTable);
+#endif
 
             /* drawing areas */
 
@@ -652,7 +679,11 @@ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const in
 
                     gtk_widget_set_size_request(ptm->aapwDA[i][j], SIZE_QUADRANT, SIZE_QUADRANT);
 
+#if GTK_CHECK_VERSION(3,0,0)
+                    gtk_grid_attach(GTK_GRID(pwGrid), ptm->aapwe[i][j], i + 1, j + 1, 1, 1);
+#else
                     gtk_table_attach_defaults(GTK_TABLE(pwTable), ptm->aapwe[i][j], i + 1, i + 2, j + 1, j + 2);
+#endif
 
                     pi = (int *) g_malloc(sizeof(int));
                     *pi = i * 6 + j + m * 100;
@@ -671,7 +702,11 @@ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const in
                 pw = gtk_drawing_area_new();
                 gtk_widget_set_size_request(pw, SIZE_QUADRANT, SIZE_QUADRANT);
 
+#if GTK_CHECK_VERSION(3,0,0)
+                gtk_grid_attach(GTK_GRID(pwGrid), pw, 0, i + 1, 1, 1);
+#else
                 gtk_table_attach_defaults(GTK_TABLE(pwTable), pw, 0, 1, i + 1, i + 2);
+#endif
 
                 pi = (int *) g_malloc(sizeof(int));
                 *pi = i;
@@ -688,7 +723,11 @@ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const in
                 pw = gtk_drawing_area_new();
                 gtk_widget_set_size_request(pw, SIZE_QUADRANT, SIZE_QUADRANT);
 
+#if GTK_CHECK_VERSION(3,0,0)
+                gtk_grid_attach(GTK_GRID(pwGrid), pw, i + 1, 0, 1, 1);
+#else
                 gtk_table_attach_defaults(GTK_TABLE(pwTable), pw, i + 1, i + 2, 0, 1);
+#endif
 
                 pi = (int *) g_malloc(sizeof(int));
                 *pi = i;
@@ -713,7 +752,11 @@ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const in
 
             gtk_widget_set_size_request(ptm->pwAverage, SIZE_QUADRANT, SIZE_QUADRANT);
 
+#if GTK_CHECK_VERSION(3,0,0)
+            gtk_grid_attach(GTK_GRID(pwGrid), ptm->pweAverage, 0, 0, 1, 1);
+#else
             gtk_table_attach_defaults(GTK_TABLE(pwTable), ptm->pweAverage, 0, 1, 0, 1);
+#endif
 
             pi = (int *) g_malloc(sizeof(int));
             *pi = -m - 1;
@@ -739,15 +782,25 @@ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const in
 
     /* gauge */
 
+#if GTK_CHECK_VERSION(3,0,0)
+    pwGrid = gtk_grid_new();
+    gtk_box_pack_start(GTK_BOX(pwv), pwGrid, FALSE, FALSE, 0);
+#else
     pwTable = gtk_table_new(2, 16, FALSE);
     gtk_box_pack_start(GTK_BOX(pwv), pwTable, FALSE, FALSE, 0);
+#endif
 
     for (i = 0; i < 16; ++i) {
 
         pw = gtk_drawing_area_new();
         gtk_widget_set_size_request(pw, 15, 20);
 
+#if GTK_CHECK_VERSION(3,0,0)
+        gtk_grid_attach(GTK_GRID(pwGrid), pw, i, 1, 1, 1);
+        gtk_widget_set_hexpand(pw, TRUE);
+#else
         gtk_table_attach_defaults(GTK_TABLE(pwTable), pw, i, i + 1, 1, 2);
+#endif
 
         g_object_set_data(G_OBJECT(pw), "user_data", NULL);
 
@@ -758,14 +811,18 @@ GTKShowTempMap(const matchstate ams[], const int n, gchar * aszTitle[], const in
         g_signal_connect(G_OBJECT(pw), "expose_event", G_CALLBACK(ExposeQuadrant), NULL);
 #endif
 
-        UpdateStyle(pw, 1.0f * i / 15.0f);
+        UpdateStyle(pw, (float)i / 15.0f);
 
 
     }
 
     for (i = 0; i < 2; ++i) {
         ptmw->apwGauge[i] = gtk_label_new("");
+#if GTK_CHECK_VERSION(3,0,0)
+        gtk_grid_attach(GTK_GRID(pwGrid), ptmw->apwGauge[i], 15 * i, 0, 1, 1);
+#else
         gtk_table_attach_defaults(GTK_TABLE(pwTable), ptmw->apwGauge[i], 15 * i, 15 * i + 1, 0, 1);
+#endif
     }
 
     /* separator */
