@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2011 Michael Petch <mpetch@capp-sysware.com>
- * Copyright (C) 2013-2021 the AUTHORS
+ * Copyright (C) 2013-2023 the AUTHORS
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: gtkuidefs.h,v 1.6 2021/10/05 20:58:46 plm Exp $
+ * $Id: gtkuidefs.h,v 1.9 2023/09/05 20:34:21 plm Exp $
  */
 
 #define GNUBG_MAIN_UI \
@@ -165,17 +165,20 @@
 	      "</menu>" \
 	      \
 	      "<separator/>" \
+              "<menuitem name='AnalyseFile' action='AnalyseFileAction' />" \
 	      "<menuitem name='BatchAnalyse' action='BatchAnalyseAction' />" \
 	      "<separator/>" \
 	      "<menuitem name='MatchOrSessionStats' action='MatchOrSessionStatsAction' />" \
 	      "<separator/>" \
 	      "<menuitem name='AddMatchOrSessionStatsToDB' action='AddMatchOrSessionStatsToDBAction' />" \
 	      "<menuitem name='ShowRecords' action='ShowRecordsAction' />" \
+              "<menuitem name='PlotHistory' action='PlotHistoryAction' />" \
 	      "<separator/>" \
 	      "<menuitem name='DistributionOfRolls' action='DistributionOfRollsAction' />" \
 	      "<menuitem name='TemperatureMap' action='TemperatureMapAction' />" \
 	      "<menuitem name='TemperatureMapCube' action='TemperatureMapCubeAction' />" \
-	      "<menuitem name='ScoreMapCube' action='ScoreMapAction' />" \
+		  "<menuitem name='ScoreMapMove' action='ScoreMapMoveAction' />" \
+	      "<menuitem name='ScoreMapCube' action='ScoreMapCubeAction' />" \
 	      "<separator/>" \
 	      "<menuitem name='RaceTheory' action='RaceTheoryAction' />" \
 	      "<separator/>" \
@@ -234,6 +237,9 @@
 	    "<toolitem name='Hint' action='HintAction' />" \
 	    "<toolitem name='EditPosition' action='EditPositionAction' />" \
 	    "<toolitem name='PlayClockwise' action='PlayClockwiseAction' />" \
+            "<separator/>" \
+            "<toolitem name='Analyse' action='AnalyseCurrentAction' />" \
+            "<toolitem name='Analyse File' action='AnalyseFileAction' />" \
 	    "<separator expand='true'/>" \
 	    "<toolitem name='PreviousMarkedMove' action='GoPreviousMarkedMoveAction' />" \
 	    "<toolitem name='PreviousCMarkedMove' action='GoPreviousCMarkedMoveAction' />" \
