@@ -1,11 +1,11 @@
 /*
- * htmlimages.c
+ * Copyright (C) 1997-2003 Gary Wong <gtw@gnu.org>
+ * Copyright (C) 2002-2009 the AUTHORS
  *
- * by Gary Wong <gtw@gnu.org>, 1997-2002.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,17 +13,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: htmlimages.c,v 1.55 2014/07/20 20:56:28 plm Exp $
+ * $Id: htmlimages.c,v 1.61 2023/07/23 15:43:21 plm Exp $
  */
 
 #include "config.h"
-#include <errno.h>
 
 #include <string.h>
-#if HAVE_UNISTD_H
+#if defined(HAVE_UNISTD_H)
 #include <unistd.h>
 #endif
 
@@ -41,7 +39,7 @@
 #include "boardpos.h"
 #include "boarddim.h"
 
-#if HAVE_LIBPNG
+#if defined(HAVE_LIBPNG)
 
 static char *szFile, *pchFile;
 static int imagesWritten;
@@ -64,7 +62,7 @@ static unsigned char *auchBoard, *auchChequer[2], *auchChequerLabels, *auchLo, *
 
 static unsigned short *asRefract[2];
 
-#if USE_GTK
+#if defined(USE_GTK)
 static unsigned char *auchArrow[2];
 #endif
 static unsigned char *auchMidlb;
@@ -72,8 +70,8 @@ static unsigned char *auchMidlb;
 static void
 WriteImageStride(unsigned char *img, int stride, int cx, int cy)
 {
-    if (WritePNG(szFile, img, stride, cx, cy) == -1)
-        outputf("Error creating file %s\n", szFile);
+    if (WritePNG(szFile, img, (unsigned int) stride, (unsigned int) cx, (unsigned int) cy) == -1)
+        outputf(_("Error creating image file %s\n"), szFile);
     imagesWritten++;
     ProgressValueAdd(1);
 }
@@ -105,7 +103,7 @@ DrawArrow(int side, int player)
 
     memcpy(auchMidlb, auchBoard, BOARD_WIDTH * s * BOARD_HEIGHT * s * 3);
 
-#if USE_GTK
+#if defined(USE_GTK)
     {
         int x, y;
         ArrowPosition(side /* rd.fClockwise */ , player, s, &x, &y);
@@ -566,7 +564,7 @@ WriteImages(void)
     }
 
     if (imagesWritten != NUM_IMAGES)
-        g_print("Wrong number of images generated - %d written, expected %d\n", imagesWritten, NUM_IMAGES);
+        g_print(_("Wrong number of images generated - %d written, expected %d\n"), imagesWritten, NUM_IMAGES);
 }
 
 static void
@@ -578,7 +576,7 @@ RenderObjects(void)
 
     rd.fLabels = TRUE;
     rd.nSize = s;
-#if USE_BOARD3D
+#if defined(USE_BOARD3D)
     /* Use 2d colours for dice */
     rd.fDisplayType = DT_2D;
 #endif
@@ -587,7 +585,7 @@ RenderObjects(void)
     RenderChequers(&rd, auchChequer[0], auchChequer[1], asRefract[0], asRefract[1], CHEQUER_WIDTH * s * 4);
     RenderChequerLabels(&rd, auchChequerLabels, CHEQUER_LABEL_WIDTH * s * 3);
 
-#if USE_GTK && HAVE_CAIRO
+#if defined(USE_GTK) && defined(HAVE_CAIRO)
     RenderArrows(&rd, auchArrow[0], auchArrow[1], s * ARROW_WIDTH * 4, rd.fClockwise);
 #endif
 
@@ -616,15 +614,16 @@ GetFilenameBase(char *sz)
 
     if (!sz || !*sz) {
         outputf(_("You must specify a directory to export to (see `%s')\n"), "help export htmlimages");
-        return 0;
+        return NULL;
     }
 
     if (!g_file_test(sz, G_FILE_TEST_IS_DIR) && g_mkdir(sz, 0777) < 0) {
         outputerr(sz);
-        return 0;
+        return NULL;
     }
 
-    szFile = malloc(strlen(sz) + 32);
+    szFile = g_malloc(strlen(sz) + 32);
+
     strcpy(szFile, sz);
 
     if (szFile[strlen(szFile) - 1] != '/')
@@ -643,12 +642,16 @@ AllocObjects(void)
     s = exsExport.nHtmlSize;
 
     auchMidlb = malloc((BOARD_WIDTH * s * 3 * BOARD_HEIGHT * s) * sizeof(unsigned char));
-#if USE_GTK
+#if defined(USE_GTK)
     auchArrow[0] = malloc(s * ARROW_WIDTH * 4 * s * ARROW_HEIGHT);
     auchArrow[1] = malloc(s * ARROW_WIDTH * 4 * s * ARROW_HEIGHT);
 #endif
 
-    auchBoard = malloc((BOARD_WIDTH * s * 3 * BOARD_HEIGHT * s) * sizeof(unsigned char));
+    /* Initialise this one else valgrind reports
+     * use of uninitialised values in libpng
+     */
+    auchBoard = calloc(sizeof(unsigned char), BOARD_WIDTH * s * 3 * BOARD_HEIGHT * s);
+
     for (i = 0; i < 2; i++)
         auchChequer[i] = malloc((CHEQUER_WIDTH * s * 4 * CHEQUER_HEIGHT * s) * sizeof(unsigned char));
     auchChequerLabels = malloc((12 * CHEQUER_LABEL_WIDTH * s * 3 * CHEQUER_LABEL_HEIGHT * s) * sizeof(unsigned char));
@@ -681,11 +684,11 @@ TidyObjects(void)
 {
     int i, j, k;
     free(auchMidlb);
-#if USE_GTK
+#if defined(USE_GTK)
     free(auchArrow[0]);
     free(auchArrow[1]);
 #endif
-    free(szFile);
+    g_free(szFile);
     free(auchBoard);
     for (i = 0; i < 2; i++)
         free(auchChequer[i]);
@@ -718,15 +721,13 @@ extern void
 CommandExportHTMLImages(char *sz)
 {
     szFile = GetFilenameBase(sz);
-    if (!szFile)
-        return;
 
     ProgressStartValue(_("Generating image:"), NUM_IMAGES);
     AllocObjects();
     RenderObjects();
     WriteImages();
-    ProgressEnd();
     TidyObjects();
+    ProgressEnd();
 }
 
 #else                           /* not HAVE_LIBPNG */
