@@ -1,6 +1,11 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+/*
+ * Copyright (C) 1997-2000 Gary Wong <gtw@gnu.org>
+ * Copyright (C) 2002-2022 the AUTHORS
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -8,24 +13,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- *
- * cache.c
- *
- * by Gary Wong, 1997-2000
- * $Id: cache.c,v 1.42 2016/04/23 19:33:45 plm Exp $
+ * $Id: cache.c,v 1.50 2022/02/20 16:54:43 plm Exp $
  */
 
 #include "config.h"
 
-#include <stddef.h>
 #include <stdlib.h>
 #include <string.h>
-#ifndef WIN32
-#include <stdio.h>
-#endif
 
 #include "cache.h"
 #include "positionid.h"
@@ -33,15 +29,19 @@
 #if defined(USE_MULTITHREAD)
 #include "multithread.h"
 
-#if defined(__GNUC__) && ( __GNUC__ * 100 + __GNUC_MINOR__ >= 401 ) \
-  && (defined (__i386) || defined (__x86_64))
+#if defined(__GNUC__) && ( \
+    (( __GNUC__ * 100 + __GNUC_MINOR__ >= 401 ) \
+      && (defined (__i486) || defined (__x86_64))) \
+  || (( __GNUC__ * 100 + __GNUC_MINOR__ >= 404 ) \
+      && defined (__i386))			 \
+  )
 
 static inline void
 cache_lock(evalCache * pc, uint32_t k)
 {
     while (__sync_lock_test_and_set(&(pc->entries[k].lock), 1))
-        while (pc->entries[k].lock)
-            __asm volatile ("pause":::"memory");
+        while (__sync_fetch_and_add(&pc->entries[k].lock, 0))
+            __asm__ __volatile__ ("pause":::"memory");
 }
 
 static inline void
@@ -50,7 +50,7 @@ cache_unlock(evalCache * pc, uint32_t k)
     __sync_lock_release(&(pc->entries[k].lock));
 }
 
-#else
+#else	/* not x86 or older gcc: no suitable intrinsics */
 
 static inline void
 WaitForLock(volatile int *lock)
@@ -99,7 +99,7 @@ CacheCreate(evalCache * pc, unsigned int s)
     pc->hashMask = (pc->size >> 1) - 1;
 
     pc->entries = (cacheNode *) malloc((pc->size / 2) * sizeof(*pc->entries));
-    if (pc->entries == 0)
+    if (pc->entries == NULL)
         return -1;
 
     CacheFlush(pc);
@@ -109,7 +109,7 @@ CacheCreate(evalCache * pc, unsigned int s)
 /* MurmurHash3  https://code.google.com/p/smhasher/wiki/MurmurHash */
 
 extern uint32_t
-GetHashKey(uint32_t hashMask, const cacheNodeDetail * e)
+GetHashKey(uint32_t hashMask, const cacheNodeDetail * restrict e)
 {
     uint32_t hash = (uint32_t) e->nEvalContext;
     int i;
@@ -147,16 +147,22 @@ GetHashKey(uint32_t hashMask, const cacheNodeDetail * e)
 
 
 uint32_t
-CacheLookupWithLocking(evalCache * pc, const cacheNodeDetail * e, float *arOut, float *arCubeful)
+CacheLookupWithLocking(evalCache * restrict pc, const cacheNodeDetail * restrict e, float * restrict arOut, float * restrict arCubeful)
 {
     uint32_t const l = GetHashKey(pc->hashMask, e);
 
 #if CACHE_STATS
+#if defined(USE_MULTITHREAD)
+    MT_SafeInc(&pc->cLookup);
+#else
     ++pc->cLookup;
 #endif
+#endif
+
 #if defined(USE_MULTITHREAD)
     cache_lock(pc, l);
 #endif
+
     if (!EqualKeys(pc->entries[l].nd_primary.key, e->key) || pc->entries[l].nd_primary.nEvalContext != e->nEvalContext) {       /* Not in primary slot */
         if (!EqualKeys(pc->entries[l].nd_secondary.key, e->key) || pc->entries[l].nd_secondary.nEvalContext != e->nEvalContext) {       /* Cache miss */
 #if defined(USE_MULTITHREAD)
@@ -180,14 +186,18 @@ CacheLookupWithLocking(evalCache * pc, const cacheNodeDetail * e, float *arOut,
 #endif
 
 #if CACHE_STATS
+#if defined(USE_MULTITHREAD)
+    MT_SafeInc(&pc->cHit);
+#else
     ++pc->cHit;
+#endif
 #endif
 
     return CACHEHIT;
 }
 
 uint32_t
-CacheLookupNoLocking(evalCache * pc, const cacheNodeDetail * e, float *arOut, float *arCubeful)
+CacheLookupNoLocking(evalCache * restrict pc, const cacheNodeDetail * restrict e, float *restrict arOut, float * restrict arCubeful)
 {
     uint32_t const l = GetHashKey(pc->hashMask, e);
 
@@ -218,7 +228,7 @@ CacheLookupNoLocking(evalCache * pc, const cacheNodeDetail * e, float *arOut, fl
 }
 
 void
-CacheAddWithLocking(evalCache * pc, const cacheNodeDetail * e, uint32_t l)
+CacheAddWithLocking(evalCache * restrict pc, const cacheNodeDetail * restrict e, uint32_t l)
 {
 #if defined(USE_MULTITHREAD)
     cache_lock(pc, l);
@@ -232,10 +242,16 @@ CacheAddWithLocking(evalCache * pc, const cacheNodeDetail * e, uint32_t l)
 #endif
 
 #if CACHE_STATS
+#if defined(USE_MULTITHREAD)
+    MT_SafeInc(&pc->nAdds);
+#else
     ++pc->nAdds;
 #endif
+#endif
 }
 
+/* CacheAddNoLocking() is inlined and in cache.h */
+
 void
 CacheDestroy(const evalCache * pc)
 {
@@ -267,10 +283,10 @@ CacheResize(evalCache * pc, unsigned int cNew)
     return (int) pc->size;
 }
 
+#if CACHE_STATS
 void
 CacheStats(const evalCache * pc, unsigned int *pcLookup, unsigned int *pcHit, unsigned int *pcUsed)
 {
-#if CACHE_STATS
     if (pcLookup)
         *pcLookup = pc->cLookup;
 
@@ -279,16 +295,5 @@ CacheStats(const evalCache * pc, unsigned int *pcLookup, unsigned int *pcHit, un
 
     if (pcUsed)
         *pcUsed = pc->nAdds;
-#else
-    (void) pc;                  /* suppress unused parameter compiler warning */
-
-    if (pcLookup)
-        *pcLookup = 0;
-
-    if (pcHit)
-        *pcHit = 0;
-
-    if (pcUsed)
-        *pcUsed = 0;
-#endif
 }
+#endif
