@@ -1,12 +1,11 @@
 /*
- * neuralnetsse.c
- * by Jon Kinsey, 2006
+ * Copyright (C) 2006-2009 Jon Kinsey <jonkinsey@gmail.com>
+ * Copyright (C) 2007-2021 the AUTHORS
  *
- * SIMD specific code
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -14,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: neuralnetsse.c,v 1.36 2018/05/12 21:42:33 plm Exp $
+ * $Id: neuralnetsse.c,v 1.43 2021/10/30 19:42:20 plm Exp $
  */
 
 #include "config.h"
@@ -52,25 +50,38 @@
 float *
 sse_malloc(size_t size)
 {
-#if defined(HAVE_SSE)
-    return (float *) _mm_malloc(size, ALIGN_SIZE);
-#elif defined(HAVE_NEON)
+#if defined(HAVE_POSIX_MEMALIGN)
     void *ptr = NULL;
+    int ret;
     
-    posix_memalign(&ptr, ALIGN_SIZE, size);
-    return (float *)ptr;
+    ret = posix_memalign(&ptr, ALIGN_SIZE, size);
+    
+    if (ret == 0)
+        return (float *)ptr;
+
+    /* mimic g_malloc() error message */
+    g_error("%s: failed to allocate %"G_GSIZE_FORMAT" bytes", G_STRLOC, size);
+
+    /* avoid warning: "control reaches end of non-void function" for
+       compilers that don't understand that g_error() never returns. */
+    return NULL;
+
+#elif defined(HAVE__ALIGNED_MALLOC)
+    return (float *) _aligned_malloc(size, ALIGN_SIZE);
 #else
-    #error "Inconsistent SIMD defines"
+    return (float *) _mm_malloc(size, ALIGN_SIZE);
 #endif
 }
 
 void
 sse_free(float *ptr)
 {
-#if defined(HAVE_SSE)
-    _mm_free(ptr);
-#else
+#if defined(HAVE_POSIX_MEMALIGN)
     free(ptr);
+#elif defined(HAVE__ALIGNED_MALLOC)
+    _aligned_free(ptr);
+#else
+    _mm_free(ptr);
 #endif
 }
 
@@ -95,10 +106,10 @@ CheckNEON(void)
    } else {
 #if defined(__ARM_FEATURE_SIMD32)
        /* v7 */
-       asm volatile ("vmin.f32 q0, q0, q0");
+       __asm__ __volatile__ ("vmin.f32 q0, q0, q0");
 #elif defined(__ARM_NEON)
        /* aarch64 */
-       asm volatile ("fmin v0.4s, v0.4s, v0.4s");
+       __asm__ __volatile__ ("fmin v0.4s, v0.4s, v0.4s");
 #else
        #error "Unexpected ARM architecture"
 #endif
@@ -233,19 +244,20 @@ sigmoid_ps(float_vector xin)
     float_vector c;
     xin = _mm256_and_ps(xin, abs_mask.ps);      /* Abs. value by clearing signbit */
     c = sigmoid_positive_ps(xin);
-    return _mm256_or_ps(_mm256_and_ps(mask, c), _mm256_andnot_ps(mask, _mm256_sub_ps(ones.ps, c)));
+    return _mm256_blendv_ps(_mm256_sub_ps(ones.ps, c), c, mask);
 #elif defined(HAVE_SSE)
     float_vector mask = _mm_cmplt_ps(xin, _mm_setzero_ps());
     float_vector c;
     xin = _mm_and_ps(xin, abs_mask.ps); /* Abs. value by clearing signbit */
     c = sigmoid_positive_ps(xin);
+    /* _mm_blendv_ps() is only available with SSE4.1 or later */
     return _mm_or_ps(_mm_and_ps(mask, c), _mm_andnot_ps(mask, _mm_sub_ps(ones.ps, c)));
 #else
     int_vector mask = (int_vector)vcltq_f32(xin, vdupq_n_f32(0.0f));
     float_vector c;
     xin = (float_vector)vandq_s32((int_vector)xin, (int_vector)abs_mask.ps); /* Abs. value by clearing signbit */
     c = sigmoid_positive_ps(xin);
-    return (float_vector)vorrq_s32(vandq_s32(mask, (int_vector)c), vbicq_s32((int_vector)vsubq_f32(ones.ps, c),mask));
+    return vbslq_f32((uint32x4_t)mask, c, vsubq_f32(ones.ps, c));
 #endif
 }
 
@@ -314,7 +326,7 @@ for (j = (cHidden >> LOG2VEC_SIZE); j; j--, pr += VEC_SIZE, prWeight += VEC_SIZE
 #endif
 
 static void
-EvaluateSSE(const neuralnet * pnn, const float arInput[], float ar[], float arOutput[])
+EvaluateSSE(const neuralnet * restrict pnn, const float arInput[], float ar[], float arOutput[])
 {
     const unsigned int cHidden = pnn->cHidden;
     unsigned int i, j;
@@ -555,7 +567,7 @@ EvaluateSSE(const neuralnet * pnn, const float arInput[], float ar[], float arOu
 
 
 extern int
-NeuralNetEvaluateSSE(const neuralnet * pnn, /*lint -e{818} */ float arInput[],
+NeuralNetEvaluateSSE(const neuralnet * restrict pnn, /*lint -e{818} */ float arInput[],
                      float arOutput[], NNState * UNUSED(pnState))
 {
     SSE_ALIGN(float ar[pnn->cHidden]);
