@@ -1,11 +1,11 @@
-/*
- * makebearoff.c
+/* 
+ * Copyright (C) 1997-2003 Gary Wong <gary@cs.arizona.edu>
+ * Copyright (C) 2002-2024 the AUTHORS
  *
- * by Gary Wong <gary@cs.arizona.edu>, 1997-1999.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,10 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- * $Id: makebearoff.c,v 1.100 2017/08/08 19:14:19 plm Exp $
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -32,12 +29,14 @@
 #endif
 #include <math.h>
 #include <errno.h>
+#include <locale.h>
+#include <glib/gstdio.h>
+
 #include "eval.h"
 #include "positionid.h"
 #include "bearoff.h"
 #include "util.h"
 #include "backgammon.h"
-#include <glib/gstdio.h>
 #include "glib-ext.h"
 #include "multithread.h"
 
@@ -47,12 +46,12 @@ MT_CloseThreads(void)
     return;
 }
 
-typedef struct _xhashent {
+typedef struct {
     void *p;
     unsigned int iKey;
 } xhashent;
 
-typedef struct _xhash {
+typedef struct {
     unsigned long int nQueries, nHits, nEntries, nOverwrites;
     int nHashSize;
     xhashent *phe;
@@ -73,10 +72,10 @@ static void
 XhashStatus(xhash * ph)
 {
 
-    fprintf(stderr, "Xhash status:\n");
-    fprintf(stderr, "Size:    %d elements\n", ph->nHashSize);
-    fprintf(stderr, "Queries: %lu (hits: %lu)\n", ph->nQueries, ph->nHits);
-    fprintf(stderr, "Entries: %lu (overwrites: %lu)\n", ph->nEntries, ph->nOverwrites);
+    g_printerr(_("Xhash status:\n"));
+    g_printerr(_("Size:    %d elements\n"), ph->nHashSize);
+    g_printerr(_("Queries: %lu (hits: %lu)\n"), ph->nQueries, ph->nHits);
+    g_printerr(_("Entries: %lu (overwrites: %lu)\n"), ph->nEntries, ph->nOverwrites);
 
 }
 
@@ -87,10 +86,7 @@ XhashCreate(xhash * ph, const int nHashSize)
 
     int i;
 
-    if (!(ph->phe = (xhashent *) malloc(nHashSize * sizeof(xhashent)))) {
-        perror("xhashtable");
-        return -1;
-    }
+    ph->phe = (xhashent *) g_malloc(nHashSize * sizeof(xhashent));
 
     ph->nQueries = 0;
     ph->nHits = 0;
@@ -114,7 +110,7 @@ XhashDestroy(xhash * ph)
 
     for (i = 0; i < ph->nHashSize; ++i)
         if (ph->phe[i].p)
-            free(ph->phe[i].p);
+            g_free(ph->phe[i].p);
     free(ph->phe);
 }
 
@@ -127,7 +123,7 @@ XhashAdd(xhash * ph, const unsigned int iKey, const void *data, const int size)
 
     if (ph->phe[l].p) {
         /* occupied */
-        free(ph->phe[l].p);
+        g_free(ph->phe[l].p);
         ph->nOverwrites++;
     } else {
 
@@ -137,9 +133,11 @@ XhashAdd(xhash * ph, const unsigned int iKey, const void *data, const int size)
     }
 
     ph->phe[l].iKey = iKey;
-    ph->phe[l].p = malloc(size);
-    memcpy(ph->phe[l].p, data, size);
-
+#if GLIB_CHECK_VERSION (2,67,4)
+    ph->phe[l].p = g_memdup2(data, size);
+#else
+    ph->phe[l].p = g_memdup(data, size);
+#endif
 }
 
 
@@ -193,7 +191,7 @@ OSLookup(const unsigned int iPos,
             if (errno)
                 perror("output file");
             else
-                fprintf(stderr, "error reading output file\n");
+                g_printerr(_("Error reading output file\n"));
             exit(-1);
         }
 
@@ -221,7 +219,7 @@ OSLookup(const unsigned int iPos,
         nBytes = 2 * (nz + nzg);
 
         if (fseek(pfTmp, iOffset, SEEK_SET) < 0) {
-            perror("fseek'ing temp file");
+            perror("fseek'ing temporary file");
             exit(-1);
         }
 
@@ -229,9 +227,9 @@ OSLookup(const unsigned int iPos,
 
         if (fread(ac, 1, nBytes, pfTmp) < nBytes) {
             if (errno)
-                perror("reading temp file");
+                perror("reading temporary file");
             else
-                fprintf(stderr, "error reading temp file");
+                g_printerr(_("Error reading temporary file"));
             exit(-1);
         }
 
@@ -252,7 +250,7 @@ OSLookup(const unsigned int iPos,
         /* re-position at EOF */
 
         if (fseek(pfTmp, 0L, SEEK_END) < 0) {
-            perror("fseek'ing to EOF on temp file");
+            perror("fseek'ing to EOF on temporary file");
             exit(-1);
         }
 
@@ -261,14 +259,14 @@ OSLookup(const unsigned int iPos,
         /* look up position by seeking */
 
         if (fseek(pfOutput, 40 + iPos * (fGammon ? 128 : 64), SEEK_SET) < 0) {
-            fprintf(stderr, "error seeking in pfOutput\n");
+            g_printerr(_("Error seeking in pfOutput\n"));
             exit(-1);
         }
 
         /* read distribution */
 
         if (fread(ac, 1, fGammon ? 128U : 64U, pfOutput) < (fGammon ? 128U : 64U)) {
-            fprintf(stderr, "error readung from pfOutput\n");
+            g_printerr(_("Error reading from pfOutput\n"));
             exit(-1);
         }
 
@@ -285,7 +283,7 @@ OSLookup(const unsigned int iPos,
         /* position cursor at end of file */
 
         if (fseek(pfOutput, 0L, SEEK_END) < 0) {
-            fprintf(stderr, "error seeking to end!\n");
+            g_printerr(_("Error seeking to end!\n"));
             exit(-1);
         }
 
@@ -351,7 +349,7 @@ BearOff(int nId, unsigned int nPoints,
 #if !defined(G_DISABLE_ASSERT)
     int iBest;
 #endif
-    int iMode, j, anRoll[2], aProb[64];
+    int iMode, j, anRoll[2], aProb[64] = { 0 };
     unsigned int i;
     TanBoard anBoard, anBoardTemp;
     movelist ml;
@@ -373,7 +371,7 @@ BearOff(int nId, unsigned int nPoints,
     /* initialise probabilities */
 
     for (i = 0; i < 64; i++)
-        aProb[i] = aOutProb[i] = 0;
+        aOutProb[i] = 0;
 
     /* all chequers off is easy :-) */
 
@@ -486,7 +484,7 @@ BearOff(int nId, unsigned int nPoints,
             iMode = i;
     }
 
-    aOutProb[iMode] -= (j - 0xFFFF);
+    aOutProb[iMode] -= (unsigned short int) (j - 0xFFFF);
 
     /* gammon probs */
 
@@ -497,7 +495,7 @@ BearOff(int nId, unsigned int nPoints,
                 iMode = i;
         }
 
-        aOutProb[32 + iMode] -= (j - 0xFFFF);
+        aOutProb[32 + iMode] -= (unsigned short int) (j - 0xFFFF);
     }
 
 }
@@ -604,7 +602,7 @@ generate_os(const int nOS, const int fHeader,
     /* initialise xhash */
 
     if (XhashCreate(&h, nHashSize / (fGammon ? 128 : 64))) {
-        fprintf(stderr, _("Error creating xhash with %d elements\n"), nHashSize / (fGammon ? 128 : 64));
+        g_printerr(_("Error creating xhash with %d elements\n"), nHashSize / (fGammon ? 128 : 64));
         exit(2);
     }
 
@@ -620,8 +618,10 @@ generate_os(const int nOS, const int fHeader,
 
     if (fCompress) {
         pfTmp = GetTemporaryFile(NULL, &tmpfile);
-        if (pfTmp == NULL)
+        if (pfTmp == NULL) {
+            g_printerr(_("Error creating temporary file\n"));
             exit(2);
+        }
     }
 
 
@@ -641,7 +641,7 @@ generate_os(const int nOS, const int fHeader,
             aus[32] = 0xFFFF;
         }
         if (!(i % 100) && fTTY)
-            fprintf(stderr, "1:%d/%d        \r", i, n);
+            g_printerr("1:%d/%d        \r", i, n);
 
         WriteOS(aus, fCompress, fCompress ? pfTmp : output);
         if (fGammon)
@@ -664,7 +664,7 @@ generate_os(const int nOS, const int fHeader,
 
         while (!feof(pfTmp) && (u = fread(ac, 1, sizeof(ac), pfTmp))) {
             if (fwrite(ac, 1, u, output) != u) {
-                fprintf(stderr, "failed writing to '%s'\n", tmpfile);
+                g_printerr(_("Error writing to '%s'\n"), tmpfile);
                 exit(3);
             }
         }
@@ -696,7 +696,7 @@ NDBearoff(const int iPos, const unsigned int nPoints, float ar[4], xhash * ph, b
     int d0, d1;
     movelist ml;
     TanBoard anBoard, anBoardTemp;
-    int ii, j, k;
+    int j, k;
     unsigned int i;
 #if !defined(G_DISABLE_ASSERT)
     int iBest;
@@ -727,6 +727,8 @@ NDBearoff(const int iPos, const unsigned int nPoints, float ar[4], xhash * ph, b
      */
 
     if (pbc) {
+        int ii;
+
         for (ii = 24; ii >= 0 && !anBoard[1][ii]; --ii);
 
         if (ii < (int) pbc->nPoints) {
@@ -828,13 +830,12 @@ NDBearoff(const int iPos, const unsigned int nPoints, float ar[4], xhash * ph, b
 
 
 static void
-generate_nd(const int nPoints, const int nHashSize, const int fHeader, bearoffcontext * pbc, FILE * output)
+generate_nd(const int nPoints, const int nHashSize, const int fHeader, bearoffcontext * pbc, FILE * outfile)
 {
 
     int n = Combination(nPoints + 15, nPoints);
 
     int i, j;
-    char sz[41];
     float ar[4];
     int fTTY = isatty(STDERR_FILENO);
 
@@ -843,16 +844,18 @@ generate_nd(const int nPoints, const int nHashSize, const int fHeader, bearoffco
     /* initialise xhash */
 
 
-    if (XhashCreate(&h, nHashSize / (4 * sizeof(float)))) {
-        fprintf(stderr, "Error creating cache\n");
+    if (XhashCreate(&h, (int) (nHashSize / (4 * sizeof(float))))) {
+        g_printerr(_("Error creating cache\n"));
         return;
     }
 
     XhashStatus(&h);
 
     if (fHeader) {
+        char sz[41];
+
         sprintf(sz, "gnubg-OS-%02d-15-1-0-1xxxxxxxxxxxxxxxxxxx\n", nPoints);
-        fputs(sz, output);
+        fputs(sz, outfile);
     }
 
 
@@ -864,11 +867,11 @@ generate_nd(const int nPoints, const int nHashSize, const int fHeader, bearoffco
             ar[0] = ar[1] = ar[2] = ar[3] = 0.0f;
 
         for (j = 0; j < 4; ++j)
-            WriteFloat(ar[j], output);
+            WriteFloat(ar[j], outfile);
 
         XhashAdd(&h, i, ar, 16);
         if (!(i % 100) && fTTY)
-            fprintf(stderr, "1:%d/%d        \r", i, n);
+            g_printerr("1:%d/%d        \r", i, n);
 
     }
     putc('\n', stderr);
@@ -891,7 +894,7 @@ CubeEquity(const short int siND, const short int siDT, const short int siDP)
             return siDP;
         else
             /* double, take */
-            return 2 * siDT;
+            return (short int) (2 * siDT);
 
     } else
         /* no double */
@@ -913,9 +916,9 @@ CalcPosition(const int i, const int j, const int n)
 
 #if 0
     if (n == 6) {
-        fprintf(stderr, "%2d ", k);
+        g_printerr("%2d ", k);
         if (j == n - 1)
-            fprintf(stderr, "\n");
+            g_printerr("\n");
     }
 #endif
 
@@ -934,34 +937,31 @@ TSLookup(const int nUs, const int nThem,
     int iPos = CalcPosition(nUs, nThem, n);
     unsigned char ac[8];
     int i;
-    unsigned short int us;
 
     /* seek to position */
 
     if (fseek(pfTmp, iPos * (fCubeful ? 8 : 2), SEEK_SET) < 0) {
-        perror("temp file");
+        perror("temporary file");
         exit(-1);
     }
 
     if (fread(ac, 1, 8, pfTmp) < 8) {
         if (errno)
-            perror("temp file");
+            perror("temporary file");
         else
-            fprintf(stderr, "error reading temp file\n");
+            g_printerr(_("Error reading temporary file\n"));
         exit(-1);
     }
 
     /* re-position at EOF */
 
     if (fseek(pfTmp, 0L, SEEK_END) < 0) {
-        perror("temp file");
+        perror("temporary file");
         exit(-1);
     }
 
-    for (i = 0; i < (fCubeful ? 4 : 1); ++i) {
-        us = (unsigned short) (ac[2 * i] | ac[2 * i + 1] << 8);
-        arEquity[i] = us - 0x8000;
-    }
+    for (i = 0; i < (fCubeful ? 4 : 1); ++i)
+        arEquity[i] = (unsigned short) ((ac[2 * i] | ac[2 * i + 1] << 8) - 0x8000);
 
     ++cLookup;
 
@@ -1032,7 +1032,7 @@ BearOff2(int nUs, int nThem,
         BearoffCubeful(pbc, iPos, NULL, aus);
 
         for (i = 0; i < 4; ++i)
-            asiEquity[i] = aus[i] - 0x8000;
+            asiEquity[i] = (short int) (aus[i] - 0x8000);
 
         return;
     }
@@ -1140,7 +1140,7 @@ static void
 WriteEquity(FILE * pf, const short int si)
 {
 
-    unsigned short int us = si + 0x8000;
+    unsigned short int us = (unsigned short int) (si + 0x8000);
 
     putc(us & 0xFF, pf);
     putc((us >> 8) & 0xFF, pf);
@@ -1163,13 +1163,15 @@ generate_ts(const int nTSP, const int nTSC,
     int fTTY = isatty(STDERR_FILENO);
 
     pfTmp = GetTemporaryFile(NULL, &tmpfile);
-    if (pfTmp == NULL)
+    if (pfTmp == NULL) {
+        g_printerr(_("Error creating temporary file\n"));
         exit(2);
+    }
 
     /* initialise xhash */
 
     if (XhashCreate(&h, nHashSize / (fCubeful ? 8 : 2))) {
-        fprintf(stderr, _("Error creating xhash with %d elements\n"), nHashSize / (fCubeful ? 8 : 2));
+        g_printerr(_("Error creating xhash with %d elements\n"), nHashSize / (fCubeful ? 8 : 2));
         exit(2);
     }
 
@@ -1204,7 +1206,7 @@ generate_ts(const int nTSP, const int nTSC,
 
         }
         if (fTTY)
-            fprintf(stderr, "%d/%d     \r", iPos, n * n);
+            g_printerr("%d/%d     \r", iPos, n * n);
     }
 
     /* positions below diagonal */
@@ -1221,7 +1223,7 @@ generate_ts(const int nTSP, const int nTSC,
 
         }
         if (fTTY)
-            fprintf(stderr, "%d/%d     \r", iPos, n * n);
+            g_printerr("%d/%d     \r", iPos, n * n);
     }
 
     putc('\n', stderr);
@@ -1245,7 +1247,7 @@ generate_ts(const int nTSP, const int nTSC,
 
             fseek(pfTmp, count * k, SEEK_SET);
             if (fread(ac, 1, count, pfTmp) != count || fwrite(ac, 1, count, output) != count) {
-                fprintf(stderr, "failed to read from or write to database file\n");
+                g_printerr(_("failed to read from or write to database file\n"));
                 exit(3);
             }
         }
@@ -1260,19 +1262,10 @@ generate_ts(const int nTSP, const int nTSC,
 }
 
 
-
-
-static void
-version(void)
-{
-    printf("makebearoff $Revision: 1.100 $\n");
-}
-
-
 extern int
 main(int argc, char **argv)
 {
-    /* static storage for options to keep picky comipler happy */
+    /* static storage for options to keep picky compiler happy */
     static int nOS = 0;
     static int fHeader = TRUE;
     static int fCompress = TRUE;
@@ -1283,44 +1276,49 @@ main(int argc, char **argv)
     static int fND = FALSE;
     static char *szOutput = NULL;
     static char *szTwoSided = NULL;
-    static int show_version = 0;
 
-    glib_ext_init();
-    MT_InitThreads();
     bearoffcontext *pbc = NULL;
-    FILE *output;
+    FILE *outfile;
     double r;
     int nTSP = 0, nTSC = 0;
 
     GOptionEntry ao[] = {
         {"two-sided", 't', 0, G_OPTION_ARG_STRING, &szTwoSided,
-         "Number of points (P) and number of chequers (C) for two-sided database", "PxC"},
+         N_("Number of points (P) and number of chequers (C) for two-sided database"), "PxC"},
         {"one-sided", 'o', 0, G_OPTION_ARG_INT, &nOS,
-         "Number of points (P) for one-sided database", "P"},
+         N_("Number of points (P) for one-sided database"), "P"},
         {"xhash-size", 's', 0, G_OPTION_ARG_INT, &nHashSize,
-         "Use cache of size N bytes", "N"},
+         N_("Use cache of size N bytes"), "N"},
         {"old-bearoff", 'O', 0, G_OPTION_ARG_STRING, &szOldBearoff,
-         "Reuse already generated bearoff database \"filename\"", "filename"},
+         N_("Reuse already generated bearoff database \"filename\""), "filename"},
         {"no-header", 'H', G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &fHeader,
-         "Do not write header", NULL},
+         N_("Do not write header"), NULL},
         {"no-cubeful", 'C', G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &fCubeful,
-         "Do not calculate cubeful equities for two-sided databases", NULL},
+         N_("Do not calculate cubeful equities for two-sided databases"), NULL},
         {"no-compress", 'c', G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &fCompress,
-         "Do not use compression scheme for one-sided databases", NULL},
+         N_("Do not use compression scheme for one-sided databases"), NULL},
         {"no-gammon", 'g', G_OPTION_FLAG_REVERSE, G_OPTION_ARG_NONE, &fGammon,
-         "Do not include gammon distribution for one-sided databases", NULL},
+         N_("Do not include gammon distribution for one-sided databases"), NULL},
         {"normal-dist", 'n', 0, G_OPTION_ARG_NONE, &fND,
-         "Approximate one-sided bearoff database with normal distributions", NULL},
-        {"version", 'v', 0, G_OPTION_ARG_NONE, &show_version,
-         "Prints version and exits", NULL},
+         N_("Approximate one-sided bearoff database with normal distributions"), NULL},
         {"outfile", 'f', 0, G_OPTION_ARG_STRING, &szOutput,
-         "Required output filename", "filename"},
+         N_("Required output filename"), "filename"},
         {NULL, 0, 0, (GOptionArg) 0, NULL, NULL, NULL}
     };
 
     GError *error = NULL;
     GOptionContext *context;
 
+    /* i18n */
+
+    glib_ext_init();
+    MT_InitThreads();
+    setlocale(LC_ALL, "");
+    bindtextdomain(PACKAGE, LOCALEDIR);
+    textdomain(PACKAGE);
+
+    g_set_printerr_handler(print_utf8_to_locale);
+
     context = g_option_context_new(NULL);
     g_option_context_add_main_entries(context, ao, PACKAGE);
     g_option_context_parse(context, &argc, &argv, &error);
@@ -1330,21 +1328,15 @@ main(int argc, char **argv)
         exit(EXIT_FAILURE);
     }
 
-
     if (szTwoSided)
         sscanf(szTwoSided, "%2dx%2d", &nTSP, &nTSC);
 
-    if (show_version) {
-        version();
-        exit(0);
-    }
-
     if (!szOutput) {
-        g_printerr("Required argument -f missing\n");
+        g_printerr(_("Required argument -f missing\n"));
         exit(EXIT_FAILURE);
     }
 
-    if (!(output = gnubg_g_fopen(szOutput, "w+b"))) {
+    if (!(outfile = g_fopen(szOutput, "w+b"))) {
         perror(szOutput);
         return EXIT_FAILURE;
     }
@@ -1353,36 +1345,36 @@ main(int argc, char **argv)
 
     if (nOS) {
 
-        if (nOS > 18) {
-            fprintf(stderr, _("Size of one-sided bearoff database must be between " "0 and 18\n"));
+        if (nOS > 13) {
+            g_printerr(_("Size of one-sided bearoff database should be at most 13 points\n"));
             exit(2);
         }
-        fprintf(stderr, "%-37s\n", _("One-sided database"));
-        fprintf(stderr, "%-37s: %12d\n", _("Number of points"), nOS);
-        fprintf(stderr, "%-37s: %12d\n", _("Number of chequers"), 15);
-        fprintf(stderr, "%-37s: %12u\n", _("Number of positions"), Combination(nOS + 15, nOS));
-        fprintf(stderr, "%-37s: %12s\n", _("Approximate by normal distribution"), fND ? _("yes") : _("no"));
-        fprintf(stderr, "%-37s: %12s\n", _("Include gammon distributions"), fGammon ? _("yes") : _("no"));
-        fprintf(stderr, "%-37s: %12s\n", _("Use compression scheme"), fCompress ? _("yes") : _("no"));
-        fprintf(stderr, "%-37s: %12s\n", _("Write header"), fHeader ? _("yes") : _("no"));
-        fprintf(stderr, "%-37s: %12d\n", _("Size of cache"), nHashSize);
-        fprintf(stderr, "%-37s: %12s %s\n", _("Reuse old bearoff database"), szOldBearoff ? _("yes") : _("no"),
+        g_printerr("%-37s\n", _("One-sided database"));
+        g_printerr("%-37s: %12d\n", _("Number of points"), nOS);
+        g_printerr("%-37s: %12d\n", _("Number of chequers"), 15);
+        g_printerr("%-37s: %12u\n", _("Number of positions"), Combination(nOS + 15, nOS));
+        g_printerr("%-37s: %12s\n", _("Approximate by normal distribution"), fND ? _("yes") : _("no"));
+        g_printerr("%-37s: %12s\n", _("Include gammon distributions"), fGammon ? _("yes") : _("no"));
+        g_printerr("%-37s: %12s\n", _("Use compression scheme"), fCompress ? _("yes") : _("no"));
+        g_printerr("%-37s: %12s\n", _("Write header"), fHeader ? _("yes") : _("no"));
+        g_printerr("%-37s: %12d\n", _("Size of cache"), nHashSize);
+        g_printerr("%-37s: %12s %s\n", _("Reuse old bearoff database"), szOldBearoff ? _("yes") : _("no"),
                 szOldBearoff ? szOldBearoff : "");
 
         if (fND) {
             r = Combination(nOS + 15, nOS) * 16.0;
-            fprintf(stderr, "%-37s: %.0f (%.1f MB)\n", _("Size of database"), r, r / 1048576.0);
+            g_printerr("%-37s: %.0f (%.1f MB)\n", _("Size of database"), r, r / 1048576.0);
         } else {
-            r = Combination(nOS + 15, nOS) * (fGammon ? 128.0f : 64.0f);
-            fprintf(stderr, "%-37s: %.0f (%.1f MB)\n", _("Size of database (uncompressed)"), r, r / 1048576.0);
+            r = (float) Combination(nOS + 15, nOS) * (fGammon ? 128.0f : 64.0f);
+            g_printerr("%-37s: %.0f (%.1f MB)\n", _("Size of database (uncompressed)"), r, r / 1048576.0);
             if (fCompress) {
-                r = Combination(nOS + 15, nOS) * (fGammon ? 32.0f : 16.0f);
-                fprintf(stderr, "%-37s: %.0f (%.1f MB)\n", _("Estimated size of compressed db"), r, r / 1048576.0);
+                r = (float) Combination(nOS + 15, nOS) * (fGammon ? 32.0f : 16.0f);
+                g_printerr("%-37s: %.0f (%.1f MB)\n", _("Estimated size of compressed db"), r, r / 1048576.0);
             }
         }
 
         if (szOldBearoff && !(pbc = BearoffInit(szOldBearoff, BO_NONE, NULL))) {
-            fprintf(stderr, _("Error initialising old bearoff database!\n"));
+            g_printerr(_("Error initialising old bearoff database!\n"));
             exit(2);
         }
 
@@ -1390,19 +1382,19 @@ main(int argc, char **argv)
          * database */
 
         if (pbc && (pbc->bt != BEAROFF_ONESIDED || pbc->fND != fND || pbc->fGammon < fGammon)) {
-            fprintf(stderr, _("The old database is not of the same kind as the" " requested database\n"));
+            g_printerr(_("The old database is not of the same kind as the" " requested database\n"));
             exit(2);
         }
 
         if (fND) {
-            generate_nd(nOS, nHashSize, fHeader, pbc, output);
+            generate_nd(nOS, nHashSize, fHeader, pbc, outfile);
         } else {
-            generate_os(nOS, fHeader, fCompress, fGammon, nHashSize, pbc, output);
+            generate_os(nOS, fHeader, fCompress, fGammon, nHashSize, pbc, outfile);
         }
 
         BearoffClose(pbc);
 
-        fprintf(stderr, "Number of re-reads while generating: %ld\n", cLookup);
+        g_printerr(_("Number of re-reads while generating: %ld\n"), cLookup);
     }
 
     /*
@@ -1413,23 +1405,28 @@ main(int argc, char **argv)
 
         int n = Combination(nTSP + nTSC, nTSC);
 
+        if (nTSC > 11) {
+            g_printerr(_("Size of two-sided bearoff database must be at most 11 chequers\n"));
+            exit(2);
+        }
+
         r = n;
         r = r * r * (fCubeful ? 8.0 : 2.0);
-        fprintf(stderr, "%-37s\n", _("Two-sided database:\n"));
-        fprintf(stderr, "%-37s: %12d\n", _("Number of points"), nTSP);
-        fprintf(stderr, "%-37s: %12d\n", _("Number of chequers"), nTSC);
-        fprintf(stderr, "%-37s: %12s\n", _("Calculate equities"),
+        g_printerr("%-37s\n", _("Two-sided database:\n"));
+        g_printerr("%-37s: %12d\n", _("Number of points"), nTSP);
+        g_printerr("%-37s: %12d\n", _("Number of chequers"), nTSC);
+        g_printerr("%-37s: %12s\n", _("Calculate equities"),
                 fCubeful ? _("cubeless and cubeful") : _("cubeless only"));
-        fprintf(stderr, "%-37s: %12s\n", _("Write header"), fHeader ? _("yes") : _("no"));
-        fprintf(stderr, "%-37s: %12d\n", _("Number of one-sided positions"), n);
-        fprintf(stderr, "%-37s: %12d\n", _("Total number of positions"), n * n);
-        fprintf(stderr, "%-37s: %.0f bytes (%.1f MB)\n", _("Size of resulting file"), r, r / 1048576.0);
-        fprintf(stderr, "%-37s: %12d\n", _("Size of xhash"), nHashSize);
-        fprintf(stderr, "%-37s: %12s %s\n", _("Reuse old bearoff database"), szOldBearoff ? _("yes") : _("no"),
+        g_printerr("%-37s: %12s\n", _("Write header"), fHeader ? _("yes") : _("no"));
+        g_printerr("%-37s: %12d\n", _("Number of one-sided positions"), n);
+        g_printerr("%-37s: %12d\n", _("Total number of positions"), n * n);
+        g_printerr("%-37s: %.0f %s (%.1f MB)\n", _("Size of resulting file"), r, _("bytes"), r / 1048576.0);
+        g_printerr("%-37s: %12d\n", _("Size of xhash"), nHashSize);
+        g_printerr("%-37s: %12s %s\n", _("Reuse old bearoff database"), szOldBearoff ? _("yes") : _("no"),
                 szOldBearoff ? szOldBearoff : "");
         /* initialise old bearoff database */
         if (szOldBearoff && !(pbc = BearoffInit(szOldBearoff, BO_NONE, NULL))) {
-            fprintf(stderr, _("Error initialising old bearoff database!\n"));
+            g_printerr(_("Error initialising old bearoff database!\n"));
             exit(2);
         }
 
@@ -1437,21 +1434,21 @@ main(int argc, char **argv)
          * database */
 
         if (pbc && (pbc->bt != BEAROFF_TWOSIDED || pbc->fCubeful != fCubeful)) {
-            fprintf(stderr, _("The old database is not of the same kind as the" " requested database\n"));
+            g_printerr(_("The old database is not of the same kind as the" " requested database\n"));
             exit(2);
         }
 
-        generate_ts(nTSP, nTSC, fHeader, fCubeful, nHashSize, pbc, output);
+        generate_ts(nTSP, nTSC, fHeader, fCubeful, nHashSize, pbc, outfile);
 
         /* close old bearoff database */
 
         BearoffClose(pbc);
 
-        fprintf(stderr, "Number of re-reads while generating: %ld\n", cLookup);
+        g_printerr(_("Number of re-reads while generating: %ld\n"), cLookup);
 
     }
 
-    fclose(output);
+    fclose(outfile);
     return 0;
 
 }
