@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2004 Joern Thyssen <jth@gnubg.org>
- * Copyright (C) 2004-2009 the AUTHORS
+ * Copyright (C) 2004-2023 the AUTHORS
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,9 +28,17 @@
 
 #define DB_VERSION 1
 
-
 extern int RelationalUpdatePlayerDetails(const char *oldName, const char *newName, const char *newNotes);
-extern float Ratio(float a, int b);
 extern statcontext *relational_player_stats_get(const char *player0, const char *player1);
 
+static inline float Ratiof(float a, int b)
+{
+    return b ? a / (float) b : 0.0f;
+}
+
+static inline double Ratio(double a, int b)
+{
+    return b ? a / (double) b : 0.0f;
+}
+
 #endif                          /* RELATIONAL_H */
