@@ -1,11 +1,11 @@
 /*
- * renderprefs.c
+ * Copyright (C) 2000-2003 Gary Wong <gtw@gnu.org>
+ * Copyright (C) 2003-2021 the AUTHORS
  *
- * by Gary Wong <gtw@gnu.org>, 2000, 2001, 2002, 2003.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: renderprefs.c,v 1.52 2016/01/03 17:23:25 plm Exp $
+ * $Id: renderprefs.c,v 1.64 2022/10/02 12:46:41 plm Exp $
  */
 
 #include "config.h"
@@ -34,7 +33,7 @@
 #include "gtkgame.h"
 #endif
 #if defined(USE_BOARD3D)
-#include "fun3d.h"
+#include "inc3d.h"
 #endif
 
 const char *aszWoodName[] = {
@@ -57,35 +56,21 @@ CopyAppearance(renderdata * prd)
     memcpy(prd, &rdAppearance, sizeof(rdAppearance));
 }
 
-static char
-HexDigit(char ch)
-{
-
-    ch = (char) toupper(ch);
-
-    if (ch >= '0' && ch <= '9')
-        return ch - '0';
-    else if (ch >= 'A' && ch <= 'F')
-        return ch - 'A' + 0xA;
-    else
-        return 0;
-}
-
 static int
 SetColour(const char *sz, unsigned char anColour[])
 {
-
-    int i;
+    unsigned long n;
 
     if (strlen(sz) < 7 || *sz != '#')
         return -1;
 
     sz++;
 
-    for (i = 0; i < 3; i++) {
-        anColour[i] = (char) (HexDigit(sz[0]) << 4) | HexDigit(sz[1]);
-        sz += 2;
-    }
+    n = strtoul(sz, 0, 16);
+
+    anColour[0] = (n & 0xFF0000) >> 16;
+    anColour[1] = (n & 0x00FF00) >> 8;
+    anColour[2] = (n & 0x0000FF);
 
     return 0;
 }
@@ -110,28 +95,6 @@ SetColourSpeckle(const char *sz, unsigned char anColour[], int *pnSpeckle)
     return 0;
 }
 
-/* Set colour (with floats) */
-static int
-SetColourX(float arColour[4], const char *sz)
-{
-
-    char *pch;
-    unsigned char anColour[3];
-
-    if ((pch = strchr(sz, ';')))
-        *pch++ = 0;
-
-    if (!SetColour(sz, anColour)) {
-        arColour[0] = anColour[0] / 255.0f;
-        arColour[1] = anColour[1] / 255.0f;
-        arColour[2] = anColour[2] / 255.0f;
-        return 0;
-    }
-
-    return -1;
-}
-
-#if defined(USE_BOARD3D)
 static int
 SetColourF(float arColour[4], const char *sz)
 {
@@ -140,7 +103,7 @@ SetColourF(float arColour[4], const char *sz)
     unsigned char anColour[3];
 
     if ((pch = strchr(sz, ';')))
-        *pch++ = 0;
+        *pch = 0;
 
     if (!SetColour(sz, anColour)) {
         arColour[0] = anColour[0] / 255.0f;
@@ -151,7 +114,6 @@ SetColourF(float arColour[4], const char *sz)
 
     return -1;
 }
-#endif                          /* USE_BOARD3D */
 
 #if defined(USE_BOARD3D)
 static int
@@ -170,37 +132,32 @@ SetMaterialCommon(Material * pMat, const char *sz, const char **arg)
 
     if (SetColourF(pMat->specularColour, sz) != 0)
         return -1;
+    sz += strlen(sz) + 1;
 
-    if (sz) {
-        sz += strlen(sz) + 1;
-        if ((pch = strchr(sz, ';')))
-            *pch = 0;
-    }
-    if (sz)
+    if ((pch = strchr(sz, ';')))
+        *pch = 0;
+
+    if (*sz)
         pMat->shine = atoi(sz);
     else
         pMat->shine = 128;
 
-    if (sz) {
-        sz += strlen(sz) + 1;
-        if ((pch = strchr(sz, ';')))
-            *pch = 0;
-    }
-    if (sz) {
-        int o = atoi(sz);
-        if (o == 100)
-            opac = 1;
-        else
-            opac = o / 100.0f;
-    } else
-        opac = 1;
+    sz += strlen(sz) + 1;
+
+    if ((pch = strchr(sz, ';')))
+        *pch = 0;
+
+    if (*sz)
+        opac = (float) atoi(sz) / 100.0f;
+    else
+        opac = 1.0f;
 
     pMat->ambientColour[3] = pMat->diffuseColour[3] = pMat->specularColour[3] = opac;
-    pMat->alphaBlend = (opac != 1) && (opac != 0);
+    pMat->alphaBlend = (opac < 1.0f) && (opac > 0.0f);
 
-    if (pch && sz) {
+    if (pch) {
         sz += strlen(sz) + 1;
-        if (sz && *sz) {
+        if (*sz) {
             *arg = sz;
             return 1;
         }
@@ -252,7 +209,7 @@ SetColourARSS(float aarColour[2][4],
     if ((pch = strchr(sz, ';')))
         *pch++ = 0;
 
-    if (!SetColourX(aarColour[i], sz)) {
+    if (!SetColourF(aarColour[i], sz)) {
 
         if (pch) {
             /* alpha */
@@ -286,7 +243,7 @@ SetColourARSS(float aarColour[2][4],
             arExponent[i] = (float) g_ascii_strtod(pch, NULL);
 
             if ((pch = strchr(pch, ';')))
-                *pch++ = 0;
+                *pch = 0;
         } else
             arExponent[i] = 10.0f;
 
@@ -298,8 +255,7 @@ SetColourARSS(float aarColour[2][4],
 
 /* Set colour, shine, specular, flag. */
 static int
-SetColourSSF(float aarColour[2][4],
-             gfloat arCoefficient[2], gfloat arExponent[2], int afDieColour[2], char *sz, int i)
+SetColourSSF(float aarColour[2][4], gfloat arCoefficient[2], gfloat arExponent[2], int afDieColour[2], char *sz, int i)
 {
 
     char *pch;
@@ -307,7 +263,7 @@ SetColourSSF(float aarColour[2][4],
     if ((pch = strchr(sz, ';')))
         *pch++ = 0;
 
-    if (!SetColourX(aarColour[i], sz)) {
+    if (!SetColourF(aarColour[i], sz)) {
 
         if (pch) {
             /* shine */
@@ -332,7 +288,7 @@ SetColourSSF(float aarColour[2][4],
             afDieColour[i] = (toupper(*pch) == 'Y');
 
             if ((pch = strchr(pch, ';')))
-                *pch++ = 0;
+                *pch = 0;
         } else
             afDieColour[i] = TRUE;
 
@@ -360,15 +316,17 @@ SetWood(const char *sz, woodtype * pbw)
 
 #if defined(USE_BOARD3D)
 static displaytype
-check_for_board3d(char *szValue)
+check_for_board3d(const char *szValue)
 {
     if (*szValue == '2')
         return DT_2D;
-    else if (!fX || gtk_gl_init_success)
+    else if (!fX || widget3dValid)
         return DT_3D;
     return DT_2D;
 }
+
 #endif
+
 extern void
 RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue)
 {
@@ -387,7 +345,7 @@ RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue)
         fValueError = SetColour(szValue, prd->aanBoardColour[1]);
     else if (!StrNCaseCmp(szParam, "cube", c))
         /* cube=colour */
-        fValueError = SetColourX(prd->arCubeColour, szValue);
+        fValueError = SetColourF(prd->arCubeColour, szValue);
     else if (!StrNCaseCmp(szParam, "translucent", c))
         /* deprecated option "translucent"; ignore */
         ;
@@ -468,15 +426,15 @@ RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue)
         float rAzimuth, rElevation;
         gchar **split = g_strsplit(szValue, ";", 0);
 
-        rAzimuth = (float) (g_ascii_strtod(split[0], NULL) * G_PI / 180.0);
-        rElevation = (float) (g_ascii_strtod(split[1], NULL) * G_PI / 180.0);
+        rAzimuth = (float) g_ascii_strtod(split[0], NULL) * F_PI / 180.0f;
+        rElevation = (float) g_ascii_strtod(split[1], NULL) * F_PI / 180.0f;
 
         g_strfreev(split);
 
         if (rElevation < 0.0f)
             rElevation = 0.0f;
-        else if (rElevation > (float) G_PI_2)
-            rElevation = (float) G_PI_2;
+        else if (rElevation > F_PI_2)
+            rElevation = F_PI_2;
 
         prd->arLight[2] = sinf(rElevation);
         prd->arLight[0] = cosf(rAzimuth) * sqrtf(1.0f - prd->arLight[2] * prd->arLight[2]);
@@ -500,10 +458,6 @@ RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue)
         prd->animateRoll = toupper(*szValue) == 'Y';
     else if (!StrNCaseCmp(szParam, "animateflag", c))
         prd->animateFlag = toupper(*szValue) == 'Y';
-    else if (!StrNCaseCmp(szParam, "closeboard", c))
-        prd->closeBoardOnExit = toupper(*szValue) == 'Y';
-    else if (!StrNCaseCmp(szParam, "quickdraw", c))
-        prd->quickDraw = toupper(*szValue) == 'Y';
     else if (!StrNCaseCmp(szParam, "curveaccuracy", c))
         prd->curveAccuracy = atoi(szValue);
     else if (!StrNCaseCmp(szParam, "lighttype", c))
@@ -521,9 +475,9 @@ RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue)
     else if (!StrNCaseCmp(szParam, "lightspecular", c))
         prd->lightLevels[2] = atoi(szValue);
     else if (!StrNCaseCmp(szParam, "boardangle", c))
-        prd->boardAngle = atoi(szValue);
+        prd->boardAngle = (float) g_ascii_strtod(szValue, &szValue);
     else if (!StrNCaseCmp(szParam, "skewfactor", c))
-        prd->skewFactor = atoi(szValue);
+        prd->skewFactor = (float) g_ascii_strtod(szValue, &szValue);
     else if (!StrNCaseCmp(szParam, "planview", c))
         prd->planView = toupper(*szValue) == 'Y';
     else if (!StrNCaseCmp(szParam, "dicesize", c))
@@ -534,9 +488,13 @@ RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue)
         prd->bgInTrays = toupper(*szValue) == 'Y';
     else if (!StrNCaseCmp(szParam, "roundedpoints", c))
         prd->roundedPoints = toupper(*szValue) == 'Y';
-    else if (!StrNCaseCmp(szParam, "piecetype", c))
+    else if (!StrNCaseCmp(szParam, "piecetype", c)) {
         prd->pieceType = (PieceType) atoi(szValue);
-    else if (!StrNCaseCmp(szParam, "piecetexturetype", c))
+        if ((unsigned int)prd->pieceType > PT_FLAT) {
+            prd->pieceType = PT_FLAT;
+            fValueError = TRUE;
+        }
+    } else if (!StrNCaseCmp(szParam, "piecetexturetype", c))
         prd->pieceTextureType = (PieceTextureType) atoi(szValue);
     else if ((!StrNCaseCmp(szParam, "chequers3d", strlen("chequers3d")) ||
               !StrNCaseCmp(szParam, "checkers3d", strlen("checkers3d"))) &&
@@ -584,7 +542,7 @@ RenderPreferencesParam(renderdata * prd, const char *szParam, char *szValue)
              (!StrNCaseCmp(szParam, "dot", c - 1) ||
               !StrNCaseCmp(szParam, "dot", c - 1)) && (szParam[c - 1] == '0' || szParam[c - 1] == '1'))
         /* dot=colour */
-        fValueError = SetColourX(prd->aarDiceDotColour[szParam[c - 1] - '0'], szValue);
+        fValueError = SetColourF(prd->aarDiceDotColour[szParam[c - 1] - '0'], szValue);
     else if (c > 1 && !StrNCaseCmp(szParam, "points", c - 1) && (szParam[c - 1] == '0' || szParam[c - 1] == '1'))
         /* pointsn=colour;speckle */
         fValueError = SetColourSpeckle(szValue,
@@ -641,14 +599,14 @@ SaveRenderingSettings(FILE * pf)
     gchar buf2[G_ASCII_DTOSTR_BUF_SIZE];
     gchar buf3[G_ASCII_DTOSTR_BUF_SIZE];
     renderdata *prd = GetMainAppearance();
-    float rElevation = (float) (asinf(prd->arLight[2]) * 180 / G_PI);
+    float rElevation = asinf(prd->arLight[2]) * 180.0f / F_PI;
     float rAzimuth = (fabsf(prd->arLight[2] - 1.0f) < 1e-5f) ? 0.0f :
-        (float) (acosf(prd->arLight[0] / sqrtf(1.0f - prd->arLight[2] * prd->arLight[2])) * 180 / G_PI);
+        acosf(prd->arLight[0] / sqrtf(1.0f - prd->arLight[2] * prd->arLight[2])) * 180.0f / F_PI;
 
     if (prd->arLight[1] < 0)
         rAzimuth = 360 - rAzimuth;
 
-    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", prd->aSpeckle[0] / 128.0f);
+    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", (float) prd->aSpeckle[0] / 128.0f);
     fprintf(pf, "set appearance board=#%02X%02X%02X;%s ",
             prd->aanBoardColour[0][0], prd->aanBoardColour[0][1], prd->aanBoardColour[0][2], buf);
 
@@ -663,26 +621,23 @@ SaveRenderingSettings(FILE * pf)
     fprintf(pf, "shadowdarkness=%d ", prd->shadowDarkness);
     fprintf(pf, "animateroll=%c ", prd->animateRoll ? 'y' : 'n');
     fprintf(pf, "animateflag=%c ", prd->animateFlag ? 'y' : 'n');
-    fprintf(pf, "closeboard=%c ", prd->closeBoardOnExit ? 'y' : 'n');
-    fprintf(pf, "quickdraw=%c ", prd->quickDraw ? 'y' : 'n');
     fprintf(pf, "curveaccuracy=%u ", prd->curveAccuracy);
     fprintf(pf, "lighttype=%c ", prd->lightType == LT_POSITIONAL ? 'p' : 'd');
 
-    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%f", prd->lightPos[0]);
+    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", prd->lightPos[0]);
     fprintf(pf, "lightposx=%s ", buf);
-
-    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%f", prd->lightPos[1]);
+    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", prd->lightPos[1]);
     fprintf(pf, "lightposy=%s ", buf);
-    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%f", prd->lightPos[2]);
+    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", prd->lightPos[2]);
     fprintf(pf, "lightposz=%s ", buf);
     fprintf(pf, "lightambient=%d ", prd->lightLevels[0]);
     fprintf(pf, "lightdiffuse=%d ", prd->lightLevels[1]);
     fprintf(pf, "lightspecular=%d ", prd->lightLevels[2]);
-    fprintf(pf, "boardangle=%d ", prd->boardAngle);
-    fprintf(pf, "skewfactor=%d ", prd->skewFactor);
+    fprintf(pf, "boardangle=%.0f ", prd->boardAngle);
+    fprintf(pf, "skewfactor=%.0f ", prd->skewFactor);
     fprintf(pf, "planview=%c ", prd->planView ? 'y' : 'n');
 
-    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%f", prd->diceSize);
+    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", prd->diceSize);
     fprintf(pf, "dicesize=%s ", buf);
 
     fprintf(pf, "roundededges=%c ", prd->roundedEdges ? 'y' : 'n');
@@ -711,12 +666,12 @@ SaveRenderingSettings(FILE * pf)
     fprintf(pf, "wood=%s ", aszWoodName[prd->wt]);
     fprintf(pf, "hinges=%c ", prd->fHinges ? 'y' : 'n');
 
-    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%f", rAzimuth);
-    g_ascii_formatd(buf1, G_ASCII_DTOSTR_BUF_SIZE, "%f", rElevation);
+    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%.1f", rAzimuth);
+    g_ascii_formatd(buf1, G_ASCII_DTOSTR_BUF_SIZE, "%.1f", rElevation);
     fprintf(pf, "light=%s;%s ", buf, buf1);
 
-    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%0.1f", (1.0 - prd->rRound));
-    fprintf(pf, "shape=%s  ", buf);
+    g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%0.1f", (1.0f - prd->rRound));
+    fprintf(pf, "shape=%s ", buf);
 
     g_ascii_formatd(buf, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", prd->aarColour[0][3]);
     g_ascii_formatd(buf1, G_ASCII_DTOSTR_BUF_SIZE, "%.2f", prd->arRefraction[0]);
