@@ -1,11 +1,9 @@
-#
-# batch_win.py -- batch import and analysis of multiple files using gnubg
-#
-# by Oystein Johansen <oystein@gnubg.org>, 2004
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of version 3 or later of the GNU General Public License as
-# published by the Free Software Foundation.
+# Copyright (C) 2004 Oystein Johansen <oystein@gnubg.org>
+
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,18 +11,16 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
+
+#
+# $Id: batch_win.py,v 1.6 2022/06/29 21:09:18 plm Exp $
 #
-# $Id: batch_win.py,v 1.3 2013/06/16 03:03:07 mdpetch Exp $
 
 # This file is inspired of the batch.py file of Jon Kinsey. The code
 # contains MS-Windows specific code and will therefore only work on MS-Windows
 # together with GNU Backgammon and Python.
 
-import win32ui
-import win32con
-
 # file extensions, names and gnubg import commands
 
 extensions = ['mat', 'pos', 'sgg', 'tmg', 'txt']
@@ -59,5 +55,6 @@ def AnalyzeFile(file, type):
     file = file[:-len(extensions[type])] + "sgf"
     gnubg.command('save match "' + file + '"')
 
+
 files = GetFiles()
 BatchAnalyze(files)
