@@ -1,11 +1,11 @@
 /*
- * sgf.c
+ * Copyright (C) 2000-2002 Gary Wong <gtw@gnu.org>
+ * Copyright (C) 2001-2023 the AUTHORS
  *
- * by Gary Wong <gtw@gnu.org>, 2000, 2001.
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: sgf.c,v 1.161 2017/04/27 20:38:12 plm Exp $
+ * $Id: sgf.c,v 1.174 2022/02/26 20:22:15 plm Exp $
  */
 
 #include "config.h"
@@ -29,7 +28,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "glib-ext.h"
 
 #include "backgammon.h"
 #include "dice.h"
@@ -100,14 +98,12 @@ LoadCollection(char *sz)
 
     listOLD *plCollection, *pl, *plRoot, *plProp;
     FILE *pf;
-    int fBackgammon;
-    property *pp;
 
     fError = FALSE;
     SGFErrorHandler = ErrorHandler;
 
     if (strcmp(sz, "-")) {
-        if (!(pf = gnubg_g_fopen(sz, "r"))) {
+        if (!(pf = g_fopen(sz, "r"))) {
             outputerr(sz);
             return NULL;
         }
@@ -127,10 +123,12 @@ LoadCollection(char *sz)
     if (plCollection) {
         pl = plCollection->plNext;
         while (pl != plCollection) {
+            int fBackgammon = FALSE;
+
             plRoot = ((listOLD *) ((listOLD *) pl->p)->plNext->p)->plNext->p;
-            fBackgammon = FALSE;
+
             for (plProp = plRoot->plNext; plProp != plRoot; plProp = plProp->plNext) {
-                pp = plProp->p;
+                property *pp = plProp->p;
 
                 if (pp->ach[0] == 'G' && pp->ach[1] == 'M' && pp->pl->plNext->p && atoi((char *)
                                                                                         pp->pl->plNext->p) == 6) {
@@ -320,7 +318,7 @@ CopyEscapedString(const char *pchOrig)
 
     char *sz, *pch;
 
-    for (pch = sz = malloc(strlen(pchOrig) + 1); *pchOrig; pchOrig++) {
+    for (pch = sz = g_malloc(strlen(pchOrig) + 1); *pchOrig; pchOrig++) {
         if (*pchOrig == '\\') {
             if (pchOrig[1] == '\\') {
                 *pch++ = '\\';
@@ -350,7 +348,7 @@ RestoreText(char *sz, char **ppch)
     if (!sz || !*sz)
         return;
 
-    free(*ppch);
+    g_free(*ppch);
 
     *ppch = CopyEscapedString(sz);
 }
@@ -516,17 +514,18 @@ Point(char ch, int f)
 static void
 RestoreRolloutScore(move * pm, const char *sz)
 {
-
     char *pc = strstr(sz, "Score");
 
-    pm->rScore = -99999;
-    pm->rScore2 = -99999;
+    if (pc) {
+        pc += 6;
+        pm->rScore = (float) g_ascii_strtod(pc, &pc);
+        pm->rScore2 = (float) g_ascii_strtod(pc, &pc);
+    } else {
+        pm->rScore = -99999;
+        pm->rScore2 = -99999;
+    }
 
-    if (!pc)
-        return;
-    pc += 6;
-    pm->rScore = (float) g_ascii_strtod(pc, &pc);
-    pm->rScore2 = (float) g_ascii_strtod(pc, &pc);
+    return;
 }
 
 static void
@@ -580,8 +579,6 @@ InitEvalContext(evalcontext * pec)
 static void
 RestoreEvalContext(evalcontext * pec, char *pc)
 {
-
-    int fUsePrune = 0;
     int ver = CheckSGFVersion(&pc);
 
     InitEvalContext(pec);
@@ -597,8 +594,7 @@ RestoreEvalContext(evalcontext * pec, char *pc)
     } else {
         pec->fDeterministic = (unsigned int) strtol(pc, &pc, 10);
         pec->rNoise = (float) g_ascii_strtod(pc, &pc);
-        fUsePrune = (unsigned int) strtol(pc, &pc, 10);
-        pec->fUsePrune = fUsePrune;
+        pec->fUsePrune = (unsigned int) strtol(pc, &pc, 10);
     }
 }
 
@@ -651,7 +647,7 @@ RestoreRolloutRolloutContext(rolloutcontext * prc, const char *sz)
     if (!pc)
         return;
 
-    sscanf(pc, "RC %d %d %d %hu %u \"%[^\"]\" %lu %d %d %d",
+    sscanf(pc, "RC %d %d %d %hu %u \"%1023[^\"]\" %lu %d %d %d",
            &fCubeful,
            &fVarRedn,
            &fInitial, &prc->nTruncate, &prc->nTrials, szTemp, &prc->nSeed, &fRotate, &fTruncBearoff2, &fTruncBearoffOS);
@@ -778,7 +774,7 @@ RestoreExtendedRolloutContext(rolloutcontext * prc, const char *sz)
     if (!pc)
         return;
 
-    if (sscanf(pc, "RC %d %d %d %d %d %d %hu %d %d %hu \"%[^\"]\" %lu",
+    if (sscanf(pc, "RC %d %d %d %d %d %d %hu %d %d %hu \"%1023[^\"]\" %lu",
                &fCubeful,
                &fVarRedn,
                &fInitial,
@@ -874,11 +870,10 @@ RestoreDoubleAnalysis(property * pp,
         ++pch;
         pes->et = EVAL_EVAL;
         ver = CheckSGFVersion(&pch);
-        pes->ec.rNoise = 0.0f;
         memset(aarOutput[0], 0, NUM_ROLLOUT_OUTPUTS * sizeof(float));
         memset(aarOutput[1], 0, NUM_ROLLOUT_OUTPUTS * sizeof(float));
-        aarOutput[0][OUTPUT_CUBEFUL_EQUITY] = -20000.0;
-        aarOutput[1][OUTPUT_CUBEFUL_EQUITY] = -20000.0;
+        aarOutput[0][OUTPUT_CUBEFUL_EQUITY] = -20000.0f;
+        aarOutput[1][OUTPUT_CUBEFUL_EQUITY] = -20000.0f;
 
         if (ver < 2) {
             /* skip 4 fields left over from earlier formats */
@@ -956,7 +951,6 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
                     movelist * pml, unsigned int *piMove, evalsetup * pesChequer, const matchstate * pms)
 {
     listOLD *pl = pp->pl->plNext;
-    char *pc, *pch, ch;
     move *pm;
     int i;
     int fUsePrune = 0;
@@ -976,11 +970,13 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
     pml->cMaxMoves = pml->cMaxPips = pml->iMoveBest = 0;
     pml->rBestScore = 0;
 
-    pm = pml->amMoves = calloc(pml->cMoves, sizeof(move));
+    pm = pml->amMoves = g_malloc0(pml->cMoves * sizeof(move));
 
     pesChequer->et = EVAL_NONE;
 
     for (pl = pp->pl->plNext->plNext; pl->p; pl = pl->plNext, pm++) {
+        char *pc, *pch, ch;
+
         pc = pl->p;
 
         /* FIXME we could work these out, but it hardly seems worth it */
@@ -1003,7 +999,7 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
 
         pch = pc;
         while (isspace(ch = *pch++)) {
-        };
+        }
         pch++;
 
         switch (ch) {
@@ -1023,6 +1019,12 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
                 (void) strtol(pch, &pch, 10);   /* reduced evaluation -- no longer supported */
                 pm->esMove.ec.fDeterministic = (unsigned int) strtol(pch, &pch, 10);
                 pm->esMove.ec.rNoise = (float) g_ascii_strtod(pch, &pch);
+/*
+ * Alternatives for ver == 2 and ver > 2 (that is == 3) are identical,
+ * version 3 still writes a reduced evalution flag (set to 0) and
+ * discards it on reads. See comment in WriteMoveAnalysis()
+ */
+#if 0
             } else if (ver == 2) {
                 pm->esMove.ec.nPlies = (unsigned int) strtol(pch, &pch, 10);
                 if (*pch == 'C') {
@@ -1033,6 +1035,7 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
                 pm->esMove.ec.fDeterministic = (unsigned int) strtol(pch, &pch, 10);
                 pm->esMove.ec.rNoise = (float) g_ascii_strtod(pch, &pch);
                 fUsePrune = (int) strtol(pch, &pch, 10);
+#endif
             } else {
                 pm->esMove.ec.nPlies = (unsigned int) strtol(pch, &pch, 10);
                 if (*pch == 'C') {
@@ -1065,7 +1068,6 @@ RestoreMoveAnalysis(property * pp, int fPlayer,
         if (cmp_evalsetup(pesChequer, &pm->esMove) < 0)
             memcpy(pesChequer, &pm->esMove, sizeof(evalsetup));
 
-
     }
 }
 
@@ -1074,13 +1076,13 @@ PointList(listOLD * pl, int an[])
 {
 
     int i;
-    char *pch, ch0, ch1;
+    char ch0, ch1;
 
     for (i = 0; i < 25; i++)
         an[i] = 0;
 
     for (; pl->p; pl = pl->plNext) {
-        pch = pl->p;
+        char *pch = pl->p;
 
         if (strchr(pch, ':')) {
             ch0 = ch1 = 0;
@@ -1163,7 +1165,7 @@ RestoreNode(listOLD * pl)
 
                 if (pmr->anDice[0] < 1 || pmr->anDice[0] > 6 || pmr->anDice[1] < 1 || pmr->anDice[1] > 6) {
                     /* illegal roll -- ignore */
-                    free(pmr);
+                    g_free(pmr);
                     pmr = NULL;
                 }
             }
@@ -1216,7 +1218,7 @@ RestoreNode(listOLD * pl)
                 pmr->scp.fCubeOwner = 0;
                 break;
             default:
-                free(pmr);
+                g_free(pmr);
                 pmr = NULL;
             }
 
@@ -1364,7 +1366,7 @@ static void
 RestoreGame(listOLD * pl)
 {
 
-    moverecord *pmr, *pmrResign;
+    moverecord *pmr;
 
     InitBoard(ms.anBoard, ms.bgv);
 
@@ -1392,7 +1394,7 @@ RestoreGame(listOLD * pl)
          * inverted when shown. /jth 2003-10-12 
          * ms.fTurn = ms.fMove = -1; */
 
-        pmrResign = NewMoveRecord();
+        moverecord *pmrResign = NewMoveRecord();
 
         pmrResign->mt = MOVE_RESIGN;
 
@@ -1450,6 +1452,9 @@ CommandLoadGame(char *sz)
         }
 
         setDefaultFileName(sz);
+        if (fUseKeyNames)
+            SmartSit();
+
 
 #endif
 
@@ -1502,6 +1507,8 @@ CommandLoadPosition(char *sz)
         }
 
         setDefaultFileName(sz);
+        if (fUseKeyNames)
+            SmartSit();
 
 #endif
 
@@ -1512,7 +1519,6 @@ CommandLoadPosition(char *sz)
 extern void
 CommandLoadMatch(char *sz)
 {
-
     listOLD *pl;
 
     sz = NextToken(&sz);
@@ -1523,6 +1529,8 @@ CommandLoadMatch(char *sz)
     }
 
     if ((pl = LoadCollection(sz))) {
+        int nGames = 0, nMoves = 0;
+
         /* FIXME make sure the root nodes have MI properties; if not,
          * we're loading a session. */
         if (!get_input_discard())
@@ -1539,6 +1547,7 @@ CommandLoadMatch(char *sz)
 
         for (pl = pl->plNext; pl->p; pl = pl->plNext) {
             RestoreGame(pl->p);
+            nGames++;
         }
 
         FreeGameTreeSeq(pl);
@@ -1553,9 +1562,38 @@ CommandLoadMatch(char *sz)
 #endif
 
         setDefaultFileName(sz);
+        if (fUseKeyNames)
+            SmartSit();
 
-        /* FIXME : don't do this if we just loaded a single position */
-        if (fGotoFirstGame)
+        for (pl = plGame->plNext; pl != plGame; pl = pl->plNext) {
+            moverecord *pmr = pl->p;
+
+            switch (pmr->mt) {
+            case MOVE_NORMAL:
+            case MOVE_DOUBLE:
+            case MOVE_TAKE:
+            case MOVE_DROP:
+                nMoves++;
+                break;
+            default:
+                /* do not count the other pseudo-moves */
+                break;
+            }
+        }
+
+        if (nGames == 1 && nMoves == 1) {
+            moverecord *pmr;
+
+            CommandFirstMove(NULL);
+            pl = plGame->plNext;
+            pmr = pl->p;
+            while (pmr->mt != MOVE_NORMAL && pmr->mt != MOVE_DOUBLE) {
+                CommandNext(NULL);
+                pl = pl->plNext;
+                pmr = pl->p;
+            }
+            CommandPrevious(NULL);
+        } else if (fGotoFirstGame)
             CommandFirstGame(NULL);
 
     }
@@ -1567,7 +1605,7 @@ WriteEscapedString(FILE * pf, char *pch, int fEscapeColons)
 
     char *sz, *pc;
 
-    sz = (char *) malloc(2 * strlen(pch) + 1);
+    sz = (char *) g_malloc(2 * strlen(pch) + 1);
 
     for (pc = sz; *pch; pch++)
         switch (*pch) {
@@ -1589,10 +1627,10 @@ WriteEscapedString(FILE * pf, char *pch, int fEscapeColons)
             break;
         }
 
-    *pc++ = 0;
+    *pc = 0;
 
     fputs(sz, pf);
-    free(sz);
+    g_free(sz);
 }
 
 static void
@@ -1821,7 +1859,13 @@ WriteMoveAnalysis(FILE * pf, int fPlayer, movelist * pml, unsigned int iMove)
             fprintf(pf, "%u%s %d %u %s %u",
                     pml->amMoves[i].esMove.ec.nPlies,
                     pml->amMoves[i].esMove.ec.fCubeful ? "C" : "",
-                    0, pml->amMoves[i].esMove.ec.fDeterministic, buffer, pml->amMoves[i].esMove.ec.fUsePrune);
+                    /*
+                     * Former reduced evaluation flag
+                     * Kept for backward compatibility ?
+                     * Always 0 in SGF ver. 3
+                     */
+                    0,
+                    pml->amMoves[i].esMove.ec.fDeterministic, buffer, pml->amMoves[i].esMove.ec.fUsePrune);
             break;
 
         case EVAL_ROLLOUT:
@@ -2080,13 +2124,12 @@ SaveGame(FILE * pf, listOLD * plGame)
     putc(']', pf);
 
     if (!pmr->g.i) {
-        char szDate[32];
-
         WriteProperty(pf, "WR", mi.pchRating[0]);
         WriteProperty(pf, "BR", mi.pchRating[1]);
         if (mi.nYear) {
-            sprintf(szDate, "%04u-%02u-%02u", mi.nYear, mi.nMonth, mi.nDay);
+            char *szDate = g_strdup_printf("%04u-%02u-%02u", mi.nYear, mi.nMonth, mi.nDay);
             WriteProperty(pf, "DT", szDate);
+            g_free(szDate);
         }
         WriteProperty(pf, "EV", mi.pchEvent);
         WriteProperty(pf, "RO", mi.pchRound);
@@ -2097,9 +2140,6 @@ SaveGame(FILE * pf, listOLD * plGame)
 
     if (pmr->g.fCrawford || pmr->g.fJacoby || pmr->g.bgv != VARIATION_STANDARD || !pmr->g.fCubeUse) {
 
-        static const char *aszSGFVariation[NUM_VARIATIONS] = { NULL, "Nackgammon", "Hypergammon1", "Hypergammon2",
-            "Hypergammon3"
-        };
         int fFirst = TRUE;
 
         fputs("RU[", pf);
@@ -2112,9 +2152,12 @@ SaveGame(FILE * pf, listOLD * plGame)
             AddRule(pf, "CrawfordGame", &fFirst);
         if (pmr->g.fJacoby)
             AddRule(pf, "Jacoby", &fFirst);
-        if (pmr->g.bgv != VARIATION_STANDARD)
-            AddRule(pf, aszSGFVariation[pmr->g.bgv], &fFirst);
+        if (pmr->g.bgv != VARIATION_STANDARD) {
+            static const char *aszSGFVariation[NUM_VARIATIONS] =
+                { NULL, "Nackgammon", "Hypergammon1", "Hypergammon2", "Hypergammon3" };
 
+            AddRule(pf, aszSGFVariation[pmr->g.bgv], &fFirst);
+        }
         fputs("]", pf);
     }
 
@@ -2306,7 +2349,7 @@ CommandSaveGame(char *sz)
 
     if (!strcmp(sz, "-"))
         pf = stdout;
-    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
+    else if (!(pf = g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -2326,6 +2369,7 @@ CommandSaveMatch(char *sz)
 
     FILE *pf;
     listOLD *pl;
+    int fDontClose = FALSE;
 
     sz = NextToken(&sz);
 
@@ -2344,9 +2388,10 @@ CommandSaveMatch(char *sz)
     if (!confirmOverwrite(sz, fConfirmSave))
         return;
 
-    if (!strcmp(sz, "-"))
+   if (!strcmp(sz, "-")) {
         pf = stdout;
-    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
+        fDontClose = TRUE;
+    } else if (!(pf = g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -2354,7 +2399,7 @@ CommandSaveMatch(char *sz)
     for (pl = lMatch.plNext; pl != &lMatch; pl = pl->plNext)
         SaveGame(pf, pl->p);
 
-    if (pf != stdout)
+    if (!fDontClose)
         fclose(pf);
 
     setDefaultFileName(sz);
@@ -2374,6 +2419,7 @@ CommandSavePosition(char *sz)
     moverecord *pmr_cur = NULL;
     moverecord *pmscv;
     moverecord *pmscp;
+    int fDontClose = FALSE;
 
     sz = NextToken(&sz);
 
@@ -2390,9 +2436,10 @@ CommandSavePosition(char *sz)
     if (!confirmOverwrite(sz, fConfirmSave))
         return;
 
-    if (!strcmp(sz, "-"))
+    if (!strcmp(sz, "-")) {
         pf = stdout;
-    else if (!(pf = gnubg_g_fopen(sz, "w"))) {
+        fDontClose = TRUE;
+    } else if (!(pf = g_fopen(sz, "w"))) {
         outputerr(sz);
         return;
     }
@@ -2473,17 +2520,17 @@ CommandSavePosition(char *sz)
 
     SaveGame(pf, &l);
 
-    if (pf != stdout)
+    if (!fDontClose)
         fclose(pf);
 
     while (l.plNext->p)
         ListDelete(l.plNext);
 
-    free(pmgi);
-    free(pmsb);
-    free(pmsd);
-    free(pmscv);
-    free(pmscp);
+    g_free(pmgi);
+    g_free(pmsb);
+    g_free(pmsd);
+    g_free(pmscv);
+    g_free(pmscp);
 
     setDefaultFileName(sz);
 }
