@@ -1,6 +1,11 @@
-/* This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+/*
+ * Copyright (C) 2007-2009 Christian Anthon <anthon@kiku.dk>
+ * Copyright (C) 2007-2019 the AUTHORS
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -8,10 +13,9 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: simpleboard.c,v 1.26 2018/04/23 22:01:58 plm Exp $
+ * $Id: simpleboard.c,v 1.30 2021/02/07 21:01:02 plm Exp $
  */
 
 /*! \file simpleboard.c
@@ -32,7 +36,7 @@
 /*! \brief get number of checkers from a backgammon variation
  *
  */
-static gint
+static guint
 checkers_from_bgv(bgvariation bgv)
 {
     switch (bgv) {
@@ -65,10 +69,10 @@ fill_and_stroke(cairo_t * cr, SimpleBoardColor c)
 
 /*! \brief calculates the point position and direction up or down
  * 
- * points are numbered 0 to 23 counter clockwize for the top player
+ * points are numbered 0 to 23 counter clockwise for the top player
  */
 static void
-get_point_base(gint i, gint * x, gint * y, gint * direction)
+get_point_base(gint i, gint * restrict x, gint * restrict y, gint * restrict direction)
 {
     g_assert(i >= 0 && i < 24);
 
@@ -84,7 +88,7 @@ get_point_base(gint i, gint * x, gint * y, gint * direction)
         *x = 30 + (11 - i) * 20;
         *y = 30;
         *direction = 1;
-    } else if (i > -1) {
+    } else {
         *x = 170 + (5 - i) * 20;
         *y = 30;
         *direction = 1;
@@ -122,7 +126,7 @@ draw_header_text(SimpleBoard * board)
         return;
     cairo_move_to(board->cr, board->text_size * 3, board->text_size * 3);
     draw_fixed_text(board->cr, board->header, board->text_size);
-    cairo_translate(board->cr, 0.0, board->text_size * 6);
+    cairo_translate(board->cr, 0.0, board->text_size * 7.5);
 }
 
 /*! \brief draws the annotation text
@@ -174,9 +178,9 @@ static void
 draw_points(SimpleBoard * board)
 {
     gint x, y, direction, i;
-    gchar *number;
     cairo_t *cr = board->cr;
     for (i = 0; i < 24; i++) {
+        gchar *number;
         SimpleBoardColor color = board->color_point[i % 2];
         gint point_nr;
 
@@ -360,10 +364,9 @@ draw_turn(SimpleBoard * board)
 }
 
 static void
-draw_checkers_on_xy(cairo_t * cr, gint x, gint y, gint direction, gint max, gint number, SimpleBoardColor color)
+draw_checkers_on_xy(cairo_t * cr, gint x, gint y, gint direction, guint max, guint number, SimpleBoardColor color)
 {
-    gint p;
-    gchar *checker_text;
+    guint p;
     for (p = 0; number > 0 && p < max; number--, p++) {
         y += 20 * direction;
         cairo_move_to(cr, x + 9, y);
@@ -372,7 +375,7 @@ draw_checkers_on_xy(cairo_t * cr, gint x, gint y, gint direction, gint max, gint
         fill_and_stroke(cr, color);
     }
     if (number) {
-        checker_text = g_strdup_printf("%d", number + max);
+        gchar *checker_text = g_strdup_printf("%u", number + max);
         cairo_move_to(cr, x, y);
         draw_centered_text(cr, color.text, 7.0, checker_text);
         g_free(checker_text);
@@ -380,11 +383,11 @@ draw_checkers_on_xy(cairo_t * cr, gint x, gint y, gint direction, gint max, gint
 }
 
 static void
-draw_checkers_on_point(cairo_t * cr, gint point, gint number, SimpleBoardColor color)
+draw_checkers_on_point(cairo_t * cr, gint point, guint number, SimpleBoardColor color)
 {
     gint x, y, direction;
 
-    g_assert(number >= 0 && number <= 15);
+    g_assert(number <= 15);
 
     if (!number)
         return;
@@ -395,7 +398,7 @@ draw_checkers_on_point(cairo_t * cr, gint point, gint number, SimpleBoardColor c
 }
 
 static void
-draw_checkers_on_bar(cairo_t * cr, gint i, gint n, SimpleBoardColor color)
+draw_checkers_on_bar(cairo_t * cr, gint i, guint n, SimpleBoardColor color)
 {
     gint x = 150;
     gint y = i ? 50 : 250;
@@ -405,7 +408,7 @@ draw_checkers_on_bar(cairo_t * cr, gint i, gint n, SimpleBoardColor color)
 }
 
 static void
-draw_checkers_off(cairo_t * cr, gint i, gint n, SimpleBoardColor color)
+draw_checkers_off(cairo_t * cr, gint i, guint n, SimpleBoardColor color)
 {
     gint x = 290;
     gint y = i ? 280 : 20;
@@ -417,7 +420,8 @@ draw_checkers_off(cairo_t * cr, gint i, gint n, SimpleBoardColor color)
 static void
 draw_checkers(SimpleBoard * board)
 {
-    gint player, point, p, n, i, unplaced;
+    gint player, point, p, i;
+    guint n, unplaced;
     SimpleBoardColor c;
     for (i = 0; i < 2; i++) {
         player = (board->ms.fMove) ? i : !i;
@@ -479,7 +483,7 @@ simple_board_draw(SimpleBoard * board)
     draw_turn(board);
     cairo_restore(cr);
     cairo_save(cr);
-    cairo_translate(cr, board->text_size * 3, board->text_size * 6 + board->size);
+    cairo_translate(cr, board->text_size * 3, board->text_size * 7.5 + board->size);
     draw_annotation_text(board);
     cairo_restore(cr);
 
@@ -487,7 +491,7 @@ simple_board_draw(SimpleBoard * board)
 }
 
 extern SimpleBoard *
-simple_board_new(matchstate * ms, cairo_t * cr, float simple_board_size)
+simple_board_new(matchstate * state, cairo_t * cr, float simple_board_size)
 {
     SimpleBoard *board;
     SimpleBoardColor black_black_white = { {0.0f, 0.0f, 0.0f}, {0.0f, 0.0f, 0.0f}, {1.0f, 1.0f, 1.0f} };
@@ -502,8 +506,8 @@ simple_board_new(matchstate * ms, cairo_t * cr, float simple_board_size)
     board->color_cube = white_black_black;
     board->size = simple_board_size;
     board->text_size = 6;
-    if (ms)
-        board->ms = *ms;
+    if (state)
+        board->ms = *state;
     board->cr = cr;
     return board;
 }
@@ -540,14 +544,18 @@ main(int argc, char *argv[])
     SimpleBoard *board;
     cairo_surface_t *surface;
     cairo_t *cr;
-    if (argc != 4)
+    if (argc != 4) {
         g_error("wrong number of arguments %d, expected 3\n", argc - 1);
+        return;
+    }
 
     surface = cairo_svg_surface_create(argv[3], SIMPLE_BOARD_SIZE, SIMPLE_BOARD_SIZE);
     cr = cairo_create(surface);
     board = simple_board_new_from_ids(argv[1], argv[2], cr);
-    if (!board)
+    if (!board) {
         g_error("Failed to create simple board from ids %s and %s", argv[1], argv[2]);
+        return;
+    }
     simple_board_draw(board);
     cairo_surface_destroy(surface);
     cairo_destroy(board->cr);
