@@ -1,11 +1,11 @@
 /*
- * sound.h
+ * Copyright (C) 2002 Joern Thyssen <jthyssen@dk.ibm.com>
+ * Copyright (C) 2002-2008 the AUTHORS
  *
- * by Joern Thyssen <jthyssen@dk.ibm.com>, 2002
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of version 3 or later of the GNU General Public License as
- * published by the Free Software Foundation.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,17 +13,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: sound.h,v 1.24 2018/06/16 15:23:09 plm Exp $
+ * $Id: sound.h,v 1.26 2020/01/05 19:51:24 plm Exp $
  */
 
 #ifndef SOUND_H
 #define SOUND_H
 
-
-typedef enum _gnubgsound {
+typedef enum {
     /* start & exit of gnubg */
     SOUND_START = 0,
     SOUND_EXIT,
@@ -56,7 +54,6 @@ extern int fSound;
 extern int fQuiet;
 
 extern void playSound(const gnubgsound gs);
-extern void SoundFlushCache(const gnubgsound gs);
 extern void SoundWait(void);
 
 extern char *GetDefaultSoundFile(gnubgsound sound);
